import 'package:flutter/material.dart';
import 'package:material_design_icons_flutter/material_design_icons_flutter.dart';

void main() {
  runApp(new MdiGalleryApp());
}

class MdiGalleryApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return new MaterialApp(
      title: 'Material Design Icons Flutter Gallery',
      theme: new ThemeData(
        iconTheme: new IconThemeData(size: 36.0, color: Colors.black87),
        primarySwatch: Colors.blue,
        textTheme: new TextTheme(
          body1: new TextStyle(fontSize: 16.0, color: Colors.black87),
        ),
      ),
      home: new MdiGalleryHome(),
    );
  }
}

class MdiGalleryHome extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => new MdiGalleryHomeState();
}

class MdiGalleryHomeState extends State<MdiGalleryHome> {
  var _searchTerm = "";
  var _isSearching = false;

  @override
  Widget build(BuildContext context) {
    final filteredIcons = icons
        .where((icon) =>
            _searchTerm.isEmpty ||
            icon.title.toLowerCase().contains(_searchTerm.toLowerCase()))
        .toList();
    final orientation = MediaQuery.of(context).orientation;

    return new Scaffold(
      appBar: _isSearching ? _searchBar(context) : _titleBar(),
      body: new GridView.builder(
          itemCount: filteredIcons.length,
          gridDelegate: new SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: orientation == Orientation.portrait ? 2 : 3,
          ),
          itemBuilder: (context, index) {
            final icon = filteredIcons[index];

            return new InkWell(
              onTap: () {
                Navigator.push(
                  context,
                  new MaterialPageRoute<Null>(
                    builder: (BuildContext context) {
                      return new GestureDetector(
                        onTap: () {
                          Navigator.of(context).pop();
                        },
                        child: new Container(
                          color: Colors.white,
                          child: new SizedBox.expand(
                            child: new Hero(
                              tag: icon,
                              child: new Icon(
                                icon.iconData,
                                size: 100.0,
                              ),
                            ),
                          ),
                        ),
                      );
                    },
                  ),
                );
              },
              child: new Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: <Widget>[
                  new Hero(tag: icon, child: new Icon(icon.iconData)),
                  new Container(
                    padding: new EdgeInsets.only(top: 16.0),
                    child: new Text(icon.title),
                  )
                ],
              ),
            );
          }),
    );
  }

  AppBar _titleBar() {
    return new AppBar(
      title: new Text("Material Design Icons Gallery"),
      actions: [
        new IconButton(
            icon: new Icon(MdiIcons.accessPoint),
            onPressed: () {
              ModalRoute.of(context).addLocalHistoryEntry(
                new LocalHistoryEntry(
                  onRemove: () {
                    setState(() {
                      _searchTerm = "";
                      _isSearching = false;
                    });
                  },
                ),
              );

              setState(() {
                _isSearching = true;
              });
            })
      ],
    );
  }

  AppBar _searchBar(BuildContext context) {
    return new AppBar(
      leading: new IconButton(
        icon: new Icon(MdiIcons.accessPoint),
        onPressed: () {
          setState(
            () {
              Navigator.pop(context);
              _isSearching = false;
              _searchTerm = "";
            },
          );
        },
      ),
      title: new TextField(
        onChanged: (text) => setState(() => _searchTerm = text),
        autofocus: true,
        style: new TextStyle(fontSize: 18.0),
        decoration: new InputDecoration(),
      ),
    );
  }
}

class IconDefinition implements Comparable {
  final IconData iconData;
  final String title;

  IconDefinition(this.iconData, this.title);

  @override
  String toString() => 'IconDefinition{iconData: $iconData, title: $title}';

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is IconDefinition &&
          runtimeType == other.runtimeType &&
          iconData == other.iconData &&
          title == other.title;

  @override
  int get hashCode => iconData.hashCode ^ title.hashCode;

  @override
  int compareTo(other) => title.compareTo(other.title);
}

final icons = <IconDefinition>[
  new IconDefinition(MdiIcons.accessPoint, 'accessPoint'),
  new IconDefinition(MdiIcons.accessPointNetwork, 'accessPointNetwork'),
  new IconDefinition(MdiIcons.accessPointNetworkOff, 'accessPointNetworkOff'),
  new IconDefinition(MdiIcons.account, 'account'),
  new IconDefinition(MdiIcons.accountAlert, 'accountAlert'),
  new IconDefinition(MdiIcons.accountAlertOutline, 'accountAlertOutline'),
  new IconDefinition(MdiIcons.accountArrowLeft, 'accountArrowLeft'),
  new IconDefinition(MdiIcons.accountArrowLeftOutline, 'accountArrowLeftOutline'),
  new IconDefinition(MdiIcons.accountArrowRight, 'accountArrowRight'),
  new IconDefinition(MdiIcons.accountArrowRightOutline, 'accountArrowRightOutline'),
  new IconDefinition(MdiIcons.accountBox, 'accountBox'),
  new IconDefinition(MdiIcons.accountBoxMultiple, 'accountBoxMultiple'),
  new IconDefinition(MdiIcons.accountBoxOutline, 'accountBoxOutline'),
  new IconDefinition(MdiIcons.accountCardDetails, 'accountCardDetails'),
  new IconDefinition(MdiIcons.accountCheck, 'accountCheck'),
  new IconDefinition(MdiIcons.accountCheckOutline, 'accountCheckOutline'),
  new IconDefinition(MdiIcons.accountChild, 'accountChild'),
  new IconDefinition(MdiIcons.accountChildCircle, 'accountChildCircle'),
  new IconDefinition(MdiIcons.accountCircle, 'accountCircle'),
  new IconDefinition(MdiIcons.accountCircleOutline, 'accountCircleOutline'),
  new IconDefinition(MdiIcons.accountClock, 'accountClock'),
  new IconDefinition(MdiIcons.accountClockOutline, 'accountClockOutline'),
  new IconDefinition(MdiIcons.accountConvert, 'accountConvert'),
  new IconDefinition(MdiIcons.accountDetails, 'accountDetails'),
  new IconDefinition(MdiIcons.accountEdit, 'accountEdit'),
  new IconDefinition(MdiIcons.accountGroup, 'accountGroup'),
  new IconDefinition(MdiIcons.accountGroupOutline, 'accountGroupOutline'),
  new IconDefinition(MdiIcons.accountHeart, 'accountHeart'),
  new IconDefinition(MdiIcons.accountHeartOutline, 'accountHeartOutline'),
  new IconDefinition(MdiIcons.accountKey, 'accountKey'),
  new IconDefinition(MdiIcons.accountKeyOutline, 'accountKeyOutline'),
  new IconDefinition(MdiIcons.accountMinus, 'accountMinus'),
  new IconDefinition(MdiIcons.accountMinusOutline, 'accountMinusOutline'),
  new IconDefinition(MdiIcons.accountMultiple, 'accountMultiple'),
  new IconDefinition(MdiIcons.accountMultipleCheck, 'accountMultipleCheck'),
  new IconDefinition(MdiIcons.accountMultipleMinus, 'accountMultipleMinus'),
  new IconDefinition(MdiIcons.accountMultipleMinusOutline, 'accountMultipleMinusOutline'),
  new IconDefinition(MdiIcons.accountMultipleOutline, 'accountMultipleOutline'),
  new IconDefinition(MdiIcons.accountMultiplePlus, 'accountMultiplePlus'),
  new IconDefinition(MdiIcons.accountMultiplePlusOutline, 'accountMultiplePlusOutline'),
  new IconDefinition(MdiIcons.accountNetwork, 'accountNetwork'),
  new IconDefinition(MdiIcons.accountNetworkOutline, 'accountNetworkOutline'),
  new IconDefinition(MdiIcons.accountOff, 'accountOff'),
  new IconDefinition(MdiIcons.accountOffOutline, 'accountOffOutline'),
  new IconDefinition(MdiIcons.accountOutline, 'accountOutline'),
  new IconDefinition(MdiIcons.accountPlus, 'accountPlus'),
  new IconDefinition(MdiIcons.accountPlusOutline, 'accountPlusOutline'),
  new IconDefinition(MdiIcons.accountQuestion, 'accountQuestion'),
  new IconDefinition(MdiIcons.accountQuestionOutline, 'accountQuestionOutline'),
  new IconDefinition(MdiIcons.accountRemove, 'accountRemove'),
  new IconDefinition(MdiIcons.accountRemoveOutline, 'accountRemoveOutline'),
  new IconDefinition(MdiIcons.accountSearch, 'accountSearch'),
  new IconDefinition(MdiIcons.accountSearchOutline, 'accountSearchOutline'),
  new IconDefinition(MdiIcons.accountSettings, 'accountSettings'),
  new IconDefinition(MdiIcons.accountStar, 'accountStar'),
  new IconDefinition(MdiIcons.accountStarOutline, 'accountStarOutline'),
  new IconDefinition(MdiIcons.accountSupervisor, 'accountSupervisor'),
  new IconDefinition(MdiIcons.accountSupervisorCircle, 'accountSupervisorCircle'),
  new IconDefinition(MdiIcons.accountSwitch, 'accountSwitch'),
  new IconDefinition(MdiIcons.accusoft, 'accusoft'),
  new IconDefinition(MdiIcons.adjust, 'adjust'),
  new IconDefinition(MdiIcons.adobe, 'adobe'),
  new IconDefinition(MdiIcons.airConditioner, 'airConditioner'),
  new IconDefinition(MdiIcons.airbag, 'airbag'),
  new IconDefinition(MdiIcons.airballoon, 'airballoon'),
  new IconDefinition(MdiIcons.airplane, 'airplane'),
  new IconDefinition(MdiIcons.airplaneLanding, 'airplaneLanding'),
  new IconDefinition(MdiIcons.airplaneOff, 'airplaneOff'),
  new IconDefinition(MdiIcons.airplaneTakeoff, 'airplaneTakeoff'),
  new IconDefinition(MdiIcons.airplay, 'airplay'),
  new IconDefinition(MdiIcons.airport, 'airport'),
  new IconDefinition(MdiIcons.alarm, 'alarm'),
  new IconDefinition(MdiIcons.alarmBell, 'alarmBell'),
  new IconDefinition(MdiIcons.alarmCheck, 'alarmCheck'),
  new IconDefinition(MdiIcons.alarmLight, 'alarmLight'),
  new IconDefinition(MdiIcons.alarmLightOutline, 'alarmLightOutline'),
  new IconDefinition(MdiIcons.alarmMultiple, 'alarmMultiple'),
  new IconDefinition(MdiIcons.alarmOff, 'alarmOff'),
  new IconDefinition(MdiIcons.alarmPlus, 'alarmPlus'),
  new IconDefinition(MdiIcons.alarmSnooze, 'alarmSnooze'),
  new IconDefinition(MdiIcons.album, 'album'),
  new IconDefinition(MdiIcons.alert, 'alert'),
  new IconDefinition(MdiIcons.alertBox, 'alertBox'),
  new IconDefinition(MdiIcons.alertCircle, 'alertCircle'),
  new IconDefinition(MdiIcons.alertCircleOutline, 'alertCircleOutline'),
  new IconDefinition(MdiIcons.alertDecagram, 'alertDecagram'),
  new IconDefinition(MdiIcons.alertOctagon, 'alertOctagon'),
  new IconDefinition(MdiIcons.alertOctagram, 'alertOctagram'),
  new IconDefinition(MdiIcons.alertOutline, 'alertOutline'),
  new IconDefinition(MdiIcons.alien, 'alien'),
  new IconDefinition(MdiIcons.allInclusive, 'allInclusive'),
  new IconDefinition(MdiIcons.alpha, 'alpha'),
  new IconDefinition(MdiIcons.alphaA, 'alphaA'),
  new IconDefinition(MdiIcons.alphaABox, 'alphaABox'),
  new IconDefinition(MdiIcons.alphaABoxOutline, 'alphaABoxOutline'),
  new IconDefinition(MdiIcons.alphaACircle, 'alphaACircle'),
  new IconDefinition(MdiIcons.alphaACircleOutline, 'alphaACircleOutline'),
  new IconDefinition(MdiIcons.alphaB, 'alphaB'),
  new IconDefinition(MdiIcons.alphaBBox, 'alphaBBox'),
  new IconDefinition(MdiIcons.alphaBBoxOutline, 'alphaBBoxOutline'),
  new IconDefinition(MdiIcons.alphaBCircle, 'alphaBCircle'),
  new IconDefinition(MdiIcons.alphaBCircleOutline, 'alphaBCircleOutline'),
  new IconDefinition(MdiIcons.alphaC, 'alphaC'),
  new IconDefinition(MdiIcons.alphaCBox, 'alphaCBox'),
  new IconDefinition(MdiIcons.alphaCBoxOutline, 'alphaCBoxOutline'),
  new IconDefinition(MdiIcons.alphaCCircle, 'alphaCCircle'),
  new IconDefinition(MdiIcons.alphaCCircleOutline, 'alphaCCircleOutline'),
  new IconDefinition(MdiIcons.alphaD, 'alphaD'),
  new IconDefinition(MdiIcons.alphaDBox, 'alphaDBox'),
  new IconDefinition(MdiIcons.alphaDBoxOutline, 'alphaDBoxOutline'),
  new IconDefinition(MdiIcons.alphaDCircle, 'alphaDCircle'),
  new IconDefinition(MdiIcons.alphaDCircleOutline, 'alphaDCircleOutline'),
  new IconDefinition(MdiIcons.alphaE, 'alphaE'),
  new IconDefinition(MdiIcons.alphaEBox, 'alphaEBox'),
  new IconDefinition(MdiIcons.alphaEBoxOutline, 'alphaEBoxOutline'),
  new IconDefinition(MdiIcons.alphaECircle, 'alphaECircle'),
  new IconDefinition(MdiIcons.alphaECircleOutline, 'alphaECircleOutline'),
  new IconDefinition(MdiIcons.alphaF, 'alphaF'),
  new IconDefinition(MdiIcons.alphaFBox, 'alphaFBox'),
  new IconDefinition(MdiIcons.alphaFBoxOutline, 'alphaFBoxOutline'),
  new IconDefinition(MdiIcons.alphaFCircle, 'alphaFCircle'),
  new IconDefinition(MdiIcons.alphaFCircleOutline, 'alphaFCircleOutline'),
  new IconDefinition(MdiIcons.alphaG, 'alphaG'),
  new IconDefinition(MdiIcons.alphaGBox, 'alphaGBox'),
  new IconDefinition(MdiIcons.alphaGBoxOutline, 'alphaGBoxOutline'),
  new IconDefinition(MdiIcons.alphaGCircle, 'alphaGCircle'),
  new IconDefinition(MdiIcons.alphaGCircleOutline, 'alphaGCircleOutline'),
  new IconDefinition(MdiIcons.alphaH, 'alphaH'),
  new IconDefinition(MdiIcons.alphaHBox, 'alphaHBox'),
  new IconDefinition(MdiIcons.alphaHBoxOutline, 'alphaHBoxOutline'),
  new IconDefinition(MdiIcons.alphaHCircle, 'alphaHCircle'),
  new IconDefinition(MdiIcons.alphaHCircleOutline, 'alphaHCircleOutline'),
  new IconDefinition(MdiIcons.alphaI, 'alphaI'),
  new IconDefinition(MdiIcons.alphaIBox, 'alphaIBox'),
  new IconDefinition(MdiIcons.alphaIBoxOutline, 'alphaIBoxOutline'),
  new IconDefinition(MdiIcons.alphaICircle, 'alphaICircle'),
  new IconDefinition(MdiIcons.alphaICircleOutline, 'alphaICircleOutline'),
  new IconDefinition(MdiIcons.alphaJ, 'alphaJ'),
  new IconDefinition(MdiIcons.alphaJBox, 'alphaJBox'),
  new IconDefinition(MdiIcons.alphaJBoxOutline, 'alphaJBoxOutline'),
  new IconDefinition(MdiIcons.alphaJCircle, 'alphaJCircle'),
  new IconDefinition(MdiIcons.alphaJCircleOutline, 'alphaJCircleOutline'),
  new IconDefinition(MdiIcons.alphaK, 'alphaK'),
  new IconDefinition(MdiIcons.alphaKBox, 'alphaKBox'),
  new IconDefinition(MdiIcons.alphaKBoxOutline, 'alphaKBoxOutline'),
  new IconDefinition(MdiIcons.alphaKCircle, 'alphaKCircle'),
  new IconDefinition(MdiIcons.alphaKCircleOutline, 'alphaKCircleOutline'),
  new IconDefinition(MdiIcons.alphaL, 'alphaL'),
  new IconDefinition(MdiIcons.alphaLBox, 'alphaLBox'),
  new IconDefinition(MdiIcons.alphaLBoxOutline, 'alphaLBoxOutline'),
  new IconDefinition(MdiIcons.alphaLCircle, 'alphaLCircle'),
  new IconDefinition(MdiIcons.alphaLCircleOutline, 'alphaLCircleOutline'),
  new IconDefinition(MdiIcons.alphaM, 'alphaM'),
  new IconDefinition(MdiIcons.alphaMBox, 'alphaMBox'),
  new IconDefinition(MdiIcons.alphaMBoxOutline, 'alphaMBoxOutline'),
  new IconDefinition(MdiIcons.alphaMCircle, 'alphaMCircle'),
  new IconDefinition(MdiIcons.alphaMCircleOutline, 'alphaMCircleOutline'),
  new IconDefinition(MdiIcons.alphaN, 'alphaN'),
  new IconDefinition(MdiIcons.alphaNBox, 'alphaNBox'),
  new IconDefinition(MdiIcons.alphaNBoxOutline, 'alphaNBoxOutline'),
  new IconDefinition(MdiIcons.alphaNCircle, 'alphaNCircle'),
  new IconDefinition(MdiIcons.alphaNCircleOutline, 'alphaNCircleOutline'),
  new IconDefinition(MdiIcons.alphaO, 'alphaO'),
  new IconDefinition(MdiIcons.alphaOBox, 'alphaOBox'),
  new IconDefinition(MdiIcons.alphaOBoxOutline, 'alphaOBoxOutline'),
  new IconDefinition(MdiIcons.alphaOCircle, 'alphaOCircle'),
  new IconDefinition(MdiIcons.alphaOCircleOutline, 'alphaOCircleOutline'),
  new IconDefinition(MdiIcons.alphaP, 'alphaP'),
  new IconDefinition(MdiIcons.alphaPBox, 'alphaPBox'),
  new IconDefinition(MdiIcons.alphaPBoxOutline, 'alphaPBoxOutline'),
  new IconDefinition(MdiIcons.alphaPCircle, 'alphaPCircle'),
  new IconDefinition(MdiIcons.alphaPCircleOutline, 'alphaPCircleOutline'),
  new IconDefinition(MdiIcons.alphaQ, 'alphaQ'),
  new IconDefinition(MdiIcons.alphaQBox, 'alphaQBox'),
  new IconDefinition(MdiIcons.alphaQBoxOutline, 'alphaQBoxOutline'),
  new IconDefinition(MdiIcons.alphaQCircle, 'alphaQCircle'),
  new IconDefinition(MdiIcons.alphaQCircleOutline, 'alphaQCircleOutline'),
  new IconDefinition(MdiIcons.alphaR, 'alphaR'),
  new IconDefinition(MdiIcons.alphaRBox, 'alphaRBox'),
  new IconDefinition(MdiIcons.alphaRBoxOutline, 'alphaRBoxOutline'),
  new IconDefinition(MdiIcons.alphaRCircle, 'alphaRCircle'),
  new IconDefinition(MdiIcons.alphaRCircleOutline, 'alphaRCircleOutline'),
  new IconDefinition(MdiIcons.alphaS, 'alphaS'),
  new IconDefinition(MdiIcons.alphaSBox, 'alphaSBox'),
  new IconDefinition(MdiIcons.alphaSBoxOutline, 'alphaSBoxOutline'),
  new IconDefinition(MdiIcons.alphaSCircle, 'alphaSCircle'),
  new IconDefinition(MdiIcons.alphaSCircleOutline, 'alphaSCircleOutline'),
  new IconDefinition(MdiIcons.alphaT, 'alphaT'),
  new IconDefinition(MdiIcons.alphaTBox, 'alphaTBox'),
  new IconDefinition(MdiIcons.alphaTBoxOutline, 'alphaTBoxOutline'),
  new IconDefinition(MdiIcons.alphaTCircle, 'alphaTCircle'),
  new IconDefinition(MdiIcons.alphaTCircleOutline, 'alphaTCircleOutline'),
  new IconDefinition(MdiIcons.alphaU, 'alphaU'),
  new IconDefinition(MdiIcons.alphaUBox, 'alphaUBox'),
  new IconDefinition(MdiIcons.alphaUBoxOutline, 'alphaUBoxOutline'),
  new IconDefinition(MdiIcons.alphaUCircle, 'alphaUCircle'),
  new IconDefinition(MdiIcons.alphaUCircleOutline, 'alphaUCircleOutline'),
  new IconDefinition(MdiIcons.alphaV, 'alphaV'),
  new IconDefinition(MdiIcons.alphaVBox, 'alphaVBox'),
  new IconDefinition(MdiIcons.alphaVBoxOutline, 'alphaVBoxOutline'),
  new IconDefinition(MdiIcons.alphaVCircle, 'alphaVCircle'),
  new IconDefinition(MdiIcons.alphaVCircleOutline, 'alphaVCircleOutline'),
  new IconDefinition(MdiIcons.alphaW, 'alphaW'),
  new IconDefinition(MdiIcons.alphaWBox, 'alphaWBox'),
  new IconDefinition(MdiIcons.alphaWBoxOutline, 'alphaWBoxOutline'),
  new IconDefinition(MdiIcons.alphaWCircle, 'alphaWCircle'),
  new IconDefinition(MdiIcons.alphaWCircleOutline, 'alphaWCircleOutline'),
  new IconDefinition(MdiIcons.alphaX, 'alphaX'),
  new IconDefinition(MdiIcons.alphaXBox, 'alphaXBox'),
  new IconDefinition(MdiIcons.alphaXBoxOutline, 'alphaXBoxOutline'),
  new IconDefinition(MdiIcons.alphaXCircle, 'alphaXCircle'),
  new IconDefinition(MdiIcons.alphaXCircleOutline, 'alphaXCircleOutline'),
  new IconDefinition(MdiIcons.alphaY, 'alphaY'),
  new IconDefinition(MdiIcons.alphaYBox, 'alphaYBox'),
  new IconDefinition(MdiIcons.alphaYBoxOutline, 'alphaYBoxOutline'),
  new IconDefinition(MdiIcons.alphaYCircle, 'alphaYCircle'),
  new IconDefinition(MdiIcons.alphaYCircleOutline, 'alphaYCircleOutline'),
  new IconDefinition(MdiIcons.alphaZ, 'alphaZ'),
  new IconDefinition(MdiIcons.alphaZBox, 'alphaZBox'),
  new IconDefinition(MdiIcons.alphaZBoxOutline, 'alphaZBoxOutline'),
  new IconDefinition(MdiIcons.alphaZCircle, 'alphaZCircle'),
  new IconDefinition(MdiIcons.alphaZCircleOutline, 'alphaZCircleOutline'),
  new IconDefinition(MdiIcons.alphabetical, 'alphabetical'),
  new IconDefinition(MdiIcons.altimeter, 'altimeter'),
  new IconDefinition(MdiIcons.amazon, 'amazon'),
  new IconDefinition(MdiIcons.amazonAlexa, 'amazonAlexa'),
  new IconDefinition(MdiIcons.amazonDrive, 'amazonDrive'),
  new IconDefinition(MdiIcons.ambulance, 'ambulance'),
  new IconDefinition(MdiIcons.ampersand, 'ampersand'),
  new IconDefinition(MdiIcons.amplifier, 'amplifier'),
  new IconDefinition(MdiIcons.anchor, 'anchor'),
  new IconDefinition(MdiIcons.android, 'android'),
  new IconDefinition(MdiIcons.androidAuto, 'androidAuto'),
  new IconDefinition(MdiIcons.androidDebugBridge, 'androidDebugBridge'),
  new IconDefinition(MdiIcons.androidHead, 'androidHead'),
  new IconDefinition(MdiIcons.androidStudio, 'androidStudio'),
  new IconDefinition(MdiIcons.angleAcute, 'angleAcute'),
  new IconDefinition(MdiIcons.angleObtuse, 'angleObtuse'),
  new IconDefinition(MdiIcons.angleRight, 'angleRight'),
  new IconDefinition(MdiIcons.angular, 'angular'),
  new IconDefinition(MdiIcons.angularjs, 'angularjs'),
  new IconDefinition(MdiIcons.animation, 'animation'),
  new IconDefinition(MdiIcons.animationOutline, 'animationOutline'),
  new IconDefinition(MdiIcons.animationPlay, 'animationPlay'),
  new IconDefinition(MdiIcons.animationPlayOutline, 'animationPlayOutline'),
  new IconDefinition(MdiIcons.anvil, 'anvil'),
  new IconDefinition(MdiIcons.apple, 'apple'),
  new IconDefinition(MdiIcons.appleFinder, 'appleFinder'),
  new IconDefinition(MdiIcons.appleIcloud, 'appleIcloud'),
  new IconDefinition(MdiIcons.appleIos, 'appleIos'),
  new IconDefinition(MdiIcons.appleKeyboardCaps, 'appleKeyboardCaps'),
  new IconDefinition(MdiIcons.appleKeyboardCommand, 'appleKeyboardCommand'),
  new IconDefinition(MdiIcons.appleKeyboardControl, 'appleKeyboardControl'),
  new IconDefinition(MdiIcons.appleKeyboardOption, 'appleKeyboardOption'),
  new IconDefinition(MdiIcons.appleKeyboardShift, 'appleKeyboardShift'),
  new IconDefinition(MdiIcons.appleSafari, 'appleSafari'),
  new IconDefinition(MdiIcons.application, 'application'),
  new IconDefinition(MdiIcons.apps, 'apps'),
  new IconDefinition(MdiIcons.arch, 'arch'),
  new IconDefinition(MdiIcons.archive, 'archive'),
  new IconDefinition(MdiIcons.arrangeBringForward, 'arrangeBringForward'),
  new IconDefinition(MdiIcons.arrangeBringToFront, 'arrangeBringToFront'),
  new IconDefinition(MdiIcons.arrangeSendBackward, 'arrangeSendBackward'),
  new IconDefinition(MdiIcons.arrangeSendToBack, 'arrangeSendToBack'),
  new IconDefinition(MdiIcons.arrowAll, 'arrowAll'),
  new IconDefinition(MdiIcons.arrowBottomLeft, 'arrowBottomLeft'),
  new IconDefinition(MdiIcons.arrowBottomLeftBoldOutline, 'arrowBottomLeftBoldOutline'),
  new IconDefinition(MdiIcons.arrowBottomLeftThick, 'arrowBottomLeftThick'),
  new IconDefinition(MdiIcons.arrowBottomRight, 'arrowBottomRight'),
  new IconDefinition(MdiIcons.arrowBottomRightBoldOutline, 'arrowBottomRightBoldOutline'),
  new IconDefinition(MdiIcons.arrowBottomRightThick, 'arrowBottomRightThick'),
  new IconDefinition(MdiIcons.arrowCollapse, 'arrowCollapse'),
  new IconDefinition(MdiIcons.arrowCollapseAll, 'arrowCollapseAll'),
  new IconDefinition(MdiIcons.arrowCollapseDown, 'arrowCollapseDown'),
  new IconDefinition(MdiIcons.arrowCollapseHorizontal, 'arrowCollapseHorizontal'),
  new IconDefinition(MdiIcons.arrowCollapseLeft, 'arrowCollapseLeft'),
  new IconDefinition(MdiIcons.arrowCollapseRight, 'arrowCollapseRight'),
  new IconDefinition(MdiIcons.arrowCollapseUp, 'arrowCollapseUp'),
  new IconDefinition(MdiIcons.arrowCollapseVertical, 'arrowCollapseVertical'),
  new IconDefinition(MdiIcons.arrowDecision, 'arrowDecision'),
  new IconDefinition(MdiIcons.arrowDecisionAuto, 'arrowDecisionAuto'),
  new IconDefinition(MdiIcons.arrowDecisionAutoOutline, 'arrowDecisionAutoOutline'),
  new IconDefinition(MdiIcons.arrowDecisionOutline, 'arrowDecisionOutline'),
  new IconDefinition(MdiIcons.arrowDown, 'arrowDown'),
  new IconDefinition(MdiIcons.arrowDownBold, 'arrowDownBold'),
  new IconDefinition(MdiIcons.arrowDownBoldBox, 'arrowDownBoldBox'),
  new IconDefinition(MdiIcons.arrowDownBoldBoxOutline, 'arrowDownBoldBoxOutline'),
  new IconDefinition(MdiIcons.arrowDownBoldCircle, 'arrowDownBoldCircle'),
  new IconDefinition(MdiIcons.arrowDownBoldCircleOutline, 'arrowDownBoldCircleOutline'),
  new IconDefinition(MdiIcons.arrowDownBoldHexagonOutline, 'arrowDownBoldHexagonOutline'),
  new IconDefinition(MdiIcons.arrowDownBoldOutline, 'arrowDownBoldOutline'),
  new IconDefinition(MdiIcons.arrowDownBox, 'arrowDownBox'),
  new IconDefinition(MdiIcons.arrowDownDropCircle, 'arrowDownDropCircle'),
  new IconDefinition(MdiIcons.arrowDownDropCircleOutline, 'arrowDownDropCircleOutline'),
  new IconDefinition(MdiIcons.arrowDownThick, 'arrowDownThick'),
  new IconDefinition(MdiIcons.arrowExpand, 'arrowExpand'),
  new IconDefinition(MdiIcons.arrowExpandAll, 'arrowExpandAll'),
  new IconDefinition(MdiIcons.arrowExpandDown, 'arrowExpandDown'),
  new IconDefinition(MdiIcons.arrowExpandHorizontal, 'arrowExpandHorizontal'),
  new IconDefinition(MdiIcons.arrowExpandLeft, 'arrowExpandLeft'),
  new IconDefinition(MdiIcons.arrowExpandRight, 'arrowExpandRight'),
  new IconDefinition(MdiIcons.arrowExpandUp, 'arrowExpandUp'),
  new IconDefinition(MdiIcons.arrowExpandVertical, 'arrowExpandVertical'),
  new IconDefinition(MdiIcons.arrowLeft, 'arrowLeft'),
  new IconDefinition(MdiIcons.arrowLeftBold, 'arrowLeftBold'),
  new IconDefinition(MdiIcons.arrowLeftBoldBox, 'arrowLeftBoldBox'),
  new IconDefinition(MdiIcons.arrowLeftBoldBoxOutline, 'arrowLeftBoldBoxOutline'),
  new IconDefinition(MdiIcons.arrowLeftBoldCircle, 'arrowLeftBoldCircle'),
  new IconDefinition(MdiIcons.arrowLeftBoldCircleOutline, 'arrowLeftBoldCircleOutline'),
  new IconDefinition(MdiIcons.arrowLeftBoldHexagonOutline, 'arrowLeftBoldHexagonOutline'),
  new IconDefinition(MdiIcons.arrowLeftBoldOutline, 'arrowLeftBoldOutline'),
  new IconDefinition(MdiIcons.arrowLeftBox, 'arrowLeftBox'),
  new IconDefinition(MdiIcons.arrowLeftDropCircle, 'arrowLeftDropCircle'),
  new IconDefinition(MdiIcons.arrowLeftDropCircleOutline, 'arrowLeftDropCircleOutline'),
  new IconDefinition(MdiIcons.arrowLeftRightBoldOutline, 'arrowLeftRightBoldOutline'),
  new IconDefinition(MdiIcons.arrowLeftThick, 'arrowLeftThick'),
  new IconDefinition(MdiIcons.arrowRight, 'arrowRight'),
  new IconDefinition(MdiIcons.arrowRightBold, 'arrowRightBold'),
  new IconDefinition(MdiIcons.arrowRightBoldBox, 'arrowRightBoldBox'),
  new IconDefinition(MdiIcons.arrowRightBoldBoxOutline, 'arrowRightBoldBoxOutline'),
  new IconDefinition(MdiIcons.arrowRightBoldCircle, 'arrowRightBoldCircle'),
  new IconDefinition(MdiIcons.arrowRightBoldCircleOutline, 'arrowRightBoldCircleOutline'),
  new IconDefinition(MdiIcons.arrowRightBoldHexagonOutline, 'arrowRightBoldHexagonOutline'),
  new IconDefinition(MdiIcons.arrowRightBoldOutline, 'arrowRightBoldOutline'),
  new IconDefinition(MdiIcons.arrowRightBox, 'arrowRightBox'),
  new IconDefinition(MdiIcons.arrowRightDropCircle, 'arrowRightDropCircle'),
  new IconDefinition(MdiIcons.arrowRightDropCircleOutline, 'arrowRightDropCircleOutline'),
  new IconDefinition(MdiIcons.arrowRightThick, 'arrowRightThick'),
  new IconDefinition(MdiIcons.arrowSplitHorizontal, 'arrowSplitHorizontal'),
  new IconDefinition(MdiIcons.arrowSplitVertical, 'arrowSplitVertical'),
  new IconDefinition(MdiIcons.arrowTopLeft, 'arrowTopLeft'),
  new IconDefinition(MdiIcons.arrowTopLeftBoldOutline, 'arrowTopLeftBoldOutline'),
  new IconDefinition(MdiIcons.arrowTopLeftThick, 'arrowTopLeftThick'),
  new IconDefinition(MdiIcons.arrowTopRight, 'arrowTopRight'),
  new IconDefinition(MdiIcons.arrowTopRightBoldOutline, 'arrowTopRightBoldOutline'),
  new IconDefinition(MdiIcons.arrowTopRightThick, 'arrowTopRightThick'),
  new IconDefinition(MdiIcons.arrowUp, 'arrowUp'),
  new IconDefinition(MdiIcons.arrowUpBold, 'arrowUpBold'),
  new IconDefinition(MdiIcons.arrowUpBoldBox, 'arrowUpBoldBox'),
  new IconDefinition(MdiIcons.arrowUpBoldBoxOutline, 'arrowUpBoldBoxOutline'),
  new IconDefinition(MdiIcons.arrowUpBoldCircle, 'arrowUpBoldCircle'),
  new IconDefinition(MdiIcons.arrowUpBoldCircleOutline, 'arrowUpBoldCircleOutline'),
  new IconDefinition(MdiIcons.arrowUpBoldHexagonOutline, 'arrowUpBoldHexagonOutline'),
  new IconDefinition(MdiIcons.arrowUpBoldOutline, 'arrowUpBoldOutline'),
  new IconDefinition(MdiIcons.arrowUpBox, 'arrowUpBox'),
  new IconDefinition(MdiIcons.arrowUpDownBoldOutline, 'arrowUpDownBoldOutline'),
  new IconDefinition(MdiIcons.arrowUpDropCircle, 'arrowUpDropCircle'),
  new IconDefinition(MdiIcons.arrowUpDropCircleOutline, 'arrowUpDropCircleOutline'),
  new IconDefinition(MdiIcons.arrowUpThick, 'arrowUpThick'),
  new IconDefinition(MdiIcons.artist, 'artist'),
  new IconDefinition(MdiIcons.artstation, 'artstation'),
  new IconDefinition(MdiIcons.aspectRatio, 'aspectRatio'),
  new IconDefinition(MdiIcons.assistant, 'assistant'),
  new IconDefinition(MdiIcons.asterisk, 'asterisk'),
  new IconDefinition(MdiIcons.at, 'at'),
  new IconDefinition(MdiIcons.atlassian, 'atlassian'),
  new IconDefinition(MdiIcons.atom, 'atom'),
  new IconDefinition(MdiIcons.attachment, 'attachment'),
  new IconDefinition(MdiIcons.audioVideo, 'audioVideo'),
  new IconDefinition(MdiIcons.audiobook, 'audiobook'),
  new IconDefinition(MdiIcons.augmentedReality, 'augmentedReality'),
  new IconDefinition(MdiIcons.autoFix, 'autoFix'),
  new IconDefinition(MdiIcons.autoUpload, 'autoUpload'),
  new IconDefinition(MdiIcons.autorenew, 'autorenew'),
  new IconDefinition(MdiIcons.avTimer, 'avTimer'),
  new IconDefinition(MdiIcons.axe, 'axe'),
  new IconDefinition(MdiIcons.azure, 'azure'),
  new IconDefinition(MdiIcons.babel, 'babel'),
  new IconDefinition(MdiIcons.baby, 'baby'),
  new IconDefinition(MdiIcons.babyBuggy, 'babyBuggy'),
  new IconDefinition(MdiIcons.backburger, 'backburger'),
  new IconDefinition(MdiIcons.backspace, 'backspace'),
  new IconDefinition(MdiIcons.backspaceOutline, 'backspaceOutline'),
  new IconDefinition(MdiIcons.backupRestore, 'backupRestore'),
  new IconDefinition(MdiIcons.badminton, 'badminton'),
  new IconDefinition(MdiIcons.balloon, 'balloon'),
  new IconDefinition(MdiIcons.ballot, 'ballot'),
  new IconDefinition(MdiIcons.ballotOutline, 'ballotOutline'),
  new IconDefinition(MdiIcons.ballotRecount, 'ballotRecount'),
  new IconDefinition(MdiIcons.ballotRecountOutline, 'ballotRecountOutline'),
  new IconDefinition(MdiIcons.bandcamp, 'bandcamp'),
  new IconDefinition(MdiIcons.bank, 'bank'),
  new IconDefinition(MdiIcons.bankTransfer, 'bankTransfer'),
  new IconDefinition(MdiIcons.bankTransferIn, 'bankTransferIn'),
  new IconDefinition(MdiIcons.bankTransferOut, 'bankTransferOut'),
  new IconDefinition(MdiIcons.barcode, 'barcode'),
  new IconDefinition(MdiIcons.barcodeScan, 'barcodeScan'),
  new IconDefinition(MdiIcons.barley, 'barley'),
  new IconDefinition(MdiIcons.barleyOff, 'barleyOff'),
  new IconDefinition(MdiIcons.barn, 'barn'),
  new IconDefinition(MdiIcons.barrel, 'barrel'),
  new IconDefinition(MdiIcons.baseball, 'baseball'),
  new IconDefinition(MdiIcons.baseballBat, 'baseballBat'),
  new IconDefinition(MdiIcons.basecamp, 'basecamp'),
  new IconDefinition(MdiIcons.basket, 'basket'),
  new IconDefinition(MdiIcons.basketFill, 'basketFill'),
  new IconDefinition(MdiIcons.basketUnfill, 'basketUnfill'),
  new IconDefinition(MdiIcons.basketball, 'basketball'),
  new IconDefinition(MdiIcons.basketballHoop, 'basketballHoop'),
  new IconDefinition(MdiIcons.basketballHoopOutline, 'basketballHoopOutline'),
  new IconDefinition(MdiIcons.bat, 'bat'),
  new IconDefinition(MdiIcons.battery, 'battery'),
  new IconDefinition(MdiIcons.battery10, 'battery10'),
  new IconDefinition(MdiIcons.battery10Bluetooth, 'battery10Bluetooth'),
  new IconDefinition(MdiIcons.battery20, 'battery20'),
  new IconDefinition(MdiIcons.battery20Bluetooth, 'battery20Bluetooth'),
  new IconDefinition(MdiIcons.battery30, 'battery30'),
  new IconDefinition(MdiIcons.battery30Bluetooth, 'battery30Bluetooth'),
  new IconDefinition(MdiIcons.battery40, 'battery40'),
  new IconDefinition(MdiIcons.battery40Bluetooth, 'battery40Bluetooth'),
  new IconDefinition(MdiIcons.battery50, 'battery50'),
  new IconDefinition(MdiIcons.battery50Bluetooth, 'battery50Bluetooth'),
  new IconDefinition(MdiIcons.battery60, 'battery60'),
  new IconDefinition(MdiIcons.battery60Bluetooth, 'battery60Bluetooth'),
  new IconDefinition(MdiIcons.battery70, 'battery70'),
  new IconDefinition(MdiIcons.battery70Bluetooth, 'battery70Bluetooth'),
  new IconDefinition(MdiIcons.battery80, 'battery80'),
  new IconDefinition(MdiIcons.battery80Bluetooth, 'battery80Bluetooth'),
  new IconDefinition(MdiIcons.battery90, 'battery90'),
  new IconDefinition(MdiIcons.battery90Bluetooth, 'battery90Bluetooth'),
  new IconDefinition(MdiIcons.batteryAlert, 'batteryAlert'),
  new IconDefinition(MdiIcons.batteryAlertBluetooth, 'batteryAlertBluetooth'),
  new IconDefinition(MdiIcons.batteryBluetooth, 'batteryBluetooth'),
  new IconDefinition(MdiIcons.batteryBluetoothVariant, 'batteryBluetoothVariant'),
  new IconDefinition(MdiIcons.batteryCharging, 'batteryCharging'),
  new IconDefinition(MdiIcons.batteryCharging10, 'batteryCharging10'),
  new IconDefinition(MdiIcons.batteryCharging100, 'batteryCharging100'),
  new IconDefinition(MdiIcons.batteryCharging20, 'batteryCharging20'),
  new IconDefinition(MdiIcons.batteryCharging30, 'batteryCharging30'),
  new IconDefinition(MdiIcons.batteryCharging40, 'batteryCharging40'),
  new IconDefinition(MdiIcons.batteryCharging50, 'batteryCharging50'),
  new IconDefinition(MdiIcons.batteryCharging60, 'batteryCharging60'),
  new IconDefinition(MdiIcons.batteryCharging70, 'batteryCharging70'),
  new IconDefinition(MdiIcons.batteryCharging80, 'batteryCharging80'),
  new IconDefinition(MdiIcons.batteryCharging90, 'batteryCharging90'),
  new IconDefinition(MdiIcons.batteryChargingOutline, 'batteryChargingOutline'),
  new IconDefinition(MdiIcons.batteryChargingWireless, 'batteryChargingWireless'),
  new IconDefinition(MdiIcons.batteryChargingWireless10, 'batteryChargingWireless10'),
  new IconDefinition(MdiIcons.batteryChargingWireless20, 'batteryChargingWireless20'),
  new IconDefinition(MdiIcons.batteryChargingWireless30, 'batteryChargingWireless30'),
  new IconDefinition(MdiIcons.batteryChargingWireless40, 'batteryChargingWireless40'),
  new IconDefinition(MdiIcons.batteryChargingWireless50, 'batteryChargingWireless50'),
  new IconDefinition(MdiIcons.batteryChargingWireless60, 'batteryChargingWireless60'),
  new IconDefinition(MdiIcons.batteryChargingWireless70, 'batteryChargingWireless70'),
  new IconDefinition(MdiIcons.batteryChargingWireless80, 'batteryChargingWireless80'),
  new IconDefinition(MdiIcons.batteryChargingWireless90, 'batteryChargingWireless90'),
  new IconDefinition(MdiIcons.batteryChargingWirelessAlert, 'batteryChargingWirelessAlert'),
  new IconDefinition(MdiIcons.batteryChargingWirelessOutline, 'batteryChargingWirelessOutline'),
  new IconDefinition(MdiIcons.batteryMinus, 'batteryMinus'),
  new IconDefinition(MdiIcons.batteryNegative, 'batteryNegative'),
  new IconDefinition(MdiIcons.batteryOutline, 'batteryOutline'),
  new IconDefinition(MdiIcons.batteryPlus, 'batteryPlus'),
  new IconDefinition(MdiIcons.batteryPositive, 'batteryPositive'),
  new IconDefinition(MdiIcons.batteryUnknown, 'batteryUnknown'),
  new IconDefinition(MdiIcons.batteryUnknownBluetooth, 'batteryUnknownBluetooth'),
  new IconDefinition(MdiIcons.battlenet, 'battlenet'),
  new IconDefinition(MdiIcons.beach, 'beach'),
  new IconDefinition(MdiIcons.beaker, 'beaker'),
  new IconDefinition(MdiIcons.beats, 'beats'),
  new IconDefinition(MdiIcons.bedEmpty, 'bedEmpty'),
  new IconDefinition(MdiIcons.beer, 'beer'),
  new IconDefinition(MdiIcons.behance, 'behance'),
  new IconDefinition(MdiIcons.bell, 'bell'),
  new IconDefinition(MdiIcons.bellOff, 'bellOff'),
  new IconDefinition(MdiIcons.bellOffOutline, 'bellOffOutline'),
  new IconDefinition(MdiIcons.bellOutline, 'bellOutline'),
  new IconDefinition(MdiIcons.bellPlus, 'bellPlus'),
  new IconDefinition(MdiIcons.bellPlusOutline, 'bellPlusOutline'),
  new IconDefinition(MdiIcons.bellRing, 'bellRing'),
  new IconDefinition(MdiIcons.bellRingOutline, 'bellRingOutline'),
  new IconDefinition(MdiIcons.bellSleep, 'bellSleep'),
  new IconDefinition(MdiIcons.bellSleepOutline, 'bellSleepOutline'),
  new IconDefinition(MdiIcons.beta, 'beta'),
  new IconDefinition(MdiIcons.betamax, 'betamax'),
  new IconDefinition(MdiIcons.bible, 'bible'),
  new IconDefinition(MdiIcons.bike, 'bike'),
  new IconDefinition(MdiIcons.billiards, 'billiards'),
  new IconDefinition(MdiIcons.billiardsRack, 'billiardsRack'),
  new IconDefinition(MdiIcons.bing, 'bing'),
  new IconDefinition(MdiIcons.binoculars, 'binoculars'),
  new IconDefinition(MdiIcons.bio, 'bio'),
  new IconDefinition(MdiIcons.biohazard, 'biohazard'),
  new IconDefinition(MdiIcons.bitbucket, 'bitbucket'),
  new IconDefinition(MdiIcons.bitcoin, 'bitcoin'),
  new IconDefinition(MdiIcons.blackMesa, 'blackMesa'),
  new IconDefinition(MdiIcons.blackberry, 'blackberry'),
  new IconDefinition(MdiIcons.blender, 'blender'),
  new IconDefinition(MdiIcons.blinds, 'blinds'),
  new IconDefinition(MdiIcons.blockHelper, 'blockHelper'),
  new IconDefinition(MdiIcons.blogger, 'blogger'),
  new IconDefinition(MdiIcons.bluetooth, 'bluetooth'),
  new IconDefinition(MdiIcons.bluetoothAudio, 'bluetoothAudio'),
  new IconDefinition(MdiIcons.bluetoothConnect, 'bluetoothConnect'),
  new IconDefinition(MdiIcons.bluetoothOff, 'bluetoothOff'),
  new IconDefinition(MdiIcons.bluetoothSettings, 'bluetoothSettings'),
  new IconDefinition(MdiIcons.bluetoothTransfer, 'bluetoothTransfer'),
  new IconDefinition(MdiIcons.blur, 'blur'),
  new IconDefinition(MdiIcons.blurLinear, 'blurLinear'),
  new IconDefinition(MdiIcons.blurOff, 'blurOff'),
  new IconDefinition(MdiIcons.blurRadial, 'blurRadial'),
  new IconDefinition(MdiIcons.bomb, 'bomb'),
  new IconDefinition(MdiIcons.bombOff, 'bombOff'),
  new IconDefinition(MdiIcons.bone, 'bone'),
  new IconDefinition(MdiIcons.book, 'book'),
  new IconDefinition(MdiIcons.bookLock, 'bookLock'),
  new IconDefinition(MdiIcons.bookLockOpen, 'bookLockOpen'),
  new IconDefinition(MdiIcons.bookMinus, 'bookMinus'),
  new IconDefinition(MdiIcons.bookMultiple, 'bookMultiple'),
  new IconDefinition(MdiIcons.bookMultipleMinus, 'bookMultipleMinus'),
  new IconDefinition(MdiIcons.bookMultiplePlus, 'bookMultiplePlus'),
  new IconDefinition(MdiIcons.bookMultipleRemove, 'bookMultipleRemove'),
  new IconDefinition(MdiIcons.bookMultipleVariant, 'bookMultipleVariant'),
  new IconDefinition(MdiIcons.bookOpen, 'bookOpen'),
  new IconDefinition(MdiIcons.bookOpenOutline, 'bookOpenOutline'),
  new IconDefinition(MdiIcons.bookOpenPageVariant, 'bookOpenPageVariant'),
  new IconDefinition(MdiIcons.bookOpenVariant, 'bookOpenVariant'),
  new IconDefinition(MdiIcons.bookOutline, 'bookOutline'),
  new IconDefinition(MdiIcons.bookPlus, 'bookPlus'),
  new IconDefinition(MdiIcons.bookRemove, 'bookRemove'),
  new IconDefinition(MdiIcons.bookVariant, 'bookVariant'),
  new IconDefinition(MdiIcons.bookmark, 'bookmark'),
  new IconDefinition(MdiIcons.bookmarkCheck, 'bookmarkCheck'),
  new IconDefinition(MdiIcons.bookmarkMinus, 'bookmarkMinus'),
  new IconDefinition(MdiIcons.bookmarkMinusOutline, 'bookmarkMinusOutline'),
  new IconDefinition(MdiIcons.bookmarkMusic, 'bookmarkMusic'),
  new IconDefinition(MdiIcons.bookmarkOff, 'bookmarkOff'),
  new IconDefinition(MdiIcons.bookmarkOffOutline, 'bookmarkOffOutline'),
  new IconDefinition(MdiIcons.bookmarkOutline, 'bookmarkOutline'),
  new IconDefinition(MdiIcons.bookmarkPlus, 'bookmarkPlus'),
  new IconDefinition(MdiIcons.bookmarkPlusOutline, 'bookmarkPlusOutline'),
  new IconDefinition(MdiIcons.bookmarkRemove, 'bookmarkRemove'),
  new IconDefinition(MdiIcons.boombox, 'boombox'),
  new IconDefinition(MdiIcons.bootstrap, 'bootstrap'),
  new IconDefinition(MdiIcons.borderAll, 'borderAll'),
  new IconDefinition(MdiIcons.borderAllVariant, 'borderAllVariant'),
  new IconDefinition(MdiIcons.borderBottom, 'borderBottom'),
  new IconDefinition(MdiIcons.borderBottomVariant, 'borderBottomVariant'),
  new IconDefinition(MdiIcons.borderColor, 'borderColor'),
  new IconDefinition(MdiIcons.borderHorizontal, 'borderHorizontal'),
  new IconDefinition(MdiIcons.borderInside, 'borderInside'),
  new IconDefinition(MdiIcons.borderLeft, 'borderLeft'),
  new IconDefinition(MdiIcons.borderLeftVariant, 'borderLeftVariant'),
  new IconDefinition(MdiIcons.borderNone, 'borderNone'),
  new IconDefinition(MdiIcons.borderNoneVariant, 'borderNoneVariant'),
  new IconDefinition(MdiIcons.borderOutside, 'borderOutside'),
  new IconDefinition(MdiIcons.borderRight, 'borderRight'),
  new IconDefinition(MdiIcons.borderRightVariant, 'borderRightVariant'),
  new IconDefinition(MdiIcons.borderStyle, 'borderStyle'),
  new IconDefinition(MdiIcons.borderTop, 'borderTop'),
  new IconDefinition(MdiIcons.borderTopVariant, 'borderTopVariant'),
  new IconDefinition(MdiIcons.borderVertical, 'borderVertical'),
  new IconDefinition(MdiIcons.bottleWine, 'bottleWine'),
  new IconDefinition(MdiIcons.bowTie, 'bowTie'),
  new IconDefinition(MdiIcons.bowl, 'bowl'),
  new IconDefinition(MdiIcons.bowling, 'bowling'),
  new IconDefinition(MdiIcons.box, 'box'),
  new IconDefinition(MdiIcons.boxCutter, 'boxCutter'),
  new IconDefinition(MdiIcons.boxShadow, 'boxShadow'),
  new IconDefinition(MdiIcons.boxingGlove, 'boxingGlove'),
  new IconDefinition(MdiIcons.braille, 'braille'),
  new IconDefinition(MdiIcons.brain, 'brain'),
  new IconDefinition(MdiIcons.bridge, 'bridge'),
  new IconDefinition(MdiIcons.briefcase, 'briefcase'),
  new IconDefinition(MdiIcons.briefcaseCheck, 'briefcaseCheck'),
  new IconDefinition(MdiIcons.briefcaseDownload, 'briefcaseDownload'),
  new IconDefinition(MdiIcons.briefcaseDownloadOutline, 'briefcaseDownloadOutline'),
  new IconDefinition(MdiIcons.briefcaseEdit, 'briefcaseEdit'),
  new IconDefinition(MdiIcons.briefcaseEditOutline, 'briefcaseEditOutline'),
  new IconDefinition(MdiIcons.briefcaseMinus, 'briefcaseMinus'),
  new IconDefinition(MdiIcons.briefcaseMinusOutline, 'briefcaseMinusOutline'),
  new IconDefinition(MdiIcons.briefcaseOutline, 'briefcaseOutline'),
  new IconDefinition(MdiIcons.briefcasePlus, 'briefcasePlus'),
  new IconDefinition(MdiIcons.briefcasePlusOutline, 'briefcasePlusOutline'),
  new IconDefinition(MdiIcons.briefcaseRemove, 'briefcaseRemove'),
  new IconDefinition(MdiIcons.briefcaseRemoveOutline, 'briefcaseRemoveOutline'),
  new IconDefinition(MdiIcons.briefcaseSearch, 'briefcaseSearch'),
  new IconDefinition(MdiIcons.briefcaseSearchOutline, 'briefcaseSearchOutline'),
  new IconDefinition(MdiIcons.briefcaseUpload, 'briefcaseUpload'),
  new IconDefinition(MdiIcons.briefcaseUploadOutline, 'briefcaseUploadOutline'),
  new IconDefinition(MdiIcons.brightness1, 'brightness1'),
  new IconDefinition(MdiIcons.brightness2, 'brightness2'),
  new IconDefinition(MdiIcons.brightness3, 'brightness3'),
  new IconDefinition(MdiIcons.brightness4, 'brightness4'),
  new IconDefinition(MdiIcons.brightness5, 'brightness5'),
  new IconDefinition(MdiIcons.brightness6, 'brightness6'),
  new IconDefinition(MdiIcons.brightness7, 'brightness7'),
  new IconDefinition(MdiIcons.brightnessAuto, 'brightnessAuto'),
  new IconDefinition(MdiIcons.broom, 'broom'),
  new IconDefinition(MdiIcons.brush, 'brush'),
  new IconDefinition(MdiIcons.buddhism, 'buddhism'),
  new IconDefinition(MdiIcons.buffer, 'buffer'),
  new IconDefinition(MdiIcons.bug, 'bug'),
  new IconDefinition(MdiIcons.bugCheck, 'bugCheck'),
  new IconDefinition(MdiIcons.bugCheckOutline, 'bugCheckOutline'),
  new IconDefinition(MdiIcons.bugOutline, 'bugOutline'),
  new IconDefinition(MdiIcons.bulldozer, 'bulldozer'),
  new IconDefinition(MdiIcons.bulletinBoard, 'bulletinBoard'),
  new IconDefinition(MdiIcons.bullhorn, 'bullhorn'),
  new IconDefinition(MdiIcons.bullhornOutline, 'bullhornOutline'),
  new IconDefinition(MdiIcons.bullseye, 'bullseye'),
  new IconDefinition(MdiIcons.bullseyeArrow, 'bullseyeArrow'),
  new IconDefinition(MdiIcons.bus, 'bus'),
  new IconDefinition(MdiIcons.busAlert, 'busAlert'),
  new IconDefinition(MdiIcons.busArticulatedEnd, 'busArticulatedEnd'),
  new IconDefinition(MdiIcons.busArticulatedFront, 'busArticulatedFront'),
  new IconDefinition(MdiIcons.busClock, 'busClock'),
  new IconDefinition(MdiIcons.busDoubleDecker, 'busDoubleDecker'),
  new IconDefinition(MdiIcons.busSchool, 'busSchool'),
  new IconDefinition(MdiIcons.busSide, 'busSide'),
  new IconDefinition(MdiIcons.cached, 'cached'),
  new IconDefinition(MdiIcons.cake, 'cake'),
  new IconDefinition(MdiIcons.cakeLayered, 'cakeLayered'),
  new IconDefinition(MdiIcons.cakeVariant, 'cakeVariant'),
  new IconDefinition(MdiIcons.calculator, 'calculator'),
  new IconDefinition(MdiIcons.calculatorVariant, 'calculatorVariant'),
  new IconDefinition(MdiIcons.calendar, 'calendar'),
  new IconDefinition(MdiIcons.calendarAlert, 'calendarAlert'),
  new IconDefinition(MdiIcons.calendarBlank, 'calendarBlank'),
  new IconDefinition(MdiIcons.calendarBlankOutline, 'calendarBlankOutline'),
  new IconDefinition(MdiIcons.calendarCheck, 'calendarCheck'),
  new IconDefinition(MdiIcons.calendarCheckOutline, 'calendarCheckOutline'),
  new IconDefinition(MdiIcons.calendarClock, 'calendarClock'),
  new IconDefinition(MdiIcons.calendarEdit, 'calendarEdit'),
  new IconDefinition(MdiIcons.calendarExport, 'calendarExport'),
  new IconDefinition(MdiIcons.calendarHeart, 'calendarHeart'),
  new IconDefinition(MdiIcons.calendarImport, 'calendarImport'),
  new IconDefinition(MdiIcons.calendarMultiple, 'calendarMultiple'),
  new IconDefinition(MdiIcons.calendarMultipleCheck, 'calendarMultipleCheck'),
  new IconDefinition(MdiIcons.calendarMultiselect, 'calendarMultiselect'),
  new IconDefinition(MdiIcons.calendarOutline, 'calendarOutline'),
  new IconDefinition(MdiIcons.calendarPlus, 'calendarPlus'),
  new IconDefinition(MdiIcons.calendarQuestion, 'calendarQuestion'),
  new IconDefinition(MdiIcons.calendarRange, 'calendarRange'),
  new IconDefinition(MdiIcons.calendarRangeOutline, 'calendarRangeOutline'),
  new IconDefinition(MdiIcons.calendarRemove, 'calendarRemove'),
  new IconDefinition(MdiIcons.calendarRemoveOutline, 'calendarRemoveOutline'),
  new IconDefinition(MdiIcons.calendarSearch, 'calendarSearch'),
  new IconDefinition(MdiIcons.calendarStar, 'calendarStar'),
  new IconDefinition(MdiIcons.calendarText, 'calendarText'),
  new IconDefinition(MdiIcons.calendarTextOutline, 'calendarTextOutline'),
  new IconDefinition(MdiIcons.calendarToday, 'calendarToday'),
  new IconDefinition(MdiIcons.calendarWeek, 'calendarWeek'),
  new IconDefinition(MdiIcons.calendarWeekBegin, 'calendarWeekBegin'),
  new IconDefinition(MdiIcons.callMade, 'callMade'),
  new IconDefinition(MdiIcons.callMerge, 'callMerge'),
  new IconDefinition(MdiIcons.callMissed, 'callMissed'),
  new IconDefinition(MdiIcons.callReceived, 'callReceived'),
  new IconDefinition(MdiIcons.callSplit, 'callSplit'),
  new IconDefinition(MdiIcons.camcorder, 'camcorder'),
  new IconDefinition(MdiIcons.camcorderBox, 'camcorderBox'),
  new IconDefinition(MdiIcons.camcorderBoxOff, 'camcorderBoxOff'),
  new IconDefinition(MdiIcons.camcorderOff, 'camcorderOff'),
  new IconDefinition(MdiIcons.camera, 'camera'),
  new IconDefinition(MdiIcons.cameraAccount, 'cameraAccount'),
  new IconDefinition(MdiIcons.cameraBurst, 'cameraBurst'),
  new IconDefinition(MdiIcons.cameraControl, 'cameraControl'),
  new IconDefinition(MdiIcons.cameraEnhance, 'cameraEnhance'),
  new IconDefinition(MdiIcons.cameraEnhanceOutline, 'cameraEnhanceOutline'),
  new IconDefinition(MdiIcons.cameraFront, 'cameraFront'),
  new IconDefinition(MdiIcons.cameraFrontVariant, 'cameraFrontVariant'),
  new IconDefinition(MdiIcons.cameraGopro, 'cameraGopro'),
  new IconDefinition(MdiIcons.cameraImage, 'cameraImage'),
  new IconDefinition(MdiIcons.cameraIris, 'cameraIris'),
  new IconDefinition(MdiIcons.cameraMeteringCenter, 'cameraMeteringCenter'),
  new IconDefinition(MdiIcons.cameraMeteringMatrix, 'cameraMeteringMatrix'),
  new IconDefinition(MdiIcons.cameraMeteringPartial, 'cameraMeteringPartial'),
  new IconDefinition(MdiIcons.cameraMeteringSpot, 'cameraMeteringSpot'),
  new IconDefinition(MdiIcons.cameraOff, 'cameraOff'),
  new IconDefinition(MdiIcons.cameraPartyMode, 'cameraPartyMode'),
  new IconDefinition(MdiIcons.cameraRear, 'cameraRear'),
  new IconDefinition(MdiIcons.cameraRearVariant, 'cameraRearVariant'),
  new IconDefinition(MdiIcons.cameraSwitch, 'cameraSwitch'),
  new IconDefinition(MdiIcons.cameraTimer, 'cameraTimer'),
  new IconDefinition(MdiIcons.cancel, 'cancel'),
  new IconDefinition(MdiIcons.candle, 'candle'),
  new IconDefinition(MdiIcons.candycane, 'candycane'),
  new IconDefinition(MdiIcons.cannabis, 'cannabis'),
  new IconDefinition(MdiIcons.capsLock, 'capsLock'),
  new IconDefinition(MdiIcons.car, 'car'),
  new IconDefinition(MdiIcons.carBattery, 'carBattery'),
  new IconDefinition(MdiIcons.carBrakeAbs, 'carBrakeAbs'),
  new IconDefinition(MdiIcons.carBrakeParking, 'carBrakeParking'),
  new IconDefinition(MdiIcons.carConnected, 'carConnected'),
  new IconDefinition(MdiIcons.carConvertible, 'carConvertible'),
  new IconDefinition(MdiIcons.carDoor, 'carDoor'),
  new IconDefinition(MdiIcons.carElectric, 'carElectric'),
  new IconDefinition(MdiIcons.carEsp, 'carEsp'),
  new IconDefinition(MdiIcons.carEstate, 'carEstate'),
  new IconDefinition(MdiIcons.carHatchback, 'carHatchback'),
  new IconDefinition(MdiIcons.carKey, 'carKey'),
  new IconDefinition(MdiIcons.carLightDimmed, 'carLightDimmed'),
  new IconDefinition(MdiIcons.carLightFog, 'carLightFog'),
  new IconDefinition(MdiIcons.carLightHigh, 'carLightHigh'),
  new IconDefinition(MdiIcons.carLimousine, 'carLimousine'),
  new IconDefinition(MdiIcons.carMultiple, 'carMultiple'),
  new IconDefinition(MdiIcons.carPickup, 'carPickup'),
  new IconDefinition(MdiIcons.carSide, 'carSide'),
  new IconDefinition(MdiIcons.carSports, 'carSports'),
  new IconDefinition(MdiIcons.carTireAlert, 'carTireAlert'),
  new IconDefinition(MdiIcons.carWash, 'carWash'),
  new IconDefinition(MdiIcons.caravan, 'caravan'),
  new IconDefinition(MdiIcons.card, 'card'),
  new IconDefinition(MdiIcons.cardBulleted, 'cardBulleted'),
  new IconDefinition(MdiIcons.cardBulletedOff, 'cardBulletedOff'),
  new IconDefinition(MdiIcons.cardBulletedOffOutline, 'cardBulletedOffOutline'),
  new IconDefinition(MdiIcons.cardBulletedOutline, 'cardBulletedOutline'),
  new IconDefinition(MdiIcons.cardBulletedSettings, 'cardBulletedSettings'),
  new IconDefinition(MdiIcons.cardBulletedSettingsOutline, 'cardBulletedSettingsOutline'),
  new IconDefinition(MdiIcons.cardOutline, 'cardOutline'),
  new IconDefinition(MdiIcons.cardText, 'cardText'),
  new IconDefinition(MdiIcons.cardTextOutline, 'cardTextOutline'),
  new IconDefinition(MdiIcons.cards, 'cards'),
  new IconDefinition(MdiIcons.cardsClub, 'cardsClub'),
  new IconDefinition(MdiIcons.cardsDiamond, 'cardsDiamond'),
  new IconDefinition(MdiIcons.cardsHeart, 'cardsHeart'),
  new IconDefinition(MdiIcons.cardsOutline, 'cardsOutline'),
  new IconDefinition(MdiIcons.cardsPlayingOutline, 'cardsPlayingOutline'),
  new IconDefinition(MdiIcons.cardsSpade, 'cardsSpade'),
  new IconDefinition(MdiIcons.cardsVariant, 'cardsVariant'),
  new IconDefinition(MdiIcons.carrot, 'carrot'),
  new IconDefinition(MdiIcons.cart, 'cart'),
  new IconDefinition(MdiIcons.cartArrowRight, 'cartArrowRight'),
  new IconDefinition(MdiIcons.cartOff, 'cartOff'),
  new IconDefinition(MdiIcons.cartOutline, 'cartOutline'),
  new IconDefinition(MdiIcons.cartPlus, 'cartPlus'),
  new IconDefinition(MdiIcons.caseSensitiveAlt, 'caseSensitiveAlt'),
  new IconDefinition(MdiIcons.cash, 'cash'),
  new IconDefinition(MdiIcons.cash100, 'cash100'),
  new IconDefinition(MdiIcons.cashMultiple, 'cashMultiple'),
  new IconDefinition(MdiIcons.cashRefund, 'cashRefund'),
  new IconDefinition(MdiIcons.cashUsd, 'cashUsd'),
  new IconDefinition(MdiIcons.cassette, 'cassette'),
  new IconDefinition(MdiIcons.cast, 'cast'),
  new IconDefinition(MdiIcons.castConnected, 'castConnected'),
  new IconDefinition(MdiIcons.castOff, 'castOff'),
  new IconDefinition(MdiIcons.castle, 'castle'),
  new IconDefinition(MdiIcons.cat, 'cat'),
  new IconDefinition(MdiIcons.cctv, 'cctv'),
  new IconDefinition(MdiIcons.ceilingLight, 'ceilingLight'),
  new IconDefinition(MdiIcons.cellphone, 'cellphone'),
  new IconDefinition(MdiIcons.cellphoneAndroid, 'cellphoneAndroid'),
  new IconDefinition(MdiIcons.cellphoneArrowDown, 'cellphoneArrowDown'),
  new IconDefinition(MdiIcons.cellphoneBasic, 'cellphoneBasic'),
  new IconDefinition(MdiIcons.cellphoneDock, 'cellphoneDock'),
  new IconDefinition(MdiIcons.cellphoneErase, 'cellphoneErase'),
  new IconDefinition(MdiIcons.cellphoneIphone, 'cellphoneIphone'),
  new IconDefinition(MdiIcons.cellphoneKey, 'cellphoneKey'),
  new IconDefinition(MdiIcons.cellphoneLink, 'cellphoneLink'),
  new IconDefinition(MdiIcons.cellphoneLinkOff, 'cellphoneLinkOff'),
  new IconDefinition(MdiIcons.cellphoneLock, 'cellphoneLock'),
  new IconDefinition(MdiIcons.cellphoneMessage, 'cellphoneMessage'),
  new IconDefinition(MdiIcons.cellphoneOff, 'cellphoneOff'),
  new IconDefinition(MdiIcons.cellphoneScreenshot, 'cellphoneScreenshot'),
  new IconDefinition(MdiIcons.cellphoneSettings, 'cellphoneSettings'),
  new IconDefinition(MdiIcons.cellphoneSettingsVariant, 'cellphoneSettingsVariant'),
  new IconDefinition(MdiIcons.cellphoneSound, 'cellphoneSound'),
  new IconDefinition(MdiIcons.cellphoneText, 'cellphoneText'),
  new IconDefinition(MdiIcons.cellphoneWireless, 'cellphoneWireless'),
  new IconDefinition(MdiIcons.certificate, 'certificate'),
  new IconDefinition(MdiIcons.chairSchool, 'chairSchool'),
  new IconDefinition(MdiIcons.charity, 'charity'),
  new IconDefinition(MdiIcons.chartArc, 'chartArc'),
  new IconDefinition(MdiIcons.chartAreaspline, 'chartAreaspline'),
  new IconDefinition(MdiIcons.chartBar, 'chartBar'),
  new IconDefinition(MdiIcons.chartBarStacked, 'chartBarStacked'),
  new IconDefinition(MdiIcons.chartBellCurve, 'chartBellCurve'),
  new IconDefinition(MdiIcons.chartBubble, 'chartBubble'),
  new IconDefinition(MdiIcons.chartDonut, 'chartDonut'),
  new IconDefinition(MdiIcons.chartDonutVariant, 'chartDonutVariant'),
  new IconDefinition(MdiIcons.chartGantt, 'chartGantt'),
  new IconDefinition(MdiIcons.chartHistogram, 'chartHistogram'),
  new IconDefinition(MdiIcons.chartLine, 'chartLine'),
  new IconDefinition(MdiIcons.chartLineStacked, 'chartLineStacked'),
  new IconDefinition(MdiIcons.chartLineVariant, 'chartLineVariant'),
  new IconDefinition(MdiIcons.chartMultiline, 'chartMultiline'),
  new IconDefinition(MdiIcons.chartPie, 'chartPie'),
  new IconDefinition(MdiIcons.chartScatterplotHexbin, 'chartScatterplotHexbin'),
  new IconDefinition(MdiIcons.chartTimeline, 'chartTimeline'),
  new IconDefinition(MdiIcons.chat, 'chat'),
  new IconDefinition(MdiIcons.chatAlert, 'chatAlert'),
  new IconDefinition(MdiIcons.chatProcessing, 'chatProcessing'),
  new IconDefinition(MdiIcons.check, 'check'),
  new IconDefinition(MdiIcons.checkAll, 'checkAll'),
  new IconDefinition(MdiIcons.checkBoxMultipleOutline, 'checkBoxMultipleOutline'),
  new IconDefinition(MdiIcons.checkBoxOutline, 'checkBoxOutline'),
  new IconDefinition(MdiIcons.checkCircle, 'checkCircle'),
  new IconDefinition(MdiIcons.checkCircleOutline, 'checkCircleOutline'),
  new IconDefinition(MdiIcons.checkDecagram, 'checkDecagram'),
  new IconDefinition(MdiIcons.checkNetwork, 'checkNetwork'),
  new IconDefinition(MdiIcons.checkNetworkOutline, 'checkNetworkOutline'),
  new IconDefinition(MdiIcons.checkOutline, 'checkOutline'),
  new IconDefinition(MdiIcons.checkbook, 'checkbook'),
  new IconDefinition(MdiIcons.checkboxBlank, 'checkboxBlank'),
  new IconDefinition(MdiIcons.checkboxBlankCircle, 'checkboxBlankCircle'),
  new IconDefinition(MdiIcons.checkboxBlankCircleOutline, 'checkboxBlankCircleOutline'),
  new IconDefinition(MdiIcons.checkboxBlankOutline, 'checkboxBlankOutline'),
  new IconDefinition(MdiIcons.checkboxIntermediate, 'checkboxIntermediate'),
  new IconDefinition(MdiIcons.checkboxMarked, 'checkboxMarked'),
  new IconDefinition(MdiIcons.checkboxMarkedCircle, 'checkboxMarkedCircle'),
  new IconDefinition(MdiIcons.checkboxMarkedCircleOutline, 'checkboxMarkedCircleOutline'),
  new IconDefinition(MdiIcons.checkboxMarkedOutline, 'checkboxMarkedOutline'),
  new IconDefinition(MdiIcons.checkboxMultipleBlank, 'checkboxMultipleBlank'),
  new IconDefinition(MdiIcons.checkboxMultipleBlankCircle, 'checkboxMultipleBlankCircle'),
  new IconDefinition(MdiIcons.checkboxMultipleBlankCircleOutline, 'checkboxMultipleBlankCircleOutline'),
  new IconDefinition(MdiIcons.checkboxMultipleBlankOutline, 'checkboxMultipleBlankOutline'),
  new IconDefinition(MdiIcons.checkboxMultipleMarked, 'checkboxMultipleMarked'),
  new IconDefinition(MdiIcons.checkboxMultipleMarkedCircle, 'checkboxMultipleMarkedCircle'),
  new IconDefinition(MdiIcons.checkboxMultipleMarkedCircleOutline, 'checkboxMultipleMarkedCircleOutline'),
  new IconDefinition(MdiIcons.checkboxMultipleMarkedOutline, 'checkboxMultipleMarkedOutline'),
  new IconDefinition(MdiIcons.checkerboard, 'checkerboard'),
  new IconDefinition(MdiIcons.chefHat, 'chefHat'),
  new IconDefinition(MdiIcons.chemicalWeapon, 'chemicalWeapon'),
  new IconDefinition(MdiIcons.chessBishop, 'chessBishop'),
  new IconDefinition(MdiIcons.chessKing, 'chessKing'),
  new IconDefinition(MdiIcons.chessKnight, 'chessKnight'),
  new IconDefinition(MdiIcons.chessPawn, 'chessPawn'),
  new IconDefinition(MdiIcons.chessQueen, 'chessQueen'),
  new IconDefinition(MdiIcons.chessRook, 'chessRook'),
  new IconDefinition(MdiIcons.chevronDoubleDown, 'chevronDoubleDown'),
  new IconDefinition(MdiIcons.chevronDoubleLeft, 'chevronDoubleLeft'),
  new IconDefinition(MdiIcons.chevronDoubleRight, 'chevronDoubleRight'),
  new IconDefinition(MdiIcons.chevronDoubleUp, 'chevronDoubleUp'),
  new IconDefinition(MdiIcons.chevronDown, 'chevronDown'),
  new IconDefinition(MdiIcons.chevronDownBox, 'chevronDownBox'),
  new IconDefinition(MdiIcons.chevronDownBoxOutline, 'chevronDownBoxOutline'),
  new IconDefinition(MdiIcons.chevronDownCircle, 'chevronDownCircle'),
  new IconDefinition(MdiIcons.chevronDownCircleOutline, 'chevronDownCircleOutline'),
  new IconDefinition(MdiIcons.chevronLeft, 'chevronLeft'),
  new IconDefinition(MdiIcons.chevronLeftBox, 'chevronLeftBox'),
  new IconDefinition(MdiIcons.chevronLeftBoxOutline, 'chevronLeftBoxOutline'),
  new IconDefinition(MdiIcons.chevronLeftCircle, 'chevronLeftCircle'),
  new IconDefinition(MdiIcons.chevronLeftCircleOutline, 'chevronLeftCircleOutline'),
  new IconDefinition(MdiIcons.chevronRight, 'chevronRight'),
  new IconDefinition(MdiIcons.chevronRightBox, 'chevronRightBox'),
  new IconDefinition(MdiIcons.chevronRightBoxOutline, 'chevronRightBoxOutline'),
  new IconDefinition(MdiIcons.chevronRightCircle, 'chevronRightCircle'),
  new IconDefinition(MdiIcons.chevronRightCircleOutline, 'chevronRightCircleOutline'),
  new IconDefinition(MdiIcons.chevronUp, 'chevronUp'),
  new IconDefinition(MdiIcons.chevronUpBox, 'chevronUpBox'),
  new IconDefinition(MdiIcons.chevronUpBoxOutline, 'chevronUpBoxOutline'),
  new IconDefinition(MdiIcons.chevronUpCircle, 'chevronUpCircle'),
  new IconDefinition(MdiIcons.chevronUpCircleOutline, 'chevronUpCircleOutline'),
  new IconDefinition(MdiIcons.chiliHot, 'chiliHot'),
  new IconDefinition(MdiIcons.chiliMedium, 'chiliMedium'),
  new IconDefinition(MdiIcons.chiliMild, 'chiliMild'),
  new IconDefinition(MdiIcons.chip, 'chip'),
  new IconDefinition(MdiIcons.christianity, 'christianity'),
  new IconDefinition(MdiIcons.church, 'church'),
  new IconDefinition(MdiIcons.circle, 'circle'),
  new IconDefinition(MdiIcons.circleEditOutline, 'circleEditOutline'),
  new IconDefinition(MdiIcons.circleMedium, 'circleMedium'),
  new IconDefinition(MdiIcons.circleOutline, 'circleOutline'),
  new IconDefinition(MdiIcons.circleSlice1, 'circleSlice1'),
  new IconDefinition(MdiIcons.circleSlice2, 'circleSlice2'),
  new IconDefinition(MdiIcons.circleSlice3, 'circleSlice3'),
  new IconDefinition(MdiIcons.circleSlice4, 'circleSlice4'),
  new IconDefinition(MdiIcons.circleSlice5, 'circleSlice5'),
  new IconDefinition(MdiIcons.circleSlice6, 'circleSlice6'),
  new IconDefinition(MdiIcons.circleSlice7, 'circleSlice7'),
  new IconDefinition(MdiIcons.circleSlice8, 'circleSlice8'),
  new IconDefinition(MdiIcons.circleSmall, 'circleSmall'),
  new IconDefinition(MdiIcons.ciscoWebex, 'ciscoWebex'),
  new IconDefinition(MdiIcons.city, 'city'),
  new IconDefinition(MdiIcons.cityVariant, 'cityVariant'),
  new IconDefinition(MdiIcons.cityVariantOutline, 'cityVariantOutline'),
  new IconDefinition(MdiIcons.clipboard, 'clipboard'),
  new IconDefinition(MdiIcons.clipboardAccount, 'clipboardAccount'),
  new IconDefinition(MdiIcons.clipboardAccountOutline, 'clipboardAccountOutline'),
  new IconDefinition(MdiIcons.clipboardAlert, 'clipboardAlert'),
  new IconDefinition(MdiIcons.clipboardArrowDown, 'clipboardArrowDown'),
  new IconDefinition(MdiIcons.clipboardArrowDownOutline, 'clipboardArrowDownOutline'),
  new IconDefinition(MdiIcons.clipboardArrowLeft, 'clipboardArrowLeft'),
  new IconDefinition(MdiIcons.clipboardArrowUp, 'clipboardArrowUp'),
  new IconDefinition(MdiIcons.clipboardArrowUpOutline, 'clipboardArrowUpOutline'),
  new IconDefinition(MdiIcons.clipboardCheck, 'clipboardCheck'),
  new IconDefinition(MdiIcons.clipboardCheckOutline, 'clipboardCheckOutline'),
  new IconDefinition(MdiIcons.clipboardFlow, 'clipboardFlow'),
  new IconDefinition(MdiIcons.clipboardOutline, 'clipboardOutline'),
  new IconDefinition(MdiIcons.clipboardPlay, 'clipboardPlay'),
  new IconDefinition(MdiIcons.clipboardPlayOutline, 'clipboardPlayOutline'),
  new IconDefinition(MdiIcons.clipboardPlus, 'clipboardPlus'),
  new IconDefinition(MdiIcons.clipboardPulse, 'clipboardPulse'),
  new IconDefinition(MdiIcons.clipboardPulseOutline, 'clipboardPulseOutline'),
  new IconDefinition(MdiIcons.clipboardText, 'clipboardText'),
  new IconDefinition(MdiIcons.clipboardTextOutline, 'clipboardTextOutline'),
  new IconDefinition(MdiIcons.clipboardTextPlay, 'clipboardTextPlay'),
  new IconDefinition(MdiIcons.clipboardTextPlayOutline, 'clipboardTextPlayOutline'),
  new IconDefinition(MdiIcons.clippy, 'clippy'),
  new IconDefinition(MdiIcons.clock, 'clock'),
  new IconDefinition(MdiIcons.clockAlert, 'clockAlert'),
  new IconDefinition(MdiIcons.clockAlertOutline, 'clockAlertOutline'),
  new IconDefinition(MdiIcons.clockEnd, 'clockEnd'),
  new IconDefinition(MdiIcons.clockFast, 'clockFast'),
  new IconDefinition(MdiIcons.clockIn, 'clockIn'),
  new IconDefinition(MdiIcons.clockOut, 'clockOut'),
  new IconDefinition(MdiIcons.clockOutline, 'clockOutline'),
  new IconDefinition(MdiIcons.clockStart, 'clockStart'),
  new IconDefinition(MdiIcons.close, 'close'),
  new IconDefinition(MdiIcons.closeBox, 'closeBox'),
  new IconDefinition(MdiIcons.closeBoxMultiple, 'closeBoxMultiple'),
  new IconDefinition(MdiIcons.closeBoxMultipleOutline, 'closeBoxMultipleOutline'),
  new IconDefinition(MdiIcons.closeBoxOutline, 'closeBoxOutline'),
  new IconDefinition(MdiIcons.closeCircle, 'closeCircle'),
  new IconDefinition(MdiIcons.closeCircleOutline, 'closeCircleOutline'),
  new IconDefinition(MdiIcons.closeNetwork, 'closeNetwork'),
  new IconDefinition(MdiIcons.closeNetworkOutline, 'closeNetworkOutline'),
  new IconDefinition(MdiIcons.closeOctagon, 'closeOctagon'),
  new IconDefinition(MdiIcons.closeOctagonOutline, 'closeOctagonOutline'),
  new IconDefinition(MdiIcons.closeOutline, 'closeOutline'),
  new IconDefinition(MdiIcons.closedCaption, 'closedCaption'),
  new IconDefinition(MdiIcons.cloud, 'cloud'),
  new IconDefinition(MdiIcons.cloudAlert, 'cloudAlert'),
  new IconDefinition(MdiIcons.cloudBraces, 'cloudBraces'),
  new IconDefinition(MdiIcons.cloudCheck, 'cloudCheck'),
  new IconDefinition(MdiIcons.cloudCircle, 'cloudCircle'),
  new IconDefinition(MdiIcons.cloudDownload, 'cloudDownload'),
  new IconDefinition(MdiIcons.cloudDownloadOutline, 'cloudDownloadOutline'),
  new IconDefinition(MdiIcons.cloudOffOutline, 'cloudOffOutline'),
  new IconDefinition(MdiIcons.cloudOutline, 'cloudOutline'),
  new IconDefinition(MdiIcons.cloudPrint, 'cloudPrint'),
  new IconDefinition(MdiIcons.cloudPrintOutline, 'cloudPrintOutline'),
  new IconDefinition(MdiIcons.cloudQuestion, 'cloudQuestion'),
  new IconDefinition(MdiIcons.cloudSearch, 'cloudSearch'),
  new IconDefinition(MdiIcons.cloudSearchOutline, 'cloudSearchOutline'),
  new IconDefinition(MdiIcons.cloudSync, 'cloudSync'),
  new IconDefinition(MdiIcons.cloudTags, 'cloudTags'),
  new IconDefinition(MdiIcons.cloudUpload, 'cloudUpload'),
  new IconDefinition(MdiIcons.cloudUploadOutline, 'cloudUploadOutline'),
  new IconDefinition(MdiIcons.clover, 'clover'),
  new IconDefinition(MdiIcons.codeArray, 'codeArray'),
  new IconDefinition(MdiIcons.codeBraces, 'codeBraces'),
  new IconDefinition(MdiIcons.codeBrackets, 'codeBrackets'),
  new IconDefinition(MdiIcons.codeEqual, 'codeEqual'),
  new IconDefinition(MdiIcons.codeGreaterThan, 'codeGreaterThan'),
  new IconDefinition(MdiIcons.codeGreaterThanOrEqual, 'codeGreaterThanOrEqual'),
  new IconDefinition(MdiIcons.codeLessThan, 'codeLessThan'),
  new IconDefinition(MdiIcons.codeLessThanOrEqual, 'codeLessThanOrEqual'),
  new IconDefinition(MdiIcons.codeNotEqual, 'codeNotEqual'),
  new IconDefinition(MdiIcons.codeNotEqualVariant, 'codeNotEqualVariant'),
  new IconDefinition(MdiIcons.codeParentheses, 'codeParentheses'),
  new IconDefinition(MdiIcons.codeString, 'codeString'),
  new IconDefinition(MdiIcons.codeTags, 'codeTags'),
  new IconDefinition(MdiIcons.codeTagsCheck, 'codeTagsCheck'),
  new IconDefinition(MdiIcons.codepen, 'codepen'),
  new IconDefinition(MdiIcons.coffee, 'coffee'),
  new IconDefinition(MdiIcons.coffeeOutline, 'coffeeOutline'),
  new IconDefinition(MdiIcons.coffeeToGo, 'coffeeToGo'),
  new IconDefinition(MdiIcons.coffin, 'coffin'),
  new IconDefinition(MdiIcons.cogs, 'cogs'),
  new IconDefinition(MdiIcons.coin, 'coin'),
  new IconDefinition(MdiIcons.coins, 'coins'),
  new IconDefinition(MdiIcons.collage, 'collage'),
  new IconDefinition(MdiIcons.collapseAll, 'collapseAll'),
  new IconDefinition(MdiIcons.collapseAllOutline, 'collapseAllOutline'),
  new IconDefinition(MdiIcons.colorHelper, 'colorHelper'),
  new IconDefinition(MdiIcons.comment, 'comment'),
  new IconDefinition(MdiIcons.commentAccount, 'commentAccount'),
  new IconDefinition(MdiIcons.commentAccountOutline, 'commentAccountOutline'),
  new IconDefinition(MdiIcons.commentAlert, 'commentAlert'),
  new IconDefinition(MdiIcons.commentAlertOutline, 'commentAlertOutline'),
  new IconDefinition(MdiIcons.commentArrowLeft, 'commentArrowLeft'),
  new IconDefinition(MdiIcons.commentArrowLeftOutline, 'commentArrowLeftOutline'),
  new IconDefinition(MdiIcons.commentArrowRight, 'commentArrowRight'),
  new IconDefinition(MdiIcons.commentArrowRightOutline, 'commentArrowRightOutline'),
  new IconDefinition(MdiIcons.commentCheck, 'commentCheck'),
  new IconDefinition(MdiIcons.commentCheckOutline, 'commentCheckOutline'),
  new IconDefinition(MdiIcons.commentEye, 'commentEye'),
  new IconDefinition(MdiIcons.commentEyeOutline, 'commentEyeOutline'),
  new IconDefinition(MdiIcons.commentMultiple, 'commentMultiple'),
  new IconDefinition(MdiIcons.commentMultipleOutline, 'commentMultipleOutline'),
  new IconDefinition(MdiIcons.commentOutline, 'commentOutline'),
  new IconDefinition(MdiIcons.commentPlus, 'commentPlus'),
  new IconDefinition(MdiIcons.commentPlusOutline, 'commentPlusOutline'),
  new IconDefinition(MdiIcons.commentProcessing, 'commentProcessing'),
  new IconDefinition(MdiIcons.commentProcessingOutline, 'commentProcessingOutline'),
  new IconDefinition(MdiIcons.commentQuestion, 'commentQuestion'),
  new IconDefinition(MdiIcons.commentQuestionOutline, 'commentQuestionOutline'),
  new IconDefinition(MdiIcons.commentRemove, 'commentRemove'),
  new IconDefinition(MdiIcons.commentRemoveOutline, 'commentRemoveOutline'),
  new IconDefinition(MdiIcons.commentSearch, 'commentSearch'),
  new IconDefinition(MdiIcons.commentSearchOutline, 'commentSearchOutline'),
  new IconDefinition(MdiIcons.commentText, 'commentText'),
  new IconDefinition(MdiIcons.commentTextMultiple, 'commentTextMultiple'),
  new IconDefinition(MdiIcons.commentTextMultipleOutline, 'commentTextMultipleOutline'),
  new IconDefinition(MdiIcons.commentTextOutline, 'commentTextOutline'),
  new IconDefinition(MdiIcons.compare, 'compare'),
  new IconDefinition(MdiIcons.compass, 'compass'),
  new IconDefinition(MdiIcons.compassOff, 'compassOff'),
  new IconDefinition(MdiIcons.compassOffOutline, 'compassOffOutline'),
  new IconDefinition(MdiIcons.compassOutline, 'compassOutline'),
  new IconDefinition(MdiIcons.console, 'console'),
  new IconDefinition(MdiIcons.consoleLine, 'consoleLine'),
  new IconDefinition(MdiIcons.consoleNetwork, 'consoleNetwork'),
  new IconDefinition(MdiIcons.consoleNetworkOutline, 'consoleNetworkOutline'),
  new IconDefinition(MdiIcons.contactMail, 'contactMail'),
  new IconDefinition(MdiIcons.contacts, 'contacts'),
  new IconDefinition(MdiIcons.contain, 'contain'),
  new IconDefinition(MdiIcons.containEnd, 'containEnd'),
  new IconDefinition(MdiIcons.containStart, 'containStart'),
  new IconDefinition(MdiIcons.contentCopy, 'contentCopy'),
  new IconDefinition(MdiIcons.contentCut, 'contentCut'),
  new IconDefinition(MdiIcons.contentDuplicate, 'contentDuplicate'),
  new IconDefinition(MdiIcons.contentPaste, 'contentPaste'),
  new IconDefinition(MdiIcons.contentSave, 'contentSave'),
  new IconDefinition(MdiIcons.contentSaveAll, 'contentSaveAll'),
  new IconDefinition(MdiIcons.contentSaveOutline, 'contentSaveOutline'),
  new IconDefinition(MdiIcons.contentSaveSettings, 'contentSaveSettings'),
  new IconDefinition(MdiIcons.contentSaveSettingsOutline, 'contentSaveSettingsOutline'),
  new IconDefinition(MdiIcons.contrast, 'contrast'),
  new IconDefinition(MdiIcons.contrastBox, 'contrastBox'),
  new IconDefinition(MdiIcons.contrastCircle, 'contrastCircle'),
  new IconDefinition(MdiIcons.controllerClassic, 'controllerClassic'),
  new IconDefinition(MdiIcons.controllerClassicOutline, 'controllerClassicOutline'),
  new IconDefinition(MdiIcons.cookie, 'cookie'),
  new IconDefinition(MdiIcons.copyright, 'copyright'),
  new IconDefinition(MdiIcons.cordova, 'cordova'),
  new IconDefinition(MdiIcons.corn, 'corn'),
  new IconDefinition(MdiIcons.counter, 'counter'),
  new IconDefinition(MdiIcons.cow, 'cow'),
  new IconDefinition(MdiIcons.crane, 'crane'),
  new IconDefinition(MdiIcons.creation, 'creation'),
  new IconDefinition(MdiIcons.creditCard, 'creditCard'),
  new IconDefinition(MdiIcons.creditCardMultiple, 'creditCardMultiple'),
  new IconDefinition(MdiIcons.creditCardOff, 'creditCardOff'),
  new IconDefinition(MdiIcons.creditCardPlus, 'creditCardPlus'),
  new IconDefinition(MdiIcons.creditCardRefund, 'creditCardRefund'),
  new IconDefinition(MdiIcons.creditCardScan, 'creditCardScan'),
  new IconDefinition(MdiIcons.creditCardSettings, 'creditCardSettings'),
  new IconDefinition(MdiIcons.crop, 'crop'),
  new IconDefinition(MdiIcons.cropFree, 'cropFree'),
  new IconDefinition(MdiIcons.cropLandscape, 'cropLandscape'),
  new IconDefinition(MdiIcons.cropPortrait, 'cropPortrait'),
  new IconDefinition(MdiIcons.cropRotate, 'cropRotate'),
  new IconDefinition(MdiIcons.cropSquare, 'cropSquare'),
  new IconDefinition(MdiIcons.crosshairs, 'crosshairs'),
  new IconDefinition(MdiIcons.crosshairsGps, 'crosshairsGps'),
  new IconDefinition(MdiIcons.crown, 'crown'),
  new IconDefinition(MdiIcons.cryengine, 'cryengine'),
  new IconDefinition(MdiIcons.crystalBall, 'crystalBall'),
  new IconDefinition(MdiIcons.cube, 'cube'),
  new IconDefinition(MdiIcons.cubeOutline, 'cubeOutline'),
  new IconDefinition(MdiIcons.cubeScan, 'cubeScan'),
  new IconDefinition(MdiIcons.cubeSend, 'cubeSend'),
  new IconDefinition(MdiIcons.cubeUnfolded, 'cubeUnfolded'),
  new IconDefinition(MdiIcons.cup, 'cup'),
  new IconDefinition(MdiIcons.cupOff, 'cupOff'),
  new IconDefinition(MdiIcons.cupWater, 'cupWater'),
  new IconDefinition(MdiIcons.cupcake, 'cupcake'),
  new IconDefinition(MdiIcons.curling, 'curling'),
  new IconDefinition(MdiIcons.currencyBdt, 'currencyBdt'),
  new IconDefinition(MdiIcons.currencyBrl, 'currencyBrl'),
  new IconDefinition(MdiIcons.currencyBtc, 'currencyBtc'),
  new IconDefinition(MdiIcons.currencyChf, 'currencyChf'),
  new IconDefinition(MdiIcons.currencyCny, 'currencyCny'),
  new IconDefinition(MdiIcons.currencyEth, 'currencyEth'),
  new IconDefinition(MdiIcons.currencyEur, 'currencyEur'),
  new IconDefinition(MdiIcons.currencyGbp, 'currencyGbp'),
  new IconDefinition(MdiIcons.currencyIls, 'currencyIls'),
  new IconDefinition(MdiIcons.currencyInr, 'currencyInr'),
  new IconDefinition(MdiIcons.currencyJpy, 'currencyJpy'),
  new IconDefinition(MdiIcons.currencyKrw, 'currencyKrw'),
  new IconDefinition(MdiIcons.currencyKzt, 'currencyKzt'),
  new IconDefinition(MdiIcons.currencyNgn, 'currencyNgn'),
  new IconDefinition(MdiIcons.currencyPhp, 'currencyPhp'),
  new IconDefinition(MdiIcons.currencyRub, 'currencyRub'),
  new IconDefinition(MdiIcons.currencySign, 'currencySign'),
  new IconDefinition(MdiIcons.currencyTry, 'currencyTry'),
  new IconDefinition(MdiIcons.currencyTwd, 'currencyTwd'),
  new IconDefinition(MdiIcons.currencyUsd, 'currencyUsd'),
  new IconDefinition(MdiIcons.currencyUsdOff, 'currencyUsdOff'),
  new IconDefinition(MdiIcons.currentAc, 'currentAc'),
  new IconDefinition(MdiIcons.currentDc, 'currentDc'),
  new IconDefinition(MdiIcons.cursorDefault, 'cursorDefault'),
  new IconDefinition(MdiIcons.cursorDefaultOutline, 'cursorDefaultOutline'),
  new IconDefinition(MdiIcons.cursorMove, 'cursorMove'),
  new IconDefinition(MdiIcons.cursorPointer, 'cursorPointer'),
  new IconDefinition(MdiIcons.cursorText, 'cursorText'),
  new IconDefinition(MdiIcons.database, 'database'),
  new IconDefinition(MdiIcons.databaseCheck, 'databaseCheck'),
  new IconDefinition(MdiIcons.databaseEdit, 'databaseEdit'),
  new IconDefinition(MdiIcons.databaseExport, 'databaseExport'),
  new IconDefinition(MdiIcons.databaseImport, 'databaseImport'),
  new IconDefinition(MdiIcons.databaseLock, 'databaseLock'),
  new IconDefinition(MdiIcons.databaseMinus, 'databaseMinus'),
  new IconDefinition(MdiIcons.databasePlus, 'databasePlus'),
  new IconDefinition(MdiIcons.databaseSearch, 'databaseSearch'),
  new IconDefinition(MdiIcons.deathStar, 'deathStar'),
  new IconDefinition(MdiIcons.deathStarVariant, 'deathStarVariant'),
  new IconDefinition(MdiIcons.deathlyHallows, 'deathlyHallows'),
  new IconDefinition(MdiIcons.debian, 'debian'),
  new IconDefinition(MdiIcons.debugStepInto, 'debugStepInto'),
  new IconDefinition(MdiIcons.debugStepOut, 'debugStepOut'),
  new IconDefinition(MdiIcons.debugStepOver, 'debugStepOver'),
  new IconDefinition(MdiIcons.decagram, 'decagram'),
  new IconDefinition(MdiIcons.decagramOutline, 'decagramOutline'),
  new IconDefinition(MdiIcons.decimalDecrease, 'decimalDecrease'),
  new IconDefinition(MdiIcons.decimalIncrease, 'decimalIncrease'),
  new IconDefinition(MdiIcons.delete, 'delete'),
  new IconDefinition(MdiIcons.deleteCircle, 'deleteCircle'),
  new IconDefinition(MdiIcons.deleteCircleOutline, 'deleteCircleOutline'),
  new IconDefinition(MdiIcons.deleteEmpty, 'deleteEmpty'),
  new IconDefinition(MdiIcons.deleteForever, 'deleteForever'),
  new IconDefinition(MdiIcons.deleteForeverOutline, 'deleteForeverOutline'),
  new IconDefinition(MdiIcons.deleteOutline, 'deleteOutline'),
  new IconDefinition(MdiIcons.deleteRestore, 'deleteRestore'),
  new IconDefinition(MdiIcons.deleteSweep, 'deleteSweep'),
  new IconDefinition(MdiIcons.deleteSweepOutline, 'deleteSweepOutline'),
  new IconDefinition(MdiIcons.deleteVariant, 'deleteVariant'),
  new IconDefinition(MdiIcons.delta, 'delta'),
  new IconDefinition(MdiIcons.deskLamp, 'deskLamp'),
  new IconDefinition(MdiIcons.deskphone, 'deskphone'),
  new IconDefinition(MdiIcons.desktopClassic, 'desktopClassic'),
  new IconDefinition(MdiIcons.desktopMac, 'desktopMac'),
  new IconDefinition(MdiIcons.desktopMacDashboard, 'desktopMacDashboard'),
  new IconDefinition(MdiIcons.desktopTower, 'desktopTower'),
  new IconDefinition(MdiIcons.desktopTowerMonitor, 'desktopTowerMonitor'),
  new IconDefinition(MdiIcons.details, 'details'),
  new IconDefinition(MdiIcons.developerBoard, 'developerBoard'),
  new IconDefinition(MdiIcons.deviantart, 'deviantart'),
  new IconDefinition(MdiIcons.dialpad, 'dialpad'),
  new IconDefinition(MdiIcons.diameter, 'diameter'),
  new IconDefinition(MdiIcons.diameterOutline, 'diameterOutline'),
  new IconDefinition(MdiIcons.diameterVariant, 'diameterVariant'),
  new IconDefinition(MdiIcons.diamond, 'diamond'),
  new IconDefinition(MdiIcons.diamondOutline, 'diamondOutline'),
  new IconDefinition(MdiIcons.diamondStone, 'diamondStone'),
  new IconDefinition(MdiIcons.dice1, 'dice1'),
  new IconDefinition(MdiIcons.dice2, 'dice2'),
  new IconDefinition(MdiIcons.dice3, 'dice3'),
  new IconDefinition(MdiIcons.dice4, 'dice4'),
  new IconDefinition(MdiIcons.dice5, 'dice5'),
  new IconDefinition(MdiIcons.dice6, 'dice6'),
  new IconDefinition(MdiIcons.diceD10, 'diceD10'),
  new IconDefinition(MdiIcons.diceD12, 'diceD12'),
  new IconDefinition(MdiIcons.diceD20, 'diceD20'),
  new IconDefinition(MdiIcons.diceD4, 'diceD4'),
  new IconDefinition(MdiIcons.diceD6, 'diceD6'),
  new IconDefinition(MdiIcons.diceD8, 'diceD8'),
  new IconDefinition(MdiIcons.diceMultiple, 'diceMultiple'),
  new IconDefinition(MdiIcons.dictionary, 'dictionary'),
  new IconDefinition(MdiIcons.dipSwitch, 'dipSwitch'),
  new IconDefinition(MdiIcons.directions, 'directions'),
  new IconDefinition(MdiIcons.directionsFork, 'directionsFork'),
  new IconDefinition(MdiIcons.disc, 'disc'),
  new IconDefinition(MdiIcons.discAlert, 'discAlert'),
  new IconDefinition(MdiIcons.discPlayer, 'discPlayer'),
  new IconDefinition(MdiIcons.discord, 'discord'),
  new IconDefinition(MdiIcons.dishwasher, 'dishwasher'),
  new IconDefinition(MdiIcons.disqus, 'disqus'),
  new IconDefinition(MdiIcons.disqusOutline, 'disqusOutline'),
  new IconDefinition(MdiIcons.division, 'division'),
  new IconDefinition(MdiIcons.divisionBox, 'divisionBox'),
  new IconDefinition(MdiIcons.dlna, 'dlna'),
  new IconDefinition(MdiIcons.dna, 'dna'),
  new IconDefinition(MdiIcons.dns, 'dns'),
  new IconDefinition(MdiIcons.dnsOutline, 'dnsOutline'),
  new IconDefinition(MdiIcons.doNotDisturb, 'doNotDisturb'),
  new IconDefinition(MdiIcons.doNotDisturbOff, 'doNotDisturbOff'),
  new IconDefinition(MdiIcons.docker, 'docker'),
  new IconDefinition(MdiIcons.doctor, 'doctor'),
  new IconDefinition(MdiIcons.dog, 'dog'),
  new IconDefinition(MdiIcons.dogService, 'dogService'),
  new IconDefinition(MdiIcons.dogSide, 'dogSide'),
  new IconDefinition(MdiIcons.dolby, 'dolby'),
  new IconDefinition(MdiIcons.domain, 'domain'),
  new IconDefinition(MdiIcons.donkey, 'donkey'),
  new IconDefinition(MdiIcons.door, 'door'),
  new IconDefinition(MdiIcons.doorClosed, 'doorClosed'),
  new IconDefinition(MdiIcons.doorOpen, 'doorOpen'),
  new IconDefinition(MdiIcons.doorbellVideo, 'doorbellVideo'),
  new IconDefinition(MdiIcons.dotNet, 'dotNet'),
  new IconDefinition(MdiIcons.dotsHorizontal, 'dotsHorizontal'),
  new IconDefinition(MdiIcons.dotsHorizontalCircle, 'dotsHorizontalCircle'),
  new IconDefinition(MdiIcons.dotsHorizontalCircleOutline, 'dotsHorizontalCircleOutline'),
  new IconDefinition(MdiIcons.dotsVertical, 'dotsVertical'),
  new IconDefinition(MdiIcons.dotsVerticalCircle, 'dotsVerticalCircle'),
  new IconDefinition(MdiIcons.dotsVerticalCircleOutline, 'dotsVerticalCircleOutline'),
  new IconDefinition(MdiIcons.douban, 'douban'),
  new IconDefinition(MdiIcons.download, 'download'),
  new IconDefinition(MdiIcons.downloadMultiple, 'downloadMultiple'),
  new IconDefinition(MdiIcons.downloadNetwork, 'downloadNetwork'),
  new IconDefinition(MdiIcons.downloadNetworkOutline, 'downloadNetworkOutline'),
  new IconDefinition(MdiIcons.downloadOutline, 'downloadOutline'),
  new IconDefinition(MdiIcons.drag, 'drag'),
  new IconDefinition(MdiIcons.dragHorizontal, 'dragHorizontal'),
  new IconDefinition(MdiIcons.dragVariant, 'dragVariant'),
  new IconDefinition(MdiIcons.dragVertical, 'dragVertical'),
  new IconDefinition(MdiIcons.drawing, 'drawing'),
  new IconDefinition(MdiIcons.drawingBox, 'drawingBox'),
  new IconDefinition(MdiIcons.dribbble, 'dribbble'),
  new IconDefinition(MdiIcons.dribbbleBox, 'dribbbleBox'),
  new IconDefinition(MdiIcons.drone, 'drone'),
  new IconDefinition(MdiIcons.dropbox, 'dropbox'),
  new IconDefinition(MdiIcons.drupal, 'drupal'),
  new IconDefinition(MdiIcons.duck, 'duck'),
  new IconDefinition(MdiIcons.dumbbell, 'dumbbell'),
  new IconDefinition(MdiIcons.dumpTruck, 'dumpTruck'),
  new IconDefinition(MdiIcons.earHearing, 'earHearing'),
  new IconDefinition(MdiIcons.earHearingOff, 'earHearingOff'),
  new IconDefinition(MdiIcons.earth, 'earth'),
  new IconDefinition(MdiIcons.earthBox, 'earthBox'),
  new IconDefinition(MdiIcons.earthBoxOff, 'earthBoxOff'),
  new IconDefinition(MdiIcons.earthOff, 'earthOff'),
  new IconDefinition(MdiIcons.edge, 'edge'),
  new IconDefinition(MdiIcons.egg, 'egg'),
  new IconDefinition(MdiIcons.eggEaster, 'eggEaster'),
  new IconDefinition(MdiIcons.eightTrack, 'eightTrack'),
  new IconDefinition(MdiIcons.eject, 'eject'),
  new IconDefinition(MdiIcons.ejectOutline, 'ejectOutline'),
  new IconDefinition(MdiIcons.elephant, 'elephant'),
  new IconDefinition(MdiIcons.elevationDecline, 'elevationDecline'),
  new IconDefinition(MdiIcons.elevationRise, 'elevationRise'),
  new IconDefinition(MdiIcons.elevator, 'elevator'),
  new IconDefinition(MdiIcons.email, 'email'),
  new IconDefinition(MdiIcons.emailAlert, 'emailAlert'),
  new IconDefinition(MdiIcons.emailCheck, 'emailCheck'),
  new IconDefinition(MdiIcons.emailCheckOutline, 'emailCheckOutline'),
  new IconDefinition(MdiIcons.emailLock, 'emailLock'),
  new IconDefinition(MdiIcons.emailMarkAsUnread, 'emailMarkAsUnread'),
  new IconDefinition(MdiIcons.emailOpen, 'emailOpen'),
  new IconDefinition(MdiIcons.emailOpenOutline, 'emailOpenOutline'),
  new IconDefinition(MdiIcons.emailOutline, 'emailOutline'),
  new IconDefinition(MdiIcons.emailPlus, 'emailPlus'),
  new IconDefinition(MdiIcons.emailPlusOutline, 'emailPlusOutline'),
  new IconDefinition(MdiIcons.emailSearch, 'emailSearch'),
  new IconDefinition(MdiIcons.emailSearchOutline, 'emailSearchOutline'),
  new IconDefinition(MdiIcons.emailVariant, 'emailVariant'),
  new IconDefinition(MdiIcons.ember, 'ember'),
  new IconDefinition(MdiIcons.emby, 'emby'),
  new IconDefinition(MdiIcons.emoticon, 'emoticon'),
  new IconDefinition(MdiIcons.emoticonAngry, 'emoticonAngry'),
  new IconDefinition(MdiIcons.emoticonAngryOutline, 'emoticonAngryOutline'),
  new IconDefinition(MdiIcons.emoticonCool, 'emoticonCool'),
  new IconDefinition(MdiIcons.emoticonCoolOutline, 'emoticonCoolOutline'),
  new IconDefinition(MdiIcons.emoticonCry, 'emoticonCry'),
  new IconDefinition(MdiIcons.emoticonCryOutline, 'emoticonCryOutline'),
  new IconDefinition(MdiIcons.emoticonDead, 'emoticonDead'),
  new IconDefinition(MdiIcons.emoticonDeadOutline, 'emoticonDeadOutline'),
  new IconDefinition(MdiIcons.emoticonDevil, 'emoticonDevil'),
  new IconDefinition(MdiIcons.emoticonDevilOutline, 'emoticonDevilOutline'),
  new IconDefinition(MdiIcons.emoticonExcited, 'emoticonExcited'),
  new IconDefinition(MdiIcons.emoticonExcitedOutline, 'emoticonExcitedOutline'),
  new IconDefinition(MdiIcons.emoticonHappy, 'emoticonHappy'),
  new IconDefinition(MdiIcons.emoticonHappyOutline, 'emoticonHappyOutline'),
  new IconDefinition(MdiIcons.emoticonKiss, 'emoticonKiss'),
  new IconDefinition(MdiIcons.emoticonKissOutline, 'emoticonKissOutline'),
  new IconDefinition(MdiIcons.emoticonNeutral, 'emoticonNeutral'),
  new IconDefinition(MdiIcons.emoticonNeutralOutline, 'emoticonNeutralOutline'),
  new IconDefinition(MdiIcons.emoticonOutline, 'emoticonOutline'),
  new IconDefinition(MdiIcons.emoticonPoop, 'emoticonPoop'),
  new IconDefinition(MdiIcons.emoticonPoopOutline, 'emoticonPoopOutline'),
  new IconDefinition(MdiIcons.emoticonSad, 'emoticonSad'),
  new IconDefinition(MdiIcons.emoticonSadOutline, 'emoticonSadOutline'),
  new IconDefinition(MdiIcons.emoticonTongue, 'emoticonTongue'),
  new IconDefinition(MdiIcons.emoticonTongueOutline, 'emoticonTongueOutline'),
  new IconDefinition(MdiIcons.emoticonWink, 'emoticonWink'),
  new IconDefinition(MdiIcons.emoticonWinkOutline, 'emoticonWinkOutline'),
  new IconDefinition(MdiIcons.engine, 'engine'),
  new IconDefinition(MdiIcons.engineOff, 'engineOff'),
  new IconDefinition(MdiIcons.engineOffOutline, 'engineOffOutline'),
  new IconDefinition(MdiIcons.engineOutline, 'engineOutline'),
  new IconDefinition(MdiIcons.equal, 'equal'),
  new IconDefinition(MdiIcons.equalBox, 'equalBox'),
  new IconDefinition(MdiIcons.eraser, 'eraser'),
  new IconDefinition(MdiIcons.eraserVariant, 'eraserVariant'),
  new IconDefinition(MdiIcons.escalator, 'escalator'),
  new IconDefinition(MdiIcons.eslint, 'eslint'),
  new IconDefinition(MdiIcons.et, 'et'),
  new IconDefinition(MdiIcons.ethereum, 'ethereum'),
  new IconDefinition(MdiIcons.ethernet, 'ethernet'),
  new IconDefinition(MdiIcons.ethernetCable, 'ethernetCable'),
  new IconDefinition(MdiIcons.ethernetCableOff, 'ethernetCableOff'),
  new IconDefinition(MdiIcons.etsy, 'etsy'),
  new IconDefinition(MdiIcons.evStation, 'evStation'),
  new IconDefinition(MdiIcons.eventbrite, 'eventbrite'),
  new IconDefinition(MdiIcons.evernote, 'evernote'),
  new IconDefinition(MdiIcons.exclamation, 'exclamation'),
  new IconDefinition(MdiIcons.exitRun, 'exitRun'),
  new IconDefinition(MdiIcons.exitToApp, 'exitToApp'),
  new IconDefinition(MdiIcons.expandAll, 'expandAll'),
  new IconDefinition(MdiIcons.expandAllOutline, 'expandAllOutline'),
  new IconDefinition(MdiIcons.exponent, 'exponent'),
  new IconDefinition(MdiIcons.exponentBox, 'exponentBox'),
  new IconDefinition(MdiIcons.export, 'export'),
  new IconDefinition(MdiIcons.exportVariant, 'exportVariant'),
  new IconDefinition(MdiIcons.eye, 'eye'),
  new IconDefinition(MdiIcons.eyeCircle, 'eyeCircle'),
  new IconDefinition(MdiIcons.eyeCircleOutline, 'eyeCircleOutline'),
  new IconDefinition(MdiIcons.eyeOff, 'eyeOff'),
  new IconDefinition(MdiIcons.eyeOffOutline, 'eyeOffOutline'),
  new IconDefinition(MdiIcons.eyeOutline, 'eyeOutline'),
  new IconDefinition(MdiIcons.eyePlus, 'eyePlus'),
  new IconDefinition(MdiIcons.eyePlusOutline, 'eyePlusOutline'),
  new IconDefinition(MdiIcons.eyeSettings, 'eyeSettings'),
  new IconDefinition(MdiIcons.eyeSettingsOutline, 'eyeSettingsOutline'),
  new IconDefinition(MdiIcons.eyedropper, 'eyedropper'),
  new IconDefinition(MdiIcons.eyedropperVariant, 'eyedropperVariant'),
  new IconDefinition(MdiIcons.face, 'face'),
  new IconDefinition(MdiIcons.faceOutline, 'faceOutline'),
  new IconDefinition(MdiIcons.faceProfile, 'faceProfile'),
  new IconDefinition(MdiIcons.faceRecognition, 'faceRecognition'),
  new IconDefinition(MdiIcons.facebook, 'facebook'),
  new IconDefinition(MdiIcons.facebookBox, 'facebookBox'),
  new IconDefinition(MdiIcons.facebookMessenger, 'facebookMessenger'),
  new IconDefinition(MdiIcons.facebookWorkplace, 'facebookWorkplace'),
  new IconDefinition(MdiIcons.factoryIcon, 'factoryIcon'),
  new IconDefinition(MdiIcons.fan, 'fan'),
  new IconDefinition(MdiIcons.fanOff, 'fanOff'),
  new IconDefinition(MdiIcons.fastForward, 'fastForward'),
  new IconDefinition(MdiIcons.fastForwardOutline, 'fastForwardOutline'),
  new IconDefinition(MdiIcons.fax, 'fax'),
  new IconDefinition(MdiIcons.feather, 'feather'),
  new IconDefinition(MdiIcons.featureSearch, 'featureSearch'),
  new IconDefinition(MdiIcons.featureSearchOutline, 'featureSearchOutline'),
  new IconDefinition(MdiIcons.fedora, 'fedora'),
  new IconDefinition(MdiIcons.ferry, 'ferry'),
  new IconDefinition(MdiIcons.file, 'file'),
  new IconDefinition(MdiIcons.fileAccount, 'fileAccount'),
  new IconDefinition(MdiIcons.fileAlert, 'fileAlert'),
  new IconDefinition(MdiIcons.fileAlertOutline, 'fileAlertOutline'),
  new IconDefinition(MdiIcons.fileCabinet, 'fileCabinet'),
  new IconDefinition(MdiIcons.fileChart, 'fileChart'),
  new IconDefinition(MdiIcons.fileCheck, 'fileCheck'),
  new IconDefinition(MdiIcons.fileCloud, 'fileCloud'),
  new IconDefinition(MdiIcons.fileCompare, 'fileCompare'),
  new IconDefinition(MdiIcons.fileDelimited, 'fileDelimited'),
  new IconDefinition(MdiIcons.fileDocument, 'fileDocument'),
  new IconDefinition(MdiIcons.fileDocumentBox, 'fileDocumentBox'),
  new IconDefinition(MdiIcons.fileDocumentBoxMultiple, 'fileDocumentBoxMultiple'),
  new IconDefinition(MdiIcons.fileDocumentBoxMultipleOutline, 'fileDocumentBoxMultipleOutline'),
  new IconDefinition(MdiIcons.fileDocumentBoxOutline, 'fileDocumentBoxOutline'),
  new IconDefinition(MdiIcons.fileDocumentOutline, 'fileDocumentOutline'),
  new IconDefinition(MdiIcons.fileDownload, 'fileDownload'),
  new IconDefinition(MdiIcons.fileDownloadOutline, 'fileDownloadOutline'),
  new IconDefinition(MdiIcons.fileExcel, 'fileExcel'),
  new IconDefinition(MdiIcons.fileExcelBox, 'fileExcelBox'),
  new IconDefinition(MdiIcons.fileExport, 'fileExport'),
  new IconDefinition(MdiIcons.fileFind, 'fileFind'),
  new IconDefinition(MdiIcons.fileFindOutline, 'fileFindOutline'),
  new IconDefinition(MdiIcons.fileHidden, 'fileHidden'),
  new IconDefinition(MdiIcons.fileImage, 'fileImage'),
  new IconDefinition(MdiIcons.fileImport, 'fileImport'),
  new IconDefinition(MdiIcons.fileLock, 'fileLock'),
  new IconDefinition(MdiIcons.fileMove, 'fileMove'),
  new IconDefinition(MdiIcons.fileMultiple, 'fileMultiple'),
  new IconDefinition(MdiIcons.fileMusic, 'fileMusic'),
  new IconDefinition(MdiIcons.fileOutline, 'fileOutline'),
  new IconDefinition(MdiIcons.filePdf, 'filePdf'),
  new IconDefinition(MdiIcons.filePdfBox, 'filePdfBox'),
  new IconDefinition(MdiIcons.filePercent, 'filePercent'),
  new IconDefinition(MdiIcons.filePlus, 'filePlus'),
  new IconDefinition(MdiIcons.filePowerpoint, 'filePowerpoint'),
  new IconDefinition(MdiIcons.filePowerpointBox, 'filePowerpointBox'),
  new IconDefinition(MdiIcons.filePresentationBox, 'filePresentationBox'),
  new IconDefinition(MdiIcons.fileQuestion, 'fileQuestion'),
  new IconDefinition(MdiIcons.fileRemove, 'fileRemove'),
  new IconDefinition(MdiIcons.fileReplace, 'fileReplace'),
  new IconDefinition(MdiIcons.fileReplaceOutline, 'fileReplaceOutline'),
  new IconDefinition(MdiIcons.fileRestore, 'fileRestore'),
  new IconDefinition(MdiIcons.fileSearch, 'fileSearch'),
  new IconDefinition(MdiIcons.fileSearchOutline, 'fileSearchOutline'),
  new IconDefinition(MdiIcons.fileSend, 'fileSend'),
  new IconDefinition(MdiIcons.fileTable, 'fileTable'),
  new IconDefinition(MdiIcons.fileTableOutline, 'fileTableOutline'),
  new IconDefinition(MdiIcons.fileTree, 'fileTree'),
  new IconDefinition(MdiIcons.fileUndo, 'fileUndo'),
  new IconDefinition(MdiIcons.fileUpload, 'fileUpload'),
  new IconDefinition(MdiIcons.fileUploadOutline, 'fileUploadOutline'),
  new IconDefinition(MdiIcons.fileVideo, 'fileVideo'),
  new IconDefinition(MdiIcons.fileWord, 'fileWord'),
  new IconDefinition(MdiIcons.fileWordBox, 'fileWordBox'),
  new IconDefinition(MdiIcons.fileXml, 'fileXml'),
  new IconDefinition(MdiIcons.film, 'film'),
  new IconDefinition(MdiIcons.filmstrip, 'filmstrip'),
  new IconDefinition(MdiIcons.filmstripOff, 'filmstripOff'),
  new IconDefinition(MdiIcons.filter, 'filter'),
  new IconDefinition(MdiIcons.filterOutline, 'filterOutline'),
  new IconDefinition(MdiIcons.filterRemove, 'filterRemove'),
  new IconDefinition(MdiIcons.filterRemoveOutline, 'filterRemoveOutline'),
  new IconDefinition(MdiIcons.filterVariant, 'filterVariant'),
  new IconDefinition(MdiIcons.finance, 'finance'),
  new IconDefinition(MdiIcons.findReplace, 'findReplace'),
  new IconDefinition(MdiIcons.fingerprint, 'fingerprint'),
  new IconDefinition(MdiIcons.fire, 'fire'),
  new IconDefinition(MdiIcons.fireTruck, 'fireTruck'),
  new IconDefinition(MdiIcons.firebase, 'firebase'),
  new IconDefinition(MdiIcons.firefox, 'firefox'),
  new IconDefinition(MdiIcons.fish, 'fish'),
  new IconDefinition(MdiIcons.flag, 'flag'),
  new IconDefinition(MdiIcons.flagCheckered, 'flagCheckered'),
  new IconDefinition(MdiIcons.flagMinus, 'flagMinus'),
  new IconDefinition(MdiIcons.flagOutline, 'flagOutline'),
  new IconDefinition(MdiIcons.flagPlus, 'flagPlus'),
  new IconDefinition(MdiIcons.flagRemove, 'flagRemove'),
  new IconDefinition(MdiIcons.flagTriangle, 'flagTriangle'),
  new IconDefinition(MdiIcons.flagVariant, 'flagVariant'),
  new IconDefinition(MdiIcons.flagVariantOutline, 'flagVariantOutline'),
  new IconDefinition(MdiIcons.flash, 'flash'),
  new IconDefinition(MdiIcons.flashAuto, 'flashAuto'),
  new IconDefinition(MdiIcons.flashCircle, 'flashCircle'),
  new IconDefinition(MdiIcons.flashOff, 'flashOff'),
  new IconDefinition(MdiIcons.flashOutline, 'flashOutline'),
  new IconDefinition(MdiIcons.flashRedEye, 'flashRedEye'),
  new IconDefinition(MdiIcons.flashlight, 'flashlight'),
  new IconDefinition(MdiIcons.flashlightOff, 'flashlightOff'),
  new IconDefinition(MdiIcons.flask, 'flask'),
  new IconDefinition(MdiIcons.flaskEmpty, 'flaskEmpty'),
  new IconDefinition(MdiIcons.flaskEmptyOutline, 'flaskEmptyOutline'),
  new IconDefinition(MdiIcons.flaskOutline, 'flaskOutline'),
  new IconDefinition(MdiIcons.flattr, 'flattr'),
  new IconDefinition(MdiIcons.flipToBack, 'flipToBack'),
  new IconDefinition(MdiIcons.flipToFront, 'flipToFront'),
  new IconDefinition(MdiIcons.floorLamp, 'floorLamp'),
  new IconDefinition(MdiIcons.floorPlan, 'floorPlan'),
  new IconDefinition(MdiIcons.floppy, 'floppy'),
  new IconDefinition(MdiIcons.floppyVariant, 'floppyVariant'),
  new IconDefinition(MdiIcons.flower, 'flower'),
  new IconDefinition(MdiIcons.flowerOutline, 'flowerOutline'),
  new IconDefinition(MdiIcons.flowerTulip, 'flowerTulip'),
  new IconDefinition(MdiIcons.flowerTulipOutline, 'flowerTulipOutline'),
  new IconDefinition(MdiIcons.folder, 'folder'),
  new IconDefinition(MdiIcons.folderAccount, 'folderAccount'),
  new IconDefinition(MdiIcons.folderAccountOutline, 'folderAccountOutline'),
  new IconDefinition(MdiIcons.folderClock, 'folderClock'),
  new IconDefinition(MdiIcons.folderClockOutline, 'folderClockOutline'),
  new IconDefinition(MdiIcons.folderDownload, 'folderDownload'),
  new IconDefinition(MdiIcons.folderEdit, 'folderEdit'),
  new IconDefinition(MdiIcons.folderGoogleDrive, 'folderGoogleDrive'),
  new IconDefinition(MdiIcons.folderImage, 'folderImage'),
  new IconDefinition(MdiIcons.folderKey, 'folderKey'),
  new IconDefinition(MdiIcons.folderKeyNetwork, 'folderKeyNetwork'),
  new IconDefinition(MdiIcons.folderKeyNetworkOutline, 'folderKeyNetworkOutline'),
  new IconDefinition(MdiIcons.folderLock, 'folderLock'),
  new IconDefinition(MdiIcons.folderLockOpen, 'folderLockOpen'),
  new IconDefinition(MdiIcons.folderMove, 'folderMove'),
  new IconDefinition(MdiIcons.folderMultiple, 'folderMultiple'),
  new IconDefinition(MdiIcons.folderMultipleImage, 'folderMultipleImage'),
  new IconDefinition(MdiIcons.folderMultipleOutline, 'folderMultipleOutline'),
  new IconDefinition(MdiIcons.folderNetwork, 'folderNetwork'),
  new IconDefinition(MdiIcons.folderNetworkOutline, 'folderNetworkOutline'),
  new IconDefinition(MdiIcons.folderOpen, 'folderOpen'),
  new IconDefinition(MdiIcons.folderOutline, 'folderOutline'),
  new IconDefinition(MdiIcons.folderPlus, 'folderPlus'),
  new IconDefinition(MdiIcons.folderPlusOutline, 'folderPlusOutline'),
  new IconDefinition(MdiIcons.folderRemove, 'folderRemove'),
  new IconDefinition(MdiIcons.folderRemoveOutline, 'folderRemoveOutline'),
  new IconDefinition(MdiIcons.folderSearch, 'folderSearch'),
  new IconDefinition(MdiIcons.folderSearchOutline, 'folderSearchOutline'),
  new IconDefinition(MdiIcons.folderStar, 'folderStar'),
  new IconDefinition(MdiIcons.folderStarOutline, 'folderStarOutline'),
  new IconDefinition(MdiIcons.folderText, 'folderText'),
  new IconDefinition(MdiIcons.folderTextOutline, 'folderTextOutline'),
  new IconDefinition(MdiIcons.folderUpload, 'folderUpload'),
  new IconDefinition(MdiIcons.fontAwesome, 'fontAwesome'),
  new IconDefinition(MdiIcons.food, 'food'),
  new IconDefinition(MdiIcons.foodApple, 'foodApple'),
  new IconDefinition(MdiIcons.foodAppleOutline, 'foodAppleOutline'),
  new IconDefinition(MdiIcons.foodCroissant, 'foodCroissant'),
  new IconDefinition(MdiIcons.foodForkDrink, 'foodForkDrink'),
  new IconDefinition(MdiIcons.foodOff, 'foodOff'),
  new IconDefinition(MdiIcons.foodVariant, 'foodVariant'),
  new IconDefinition(MdiIcons.football, 'football'),
  new IconDefinition(MdiIcons.footballAustralian, 'footballAustralian'),
  new IconDefinition(MdiIcons.footballHelmet, 'footballHelmet'),
  new IconDefinition(MdiIcons.forklift, 'forklift'),
  new IconDefinition(MdiIcons.formatAlignBottom, 'formatAlignBottom'),
  new IconDefinition(MdiIcons.formatAlignCenter, 'formatAlignCenter'),
  new IconDefinition(MdiIcons.formatAlignJustify, 'formatAlignJustify'),
  new IconDefinition(MdiIcons.formatAlignLeft, 'formatAlignLeft'),
  new IconDefinition(MdiIcons.formatAlignMiddle, 'formatAlignMiddle'),
  new IconDefinition(MdiIcons.formatAlignRight, 'formatAlignRight'),
  new IconDefinition(MdiIcons.formatAlignTop, 'formatAlignTop'),
  new IconDefinition(MdiIcons.formatAnnotationMinus, 'formatAnnotationMinus'),
  new IconDefinition(MdiIcons.formatAnnotationPlus, 'formatAnnotationPlus'),
  new IconDefinition(MdiIcons.formatBold, 'formatBold'),
  new IconDefinition(MdiIcons.formatClear, 'formatClear'),
  new IconDefinition(MdiIcons.formatColorFill, 'formatColorFill'),
  new IconDefinition(MdiIcons.formatColorText, 'formatColorText'),
  new IconDefinition(MdiIcons.formatColumns, 'formatColumns'),
  new IconDefinition(MdiIcons.formatFloatCenter, 'formatFloatCenter'),
  new IconDefinition(MdiIcons.formatFloatLeft, 'formatFloatLeft'),
  new IconDefinition(MdiIcons.formatFloatNone, 'formatFloatNone'),
  new IconDefinition(MdiIcons.formatFloatRight, 'formatFloatRight'),
  new IconDefinition(MdiIcons.formatFont, 'formatFont'),
  new IconDefinition(MdiIcons.formatFontSizeDecrease, 'formatFontSizeDecrease'),
  new IconDefinition(MdiIcons.formatFontSizeIncrease, 'formatFontSizeIncrease'),
  new IconDefinition(MdiIcons.formatHeader1, 'formatHeader1'),
  new IconDefinition(MdiIcons.formatHeader2, 'formatHeader2'),
  new IconDefinition(MdiIcons.formatHeader3, 'formatHeader3'),
  new IconDefinition(MdiIcons.formatHeader4, 'formatHeader4'),
  new IconDefinition(MdiIcons.formatHeader5, 'formatHeader5'),
  new IconDefinition(MdiIcons.formatHeader6, 'formatHeader6'),
  new IconDefinition(MdiIcons.formatHeaderDecrease, 'formatHeaderDecrease'),
  new IconDefinition(MdiIcons.formatHeaderEqual, 'formatHeaderEqual'),
  new IconDefinition(MdiIcons.formatHeaderIncrease, 'formatHeaderIncrease'),
  new IconDefinition(MdiIcons.formatHeaderPound, 'formatHeaderPound'),
  new IconDefinition(MdiIcons.formatHorizontalAlignCenter, 'formatHorizontalAlignCenter'),
  new IconDefinition(MdiIcons.formatHorizontalAlignLeft, 'formatHorizontalAlignLeft'),
  new IconDefinition(MdiIcons.formatHorizontalAlignRight, 'formatHorizontalAlignRight'),
  new IconDefinition(MdiIcons.formatIndentDecrease, 'formatIndentDecrease'),
  new IconDefinition(MdiIcons.formatIndentIncrease, 'formatIndentIncrease'),
  new IconDefinition(MdiIcons.formatItalic, 'formatItalic'),
  new IconDefinition(MdiIcons.formatLetterCase, 'formatLetterCase'),
  new IconDefinition(MdiIcons.formatLetterCaseLower, 'formatLetterCaseLower'),
  new IconDefinition(MdiIcons.formatLetterCaseUpper, 'formatLetterCaseUpper'),
  new IconDefinition(MdiIcons.formatLineSpacing, 'formatLineSpacing'),
  new IconDefinition(MdiIcons.formatLineStyle, 'formatLineStyle'),
  new IconDefinition(MdiIcons.formatLineWeight, 'formatLineWeight'),
  new IconDefinition(MdiIcons.formatListBulleted, 'formatListBulleted'),
  new IconDefinition(MdiIcons.formatListBulletedType, 'formatListBulletedType'),
  new IconDefinition(MdiIcons.formatListCheckbox, 'formatListCheckbox'),
  new IconDefinition(MdiIcons.formatListChecks, 'formatListChecks'),
  new IconDefinition(MdiIcons.formatListNumbered, 'formatListNumbered'),
  new IconDefinition(MdiIcons.formatPageBreak, 'formatPageBreak'),
  new IconDefinition(MdiIcons.formatPaint, 'formatPaint'),
  new IconDefinition(MdiIcons.formatParagraph, 'formatParagraph'),
  new IconDefinition(MdiIcons.formatPilcrow, 'formatPilcrow'),
  new IconDefinition(MdiIcons.formatQuoteClose, 'formatQuoteClose'),
  new IconDefinition(MdiIcons.formatQuoteOpen, 'formatQuoteOpen'),
  new IconDefinition(MdiIcons.formatRotate90, 'formatRotate90'),
  new IconDefinition(MdiIcons.formatSection, 'formatSection'),
  new IconDefinition(MdiIcons.formatSize, 'formatSize'),
  new IconDefinition(MdiIcons.formatStrikethrough, 'formatStrikethrough'),
  new IconDefinition(MdiIcons.formatStrikethroughVariant, 'formatStrikethroughVariant'),
  new IconDefinition(MdiIcons.formatSubscript, 'formatSubscript'),
  new IconDefinition(MdiIcons.formatSuperscript, 'formatSuperscript'),
  new IconDefinition(MdiIcons.formatText, 'formatText'),
  new IconDefinition(MdiIcons.formatTextdirectionLToR, 'formatTextdirectionLToR'),
  new IconDefinition(MdiIcons.formatTextdirectionRToL, 'formatTextdirectionRToL'),
  new IconDefinition(MdiIcons.formatTitle, 'formatTitle'),
  new IconDefinition(MdiIcons.formatUnderline, 'formatUnderline'),
  new IconDefinition(MdiIcons.formatVerticalAlignBottom, 'formatVerticalAlignBottom'),
  new IconDefinition(MdiIcons.formatVerticalAlignCenter, 'formatVerticalAlignCenter'),
  new IconDefinition(MdiIcons.formatVerticalAlignTop, 'formatVerticalAlignTop'),
  new IconDefinition(MdiIcons.formatWrapInline, 'formatWrapInline'),
  new IconDefinition(MdiIcons.formatWrapSquare, 'formatWrapSquare'),
  new IconDefinition(MdiIcons.formatWrapTight, 'formatWrapTight'),
  new IconDefinition(MdiIcons.formatWrapTopBottom, 'formatWrapTopBottom'),
  new IconDefinition(MdiIcons.forum, 'forum'),
  new IconDefinition(MdiIcons.forumOutline, 'forumOutline'),
  new IconDefinition(MdiIcons.forward, 'forward'),
  new IconDefinition(MdiIcons.fountain, 'fountain'),
  new IconDefinition(MdiIcons.foursquare, 'foursquare'),
  new IconDefinition(MdiIcons.freebsd, 'freebsd'),
  new IconDefinition(MdiIcons.fridge, 'fridge'),
  new IconDefinition(MdiIcons.fridgeBottom, 'fridgeBottom'),
  new IconDefinition(MdiIcons.fridgeOutline, 'fridgeOutline'),
  new IconDefinition(MdiIcons.fridgeTop, 'fridgeTop'),
  new IconDefinition(MdiIcons.fuel, 'fuel'),
  new IconDefinition(MdiIcons.fullscreen, 'fullscreen'),
  new IconDefinition(MdiIcons.fullscreenExit, 'fullscreenExit'),
  new IconDefinition(MdiIcons.function, 'function'),
  new IconDefinition(MdiIcons.functionVariant, 'functionVariant'),
  new IconDefinition(MdiIcons.fuse, 'fuse'),
  new IconDefinition(MdiIcons.fuseBlade, 'fuseBlade'),
  new IconDefinition(MdiIcons.gamepad, 'gamepad'),
  new IconDefinition(MdiIcons.gamepadVariant, 'gamepadVariant'),
  new IconDefinition(MdiIcons.garage, 'garage'),
  new IconDefinition(MdiIcons.garageAlert, 'garageAlert'),
  new IconDefinition(MdiIcons.garageOpen, 'garageOpen'),
  new IconDefinition(MdiIcons.gasCylinder, 'gasCylinder'),
  new IconDefinition(MdiIcons.gasStation, 'gasStation'),
  new IconDefinition(MdiIcons.gate, 'gate'),
  new IconDefinition(MdiIcons.gateAnd, 'gateAnd'),
  new IconDefinition(MdiIcons.gateNand, 'gateNand'),
  new IconDefinition(MdiIcons.gateNor, 'gateNor'),
  new IconDefinition(MdiIcons.gateNot, 'gateNot'),
  new IconDefinition(MdiIcons.gateOr, 'gateOr'),
  new IconDefinition(MdiIcons.gateXnor, 'gateXnor'),
  new IconDefinition(MdiIcons.gateXor, 'gateXor'),
  new IconDefinition(MdiIcons.gauge, 'gauge'),
  new IconDefinition(MdiIcons.gaugeEmpty, 'gaugeEmpty'),
  new IconDefinition(MdiIcons.gaugeFull, 'gaugeFull'),
  new IconDefinition(MdiIcons.gaugeLow, 'gaugeLow'),
  new IconDefinition(MdiIcons.gavel, 'gavel'),
  new IconDefinition(MdiIcons.genderFemale, 'genderFemale'),
  new IconDefinition(MdiIcons.genderMale, 'genderMale'),
  new IconDefinition(MdiIcons.genderMaleFemale, 'genderMaleFemale'),
  new IconDefinition(MdiIcons.genderTransgender, 'genderTransgender'),
  new IconDefinition(MdiIcons.gentoo, 'gentoo'),
  new IconDefinition(MdiIcons.gesture, 'gesture'),
  new IconDefinition(MdiIcons.gestureDoubleTap, 'gestureDoubleTap'),
  new IconDefinition(MdiIcons.gesturePinch, 'gesturePinch'),
  new IconDefinition(MdiIcons.gestureSpread, 'gestureSpread'),
  new IconDefinition(MdiIcons.gestureSwipeDown, 'gestureSwipeDown'),
  new IconDefinition(MdiIcons.gestureSwipeHorizontal, 'gestureSwipeHorizontal'),
  new IconDefinition(MdiIcons.gestureSwipeLeft, 'gestureSwipeLeft'),
  new IconDefinition(MdiIcons.gestureSwipeRight, 'gestureSwipeRight'),
  new IconDefinition(MdiIcons.gestureSwipeUp, 'gestureSwipeUp'),
  new IconDefinition(MdiIcons.gestureSwipeVertical, 'gestureSwipeVertical'),
  new IconDefinition(MdiIcons.gestureTap, 'gestureTap'),
  new IconDefinition(MdiIcons.gestureTwoDoubleTap, 'gestureTwoDoubleTap'),
  new IconDefinition(MdiIcons.gestureTwoTap, 'gestureTwoTap'),
  new IconDefinition(MdiIcons.ghost, 'ghost'),
  new IconDefinition(MdiIcons.ghostOff, 'ghostOff'),
  new IconDefinition(MdiIcons.gift, 'gift'),
  new IconDefinition(MdiIcons.git, 'git'),
  new IconDefinition(MdiIcons.githubBox, 'githubBox'),
  new IconDefinition(MdiIcons.githubCircle, 'githubCircle'),
  new IconDefinition(MdiIcons.githubFace, 'githubFace'),
  new IconDefinition(MdiIcons.gitlab, 'gitlab'),
  new IconDefinition(MdiIcons.glassCocktail, 'glassCocktail'),
  new IconDefinition(MdiIcons.glassFlute, 'glassFlute'),
  new IconDefinition(MdiIcons.glassMug, 'glassMug'),
  new IconDefinition(MdiIcons.glassStange, 'glassStange'),
  new IconDefinition(MdiIcons.glassTulip, 'glassTulip'),
  new IconDefinition(MdiIcons.glassWine, 'glassWine'),
  new IconDefinition(MdiIcons.glassdoor, 'glassdoor'),
  new IconDefinition(MdiIcons.glasses, 'glasses'),
  new IconDefinition(MdiIcons.globeModel, 'globeModel'),
  new IconDefinition(MdiIcons.gmail, 'gmail'),
  new IconDefinition(MdiIcons.gnome, 'gnome'),
  new IconDefinition(MdiIcons.gog, 'gog'),
  new IconDefinition(MdiIcons.golf, 'golf'),
  new IconDefinition(MdiIcons.gondola, 'gondola'),
  new IconDefinition(MdiIcons.google, 'google'),
  new IconDefinition(MdiIcons.googleAdwords, 'googleAdwords'),
  new IconDefinition(MdiIcons.googleAllo, 'googleAllo'),
  new IconDefinition(MdiIcons.googleAnalytics, 'googleAnalytics'),
  new IconDefinition(MdiIcons.googleAssistant, 'googleAssistant'),
  new IconDefinition(MdiIcons.googleCardboard, 'googleCardboard'),
  new IconDefinition(MdiIcons.googleChrome, 'googleChrome'),
  new IconDefinition(MdiIcons.googleCircles, 'googleCircles'),
  new IconDefinition(MdiIcons.googleCirclesCommunities, 'googleCirclesCommunities'),
  new IconDefinition(MdiIcons.googleCirclesExtended, 'googleCirclesExtended'),
  new IconDefinition(MdiIcons.googleCirclesGroup, 'googleCirclesGroup'),
  new IconDefinition(MdiIcons.googleController, 'googleController'),
  new IconDefinition(MdiIcons.googleControllerOff, 'googleControllerOff'),
  new IconDefinition(MdiIcons.googleDrive, 'googleDrive'),
  new IconDefinition(MdiIcons.googleEarth, 'googleEarth'),
  new IconDefinition(MdiIcons.googleFit, 'googleFit'),
  new IconDefinition(MdiIcons.googleGlass, 'googleGlass'),
  new IconDefinition(MdiIcons.googleHangouts, 'googleHangouts'),
  new IconDefinition(MdiIcons.googleHome, 'googleHome'),
  new IconDefinition(MdiIcons.googleKeep, 'googleKeep'),
  new IconDefinition(MdiIcons.googleLens, 'googleLens'),
  new IconDefinition(MdiIcons.googleMaps, 'googleMaps'),
  new IconDefinition(MdiIcons.googleNearby, 'googleNearby'),
  new IconDefinition(MdiIcons.googlePages, 'googlePages'),
  new IconDefinition(MdiIcons.googlePhotos, 'googlePhotos'),
  new IconDefinition(MdiIcons.googlePhysicalWeb, 'googlePhysicalWeb'),
  new IconDefinition(MdiIcons.googlePlay, 'googlePlay'),
  new IconDefinition(MdiIcons.googlePlus, 'googlePlus'),
  new IconDefinition(MdiIcons.googlePlusBox, 'googlePlusBox'),
  new IconDefinition(MdiIcons.googleSpreadsheet, 'googleSpreadsheet'),
  new IconDefinition(MdiIcons.googleStreetView, 'googleStreetView'),
  new IconDefinition(MdiIcons.googleTranslate, 'googleTranslate'),
  new IconDefinition(MdiIcons.googleWallet, 'googleWallet'),
  new IconDefinition(MdiIcons.gpu, 'gpu'),
  new IconDefinition(MdiIcons.gradient, 'gradient'),
  new IconDefinition(MdiIcons.graphql, 'graphql'),
  new IconDefinition(MdiIcons.graveStone, 'graveStone'),
  new IconDefinition(MdiIcons.greasePencil, 'greasePencil'),
  new IconDefinition(MdiIcons.greaterThan, 'greaterThan'),
  new IconDefinition(MdiIcons.greaterThanOrEqual, 'greaterThanOrEqual'),
  new IconDefinition(MdiIcons.grid, 'grid'),
  new IconDefinition(MdiIcons.gridLarge, 'gridLarge'),
  new IconDefinition(MdiIcons.gridOff, 'gridOff'),
  new IconDefinition(MdiIcons.group, 'group'),
  new IconDefinition(MdiIcons.guitarAcoustic, 'guitarAcoustic'),
  new IconDefinition(MdiIcons.guitarElectric, 'guitarElectric'),
  new IconDefinition(MdiIcons.guitarPick, 'guitarPick'),
  new IconDefinition(MdiIcons.guitarPickOutline, 'guitarPickOutline'),
  new IconDefinition(MdiIcons.guyFawkesMask, 'guyFawkesMask'),
  new IconDefinition(MdiIcons.hackernews, 'hackernews'),
  new IconDefinition(MdiIcons.hail, 'hail'),
  new IconDefinition(MdiIcons.halloween, 'halloween'),
  new IconDefinition(MdiIcons.hamburger, 'hamburger'),
  new IconDefinition(MdiIcons.hammer, 'hammer'),
  new IconDefinition(MdiIcons.hand, 'hand'),
  new IconDefinition(MdiIcons.handOkay, 'handOkay'),
  new IconDefinition(MdiIcons.handPeace, 'handPeace'),
  new IconDefinition(MdiIcons.handPeaceVariant, 'handPeaceVariant'),
  new IconDefinition(MdiIcons.handPointingDown, 'handPointingDown'),
  new IconDefinition(MdiIcons.handPointingLeft, 'handPointingLeft'),
  new IconDefinition(MdiIcons.handPointingRight, 'handPointingRight'),
  new IconDefinition(MdiIcons.handPointingUp, 'handPointingUp'),
  new IconDefinition(MdiIcons.hanger, 'hanger'),
  new IconDefinition(MdiIcons.hardHat, 'hardHat'),
  new IconDefinition(MdiIcons.harddisk, 'harddisk'),
  new IconDefinition(MdiIcons.hatFedora, 'hatFedora'),
  new IconDefinition(MdiIcons.hazardLights, 'hazardLights'),
  new IconDefinition(MdiIcons.headphones, 'headphones'),
  new IconDefinition(MdiIcons.headphonesBluetooth, 'headphonesBluetooth'),
  new IconDefinition(MdiIcons.headphonesBox, 'headphonesBox'),
  new IconDefinition(MdiIcons.headphonesOff, 'headphonesOff'),
  new IconDefinition(MdiIcons.headphonesSettings, 'headphonesSettings'),
  new IconDefinition(MdiIcons.headset, 'headset'),
  new IconDefinition(MdiIcons.headsetDock, 'headsetDock'),
  new IconDefinition(MdiIcons.headsetOff, 'headsetOff'),
  new IconDefinition(MdiIcons.heart, 'heart'),
  new IconDefinition(MdiIcons.heartBox, 'heartBox'),
  new IconDefinition(MdiIcons.heartBoxOutline, 'heartBoxOutline'),
  new IconDefinition(MdiIcons.heartBroken, 'heartBroken'),
  new IconDefinition(MdiIcons.heartCircle, 'heartCircle'),
  new IconDefinition(MdiIcons.heartCircleOutline, 'heartCircleOutline'),
  new IconDefinition(MdiIcons.heartHalf, 'heartHalf'),
  new IconDefinition(MdiIcons.heartHalfFull, 'heartHalfFull'),
  new IconDefinition(MdiIcons.heartHalfOutline, 'heartHalfOutline'),
  new IconDefinition(MdiIcons.heartMultiple, 'heartMultiple'),
  new IconDefinition(MdiIcons.heartMultipleOutline, 'heartMultipleOutline'),
  new IconDefinition(MdiIcons.heartOff, 'heartOff'),
  new IconDefinition(MdiIcons.heartOutline, 'heartOutline'),
  new IconDefinition(MdiIcons.heartPulse, 'heartPulse'),
  new IconDefinition(MdiIcons.helicopter, 'helicopter'),
  new IconDefinition(MdiIcons.help, 'help'),
  new IconDefinition(MdiIcons.helpBox, 'helpBox'),
  new IconDefinition(MdiIcons.helpCircle, 'helpCircle'),
  new IconDefinition(MdiIcons.helpCircleOutline, 'helpCircleOutline'),
  new IconDefinition(MdiIcons.helpNetwork, 'helpNetwork'),
  new IconDefinition(MdiIcons.helpNetworkOutline, 'helpNetworkOutline'),
  new IconDefinition(MdiIcons.helpRhombus, 'helpRhombus'),
  new IconDefinition(MdiIcons.helpRhombusOutline, 'helpRhombusOutline'),
  new IconDefinition(MdiIcons.hexagon, 'hexagon'),
  new IconDefinition(MdiIcons.hexagonMultiple, 'hexagonMultiple'),
  new IconDefinition(MdiIcons.hexagonOutline, 'hexagonOutline'),
  new IconDefinition(MdiIcons.hexagonSlice1, 'hexagonSlice1'),
  new IconDefinition(MdiIcons.hexagonSlice2, 'hexagonSlice2'),
  new IconDefinition(MdiIcons.hexagonSlice3, 'hexagonSlice3'),
  new IconDefinition(MdiIcons.hexagonSlice4, 'hexagonSlice4'),
  new IconDefinition(MdiIcons.hexagonSlice5, 'hexagonSlice5'),
  new IconDefinition(MdiIcons.hexagonSlice6, 'hexagonSlice6'),
  new IconDefinition(MdiIcons.hexagram, 'hexagram'),
  new IconDefinition(MdiIcons.hexagramOutline, 'hexagramOutline'),
  new IconDefinition(MdiIcons.highDefinition, 'highDefinition'),
  new IconDefinition(MdiIcons.highDefinitionBox, 'highDefinitionBox'),
  new IconDefinition(MdiIcons.highway, 'highway'),
  new IconDefinition(MdiIcons.hinduism, 'hinduism'),
  new IconDefinition(MdiIcons.history, 'history'),
  new IconDefinition(MdiIcons.hockeyPuck, 'hockeyPuck'),
  new IconDefinition(MdiIcons.hockeySticks, 'hockeySticks'),
  new IconDefinition(MdiIcons.hololens, 'hololens'),
  new IconDefinition(MdiIcons.home, 'home'),
  new IconDefinition(MdiIcons.homeAccount, 'homeAccount'),
  new IconDefinition(MdiIcons.homeAlert, 'homeAlert'),
  new IconDefinition(MdiIcons.homeAssistant, 'homeAssistant'),
  new IconDefinition(MdiIcons.homeAutomation, 'homeAutomation'),
  new IconDefinition(MdiIcons.homeCircle, 'homeCircle'),
  new IconDefinition(MdiIcons.homeCurrencyUsd, 'homeCurrencyUsd'),
  new IconDefinition(MdiIcons.homeHeart, 'homeHeart'),
  new IconDefinition(MdiIcons.homeLock, 'homeLock'),
  new IconDefinition(MdiIcons.homeLockOpen, 'homeLockOpen'),
  new IconDefinition(MdiIcons.homeMapMarker, 'homeMapMarker'),
  new IconDefinition(MdiIcons.homeMinus, 'homeMinus'),
  new IconDefinition(MdiIcons.homeModern, 'homeModern'),
  new IconDefinition(MdiIcons.homeOutline, 'homeOutline'),
  new IconDefinition(MdiIcons.homePlus, 'homePlus'),
  new IconDefinition(MdiIcons.homeVariant, 'homeVariant'),
  new IconDefinition(MdiIcons.homeVariantOutline, 'homeVariantOutline'),
  new IconDefinition(MdiIcons.hook, 'hook'),
  new IconDefinition(MdiIcons.hookOff, 'hookOff'),
  new IconDefinition(MdiIcons.hops, 'hops'),
  new IconDefinition(MdiIcons.horseshoe, 'horseshoe'),
  new IconDefinition(MdiIcons.hospital, 'hospital'),
  new IconDefinition(MdiIcons.hospitalBuilding, 'hospitalBuilding'),
  new IconDefinition(MdiIcons.hospitalMarker, 'hospitalMarker'),
  new IconDefinition(MdiIcons.hotTub, 'hotTub'),
  new IconDefinition(MdiIcons.hotel, 'hotel'),
  new IconDefinition(MdiIcons.houzz, 'houzz'),
  new IconDefinition(MdiIcons.houzzBox, 'houzzBox'),
  new IconDefinition(MdiIcons.hulu, 'hulu'),
  new IconDefinition(MdiIcons.human, 'human'),
  new IconDefinition(MdiIcons.humanChild, 'humanChild'),
  new IconDefinition(MdiIcons.humanFemale, 'humanFemale'),
  new IconDefinition(MdiIcons.humanFemaleBoy, 'humanFemaleBoy'),
  new IconDefinition(MdiIcons.humanFemaleFemale, 'humanFemaleFemale'),
  new IconDefinition(MdiIcons.humanFemaleGirl, 'humanFemaleGirl'),
  new IconDefinition(MdiIcons.humanGreeting, 'humanGreeting'),
  new IconDefinition(MdiIcons.humanHandsdown, 'humanHandsdown'),
  new IconDefinition(MdiIcons.humanHandsup, 'humanHandsup'),
  new IconDefinition(MdiIcons.humanMale, 'humanMale'),
  new IconDefinition(MdiIcons.humanMaleBoy, 'humanMaleBoy'),
  new IconDefinition(MdiIcons.humanMaleFemale, 'humanMaleFemale'),
  new IconDefinition(MdiIcons.humanMaleGirl, 'humanMaleGirl'),
  new IconDefinition(MdiIcons.humanMaleMale, 'humanMaleMale'),
  new IconDefinition(MdiIcons.humanPregnant, 'humanPregnant'),
  new IconDefinition(MdiIcons.humbleBundle, 'humbleBundle'),
  new IconDefinition(MdiIcons.iceCream, 'iceCream'),
  new IconDefinition(MdiIcons.iframe, 'iframe'),
  new IconDefinition(MdiIcons.iframeOutline, 'iframeOutline'),
  new IconDefinition(MdiIcons.image, 'image'),
  new IconDefinition(MdiIcons.imageAlbum, 'imageAlbum'),
  new IconDefinition(MdiIcons.imageArea, 'imageArea'),
  new IconDefinition(MdiIcons.imageAreaClose, 'imageAreaClose'),
  new IconDefinition(MdiIcons.imageBroken, 'imageBroken'),
  new IconDefinition(MdiIcons.imageBrokenVariant, 'imageBrokenVariant'),
  new IconDefinition(MdiIcons.imageFilter, 'imageFilter'),
  new IconDefinition(MdiIcons.imageFilterBlackWhite, 'imageFilterBlackWhite'),
  new IconDefinition(MdiIcons.imageFilterCenterFocus, 'imageFilterCenterFocus'),
  new IconDefinition(MdiIcons.imageFilterCenterFocusWeak, 'imageFilterCenterFocusWeak'),
  new IconDefinition(MdiIcons.imageFilterDrama, 'imageFilterDrama'),
  new IconDefinition(MdiIcons.imageFilterFrames, 'imageFilterFrames'),
  new IconDefinition(MdiIcons.imageFilterHdr, 'imageFilterHdr'),
  new IconDefinition(MdiIcons.imageFilterNone, 'imageFilterNone'),
  new IconDefinition(MdiIcons.imageFilterTiltShift, 'imageFilterTiltShift'),
  new IconDefinition(MdiIcons.imageFilterVintage, 'imageFilterVintage'),
  new IconDefinition(MdiIcons.imageMove, 'imageMove'),
  new IconDefinition(MdiIcons.imageMultiple, 'imageMultiple'),
  new IconDefinition(MdiIcons.imageOff, 'imageOff'),
  new IconDefinition(MdiIcons.imageOutline, 'imageOutline'),
  new IconDefinition(MdiIcons.imagePlus, 'imagePlus'),
  new IconDefinition(MdiIcons.imageSearch, 'imageSearch'),
  new IconDefinition(MdiIcons.imageSearchOutline, 'imageSearchOutline'),
  new IconDefinition(MdiIcons.imageSizeSelectActual, 'imageSizeSelectActual'),
  new IconDefinition(MdiIcons.imageSizeSelectLarge, 'imageSizeSelectLarge'),
  new IconDefinition(MdiIcons.imageSizeSelectSmall, 'imageSizeSelectSmall'),
  new IconDefinition(MdiIcons.import, 'import'),
  new IconDefinition(MdiIcons.inbox, 'inbox'),
  new IconDefinition(MdiIcons.inboxArrowDown, 'inboxArrowDown'),
  new IconDefinition(MdiIcons.inboxArrowUp, 'inboxArrowUp'),
  new IconDefinition(MdiIcons.inboxMultiple, 'inboxMultiple'),
  new IconDefinition(MdiIcons.inboxMultipleOutline, 'inboxMultipleOutline'),
  new IconDefinition(MdiIcons.incognito, 'incognito'),
  new IconDefinition(MdiIcons.infinity, 'infinity'),
  new IconDefinition(MdiIcons.information, 'information'),
  new IconDefinition(MdiIcons.informationOutline, 'informationOutline'),
  new IconDefinition(MdiIcons.informationVariant, 'informationVariant'),
  new IconDefinition(MdiIcons.instagram, 'instagram'),
  new IconDefinition(MdiIcons.instapaper, 'instapaper'),
  new IconDefinition(MdiIcons.internetExplorer, 'internetExplorer'),
  new IconDefinition(MdiIcons.invertColors, 'invertColors'),
  new IconDefinition(MdiIcons.ip, 'ip'),
  new IconDefinition(MdiIcons.ipNetwork, 'ipNetwork'),
  new IconDefinition(MdiIcons.ipNetworkOutline, 'ipNetworkOutline'),
  new IconDefinition(MdiIcons.ipod, 'ipod'),
  new IconDefinition(MdiIcons.islam, 'islam'),
  new IconDefinition(MdiIcons.itunes, 'itunes'),
  new IconDefinition(MdiIcons.jeepney, 'jeepney'),
  new IconDefinition(MdiIcons.jira, 'jira'),
  new IconDefinition(MdiIcons.jquery, 'jquery'),
  new IconDefinition(MdiIcons.jsfiddle, 'jsfiddle'),
  new IconDefinition(MdiIcons.json, 'json'),
  new IconDefinition(MdiIcons.judaism, 'judaism'),
  new IconDefinition(MdiIcons.karate, 'karate'),
  new IconDefinition(MdiIcons.keg, 'keg'),
  new IconDefinition(MdiIcons.kettle, 'kettle'),
  new IconDefinition(MdiIcons.key, 'key'),
  new IconDefinition(MdiIcons.keyChange, 'keyChange'),
  new IconDefinition(MdiIcons.keyMinus, 'keyMinus'),
  new IconDefinition(MdiIcons.keyPlus, 'keyPlus'),
  new IconDefinition(MdiIcons.keyRemove, 'keyRemove'),
  new IconDefinition(MdiIcons.keyVariant, 'keyVariant'),
  new IconDefinition(MdiIcons.keyboard, 'keyboard'),
  new IconDefinition(MdiIcons.keyboardBackspace, 'keyboardBackspace'),
  new IconDefinition(MdiIcons.keyboardCaps, 'keyboardCaps'),
  new IconDefinition(MdiIcons.keyboardClose, 'keyboardClose'),
  new IconDefinition(MdiIcons.keyboardOff, 'keyboardOff'),
  new IconDefinition(MdiIcons.keyboardOutline, 'keyboardOutline'),
  new IconDefinition(MdiIcons.keyboardReturn, 'keyboardReturn'),
  new IconDefinition(MdiIcons.keyboardSettings, 'keyboardSettings'),
  new IconDefinition(MdiIcons.keyboardSettingsOutline, 'keyboardSettingsOutline'),
  new IconDefinition(MdiIcons.keyboardTab, 'keyboardTab'),
  new IconDefinition(MdiIcons.keyboardVariant, 'keyboardVariant'),
  new IconDefinition(MdiIcons.kickstarter, 'kickstarter'),
  new IconDefinition(MdiIcons.knife, 'knife'),
  new IconDefinition(MdiIcons.knifeMilitary, 'knifeMilitary'),
  new IconDefinition(MdiIcons.kodi, 'kodi'),
  new IconDefinition(MdiIcons.label, 'label'),
  new IconDefinition(MdiIcons.labelOff, 'labelOff'),
  new IconDefinition(MdiIcons.labelOffOutline, 'labelOffOutline'),
  new IconDefinition(MdiIcons.labelOutline, 'labelOutline'),
  new IconDefinition(MdiIcons.labelVariant, 'labelVariant'),
  new IconDefinition(MdiIcons.labelVariantOutline, 'labelVariantOutline'),
  new IconDefinition(MdiIcons.ladybug, 'ladybug'),
  new IconDefinition(MdiIcons.lambda, 'lambda'),
  new IconDefinition(MdiIcons.lamp, 'lamp'),
  new IconDefinition(MdiIcons.lan, 'lan'),
  new IconDefinition(MdiIcons.lanConnect, 'lanConnect'),
  new IconDefinition(MdiIcons.lanDisconnect, 'lanDisconnect'),
  new IconDefinition(MdiIcons.lanPending, 'lanPending'),
  new IconDefinition(MdiIcons.languageC, 'languageC'),
  new IconDefinition(MdiIcons.languageCpp, 'languageCpp'),
  new IconDefinition(MdiIcons.languageCsharp, 'languageCsharp'),
  new IconDefinition(MdiIcons.languageCss3, 'languageCss3'),
  new IconDefinition(MdiIcons.languageGo, 'languageGo'),
  new IconDefinition(MdiIcons.languageHaskell, 'languageHaskell'),
  new IconDefinition(MdiIcons.languageHtml5, 'languageHtml5'),
  new IconDefinition(MdiIcons.languageJava, 'languageJava'),
  new IconDefinition(MdiIcons.languageJavascript, 'languageJavascript'),
  new IconDefinition(MdiIcons.languageLua, 'languageLua'),
  new IconDefinition(MdiIcons.languagePhp, 'languagePhp'),
  new IconDefinition(MdiIcons.languagePython, 'languagePython'),
  new IconDefinition(MdiIcons.languagePythonText, 'languagePythonText'),
  new IconDefinition(MdiIcons.languageR, 'languageR'),
  new IconDefinition(MdiIcons.languageRubyOnRails, 'languageRubyOnRails'),
  new IconDefinition(MdiIcons.languageSwift, 'languageSwift'),
  new IconDefinition(MdiIcons.languageTypescript, 'languageTypescript'),
  new IconDefinition(MdiIcons.laptop, 'laptop'),
  new IconDefinition(MdiIcons.laptopChromebook, 'laptopChromebook'),
  new IconDefinition(MdiIcons.laptopMac, 'laptopMac'),
  new IconDefinition(MdiIcons.laptopOff, 'laptopOff'),
  new IconDefinition(MdiIcons.laptopWindows, 'laptopWindows'),
  new IconDefinition(MdiIcons.laravel, 'laravel'),
  new IconDefinition(MdiIcons.lastfm, 'lastfm'),
  new IconDefinition(MdiIcons.lastpass, 'lastpass'),
  new IconDefinition(MdiIcons.launch, 'launch'),
  new IconDefinition(MdiIcons.lavaLamp, 'lavaLamp'),
  new IconDefinition(MdiIcons.layers, 'layers'),
  new IconDefinition(MdiIcons.layersOff, 'layersOff'),
  new IconDefinition(MdiIcons.layersOffOutline, 'layersOffOutline'),
  new IconDefinition(MdiIcons.layersOutline, 'layersOutline'),
  new IconDefinition(MdiIcons.leadPencil, 'leadPencil'),
  new IconDefinition(MdiIcons.leaf, 'leaf'),
  new IconDefinition(MdiIcons.leafMaple, 'leafMaple'),
  new IconDefinition(MdiIcons.ledOff, 'ledOff'),
  new IconDefinition(MdiIcons.ledOn, 'ledOn'),
  new IconDefinition(MdiIcons.ledOutline, 'ledOutline'),
  new IconDefinition(MdiIcons.ledStrip, 'ledStrip'),
  new IconDefinition(MdiIcons.ledVariantOff, 'ledVariantOff'),
  new IconDefinition(MdiIcons.ledVariantOn, 'ledVariantOn'),
  new IconDefinition(MdiIcons.ledVariantOutline, 'ledVariantOutline'),
  new IconDefinition(MdiIcons.lessThan, 'lessThan'),
  new IconDefinition(MdiIcons.lessThanOrEqual, 'lessThanOrEqual'),
  new IconDefinition(MdiIcons.library, 'library'),
  new IconDefinition(MdiIcons.libraryBooks, 'libraryBooks'),
  new IconDefinition(MdiIcons.libraryMusic, 'libraryMusic'),
  new IconDefinition(MdiIcons.libraryPlus, 'libraryPlus'),
  new IconDefinition(MdiIcons.libraryShelves, 'libraryShelves'),
  new IconDefinition(MdiIcons.lifebuoy, 'lifebuoy'),
  new IconDefinition(MdiIcons.lightSwitch, 'lightSwitch'),
  new IconDefinition(MdiIcons.lightbulb, 'lightbulb'),
  new IconDefinition(MdiIcons.lightbulbOn, 'lightbulbOn'),
  new IconDefinition(MdiIcons.lightbulbOnOutline, 'lightbulbOnOutline'),
  new IconDefinition(MdiIcons.lightbulbOutline, 'lightbulbOutline'),
  new IconDefinition(MdiIcons.lighthouse, 'lighthouse'),
  new IconDefinition(MdiIcons.lighthouseOn, 'lighthouseOn'),
  new IconDefinition(MdiIcons.link, 'link'),
  new IconDefinition(MdiIcons.linkOff, 'linkOff'),
  new IconDefinition(MdiIcons.linkPlus, 'linkPlus'),
  new IconDefinition(MdiIcons.linkVariant, 'linkVariant'),
  new IconDefinition(MdiIcons.linkVariantOff, 'linkVariantOff'),
  new IconDefinition(MdiIcons.linkedin, 'linkedin'),
  new IconDefinition(MdiIcons.linkedinBox, 'linkedinBox'),
  new IconDefinition(MdiIcons.linux, 'linux'),
  new IconDefinition(MdiIcons.linuxMint, 'linuxMint'),
  new IconDefinition(MdiIcons.litecoin, 'litecoin'),
  new IconDefinition(MdiIcons.loading, 'loading'),
  new IconDefinition(MdiIcons.lock, 'lock'),
  new IconDefinition(MdiIcons.lockAlert, 'lockAlert'),
  new IconDefinition(MdiIcons.lockClock, 'lockClock'),
  new IconDefinition(MdiIcons.lockOpen, 'lockOpen'),
  new IconDefinition(MdiIcons.lockOpenOutline, 'lockOpenOutline'),
  new IconDefinition(MdiIcons.lockOutline, 'lockOutline'),
  new IconDefinition(MdiIcons.lockPattern, 'lockPattern'),
  new IconDefinition(MdiIcons.lockPlus, 'lockPlus'),
  new IconDefinition(MdiIcons.lockQuestion, 'lockQuestion'),
  new IconDefinition(MdiIcons.lockReset, 'lockReset'),
  new IconDefinition(MdiIcons.lockSmart, 'lockSmart'),
  new IconDefinition(MdiIcons.locker, 'locker'),
  new IconDefinition(MdiIcons.lockerMultiple, 'lockerMultiple'),
  new IconDefinition(MdiIcons.login, 'login'),
  new IconDefinition(MdiIcons.loginVariant, 'loginVariant'),
  new IconDefinition(MdiIcons.logout, 'logout'),
  new IconDefinition(MdiIcons.logoutVariant, 'logoutVariant'),
  new IconDefinition(MdiIcons.looks, 'looks'),
  new IconDefinition(MdiIcons.loop, 'loop'),
  new IconDefinition(MdiIcons.loupe, 'loupe'),
  new IconDefinition(MdiIcons.lumx, 'lumx'),
  new IconDefinition(MdiIcons.lyft, 'lyft'),
  new IconDefinition(MdiIcons.magnet, 'magnet'),
  new IconDefinition(MdiIcons.magnetOn, 'magnetOn'),
  new IconDefinition(MdiIcons.magnify, 'magnify'),
  new IconDefinition(MdiIcons.magnifyClose, 'magnifyClose'),
  new IconDefinition(MdiIcons.magnifyMinus, 'magnifyMinus'),
  new IconDefinition(MdiIcons.magnifyMinusCursor, 'magnifyMinusCursor'),
  new IconDefinition(MdiIcons.magnifyMinusOutline, 'magnifyMinusOutline'),
  new IconDefinition(MdiIcons.magnifyPlus, 'magnifyPlus'),
  new IconDefinition(MdiIcons.magnifyPlusCursor, 'magnifyPlusCursor'),
  new IconDefinition(MdiIcons.magnifyPlusOutline, 'magnifyPlusOutline'),
  new IconDefinition(MdiIcons.mailRu, 'mailRu'),
  new IconDefinition(MdiIcons.mailbox, 'mailbox'),
  new IconDefinition(MdiIcons.map, 'map'),
  new IconDefinition(MdiIcons.mapLegend, 'mapLegend'),
  new IconDefinition(MdiIcons.mapMarker, 'mapMarker'),
  new IconDefinition(MdiIcons.mapMarkerCheck, 'mapMarkerCheck'),
  new IconDefinition(MdiIcons.mapMarkerCircle, 'mapMarkerCircle'),
  new IconDefinition(MdiIcons.mapMarkerDistance, 'mapMarkerDistance'),
  new IconDefinition(MdiIcons.mapMarkerMinus, 'mapMarkerMinus'),
  new IconDefinition(MdiIcons.mapMarkerMultiple, 'mapMarkerMultiple'),
  new IconDefinition(MdiIcons.mapMarkerOff, 'mapMarkerOff'),
  new IconDefinition(MdiIcons.mapMarkerOutline, 'mapMarkerOutline'),
  new IconDefinition(MdiIcons.mapMarkerPlus, 'mapMarkerPlus'),
  new IconDefinition(MdiIcons.mapMarkerRadius, 'mapMarkerRadius'),
  new IconDefinition(MdiIcons.mapMinus, 'mapMinus'),
  new IconDefinition(MdiIcons.mapOutline, 'mapOutline'),
  new IconDefinition(MdiIcons.mapPlus, 'mapPlus'),
  new IconDefinition(MdiIcons.mapSearch, 'mapSearch'),
  new IconDefinition(MdiIcons.mapSearchOutline, 'mapSearchOutline'),
  new IconDefinition(MdiIcons.mapbox, 'mapbox'),
  new IconDefinition(MdiIcons.margin, 'margin'),
  new IconDefinition(MdiIcons.markdown, 'markdown'),
  new IconDefinition(MdiIcons.marker, 'marker'),
  new IconDefinition(MdiIcons.markerCheck, 'markerCheck'),
  new IconDefinition(MdiIcons.mastodon, 'mastodon'),
  new IconDefinition(MdiIcons.mastodonVariant, 'mastodonVariant'),
  new IconDefinition(MdiIcons.materialDesign, 'materialDesign'),
  new IconDefinition(MdiIcons.materialUi, 'materialUi'),
  new IconDefinition(MdiIcons.mathCompass, 'mathCompass'),
  new IconDefinition(MdiIcons.mathCos, 'mathCos'),
  new IconDefinition(MdiIcons.mathSin, 'mathSin'),
  new IconDefinition(MdiIcons.mathTan, 'mathTan'),
  new IconDefinition(MdiIcons.matrix, 'matrix'),
  new IconDefinition(MdiIcons.maxcdn, 'maxcdn'),
  new IconDefinition(MdiIcons.medal, 'medal'),
  new IconDefinition(MdiIcons.medicalBag, 'medicalBag'),
  new IconDefinition(MdiIcons.medium, 'medium'),
  new IconDefinition(MdiIcons.meetup, 'meetup'),
  new IconDefinition(MdiIcons.memory, 'memory'),
  new IconDefinition(MdiIcons.menu, 'menu'),
  new IconDefinition(MdiIcons.menuDown, 'menuDown'),
  new IconDefinition(MdiIcons.menuDownOutline, 'menuDownOutline'),
  new IconDefinition(MdiIcons.menuLeft, 'menuLeft'),
  new IconDefinition(MdiIcons.menuLeftOutline, 'menuLeftOutline'),
  new IconDefinition(MdiIcons.menuOpen, 'menuOpen'),
  new IconDefinition(MdiIcons.menuRight, 'menuRight'),
  new IconDefinition(MdiIcons.menuRightOutline, 'menuRightOutline'),
  new IconDefinition(MdiIcons.menuSwap, 'menuSwap'),
  new IconDefinition(MdiIcons.menuSwapOutline, 'menuSwapOutline'),
  new IconDefinition(MdiIcons.menuUp, 'menuUp'),
  new IconDefinition(MdiIcons.menuUpOutline, 'menuUpOutline'),
  new IconDefinition(MdiIcons.message, 'message'),
  new IconDefinition(MdiIcons.messageAlert, 'messageAlert'),
  new IconDefinition(MdiIcons.messageAlertOutline, 'messageAlertOutline'),
  new IconDefinition(MdiIcons.messageBulleted, 'messageBulleted'),
  new IconDefinition(MdiIcons.messageBulletedOff, 'messageBulletedOff'),
  new IconDefinition(MdiIcons.messageDraw, 'messageDraw'),
  new IconDefinition(MdiIcons.messageImage, 'messageImage'),
  new IconDefinition(MdiIcons.messageOutline, 'messageOutline'),
  new IconDefinition(MdiIcons.messagePlus, 'messagePlus'),
  new IconDefinition(MdiIcons.messageProcessing, 'messageProcessing'),
  new IconDefinition(MdiIcons.messageReply, 'messageReply'),
  new IconDefinition(MdiIcons.messageReplyText, 'messageReplyText'),
  new IconDefinition(MdiIcons.messageSettings, 'messageSettings'),
  new IconDefinition(MdiIcons.messageSettingsVariant, 'messageSettingsVariant'),
  new IconDefinition(MdiIcons.messageText, 'messageText'),
  new IconDefinition(MdiIcons.messageTextOutline, 'messageTextOutline'),
  new IconDefinition(MdiIcons.messageVideo, 'messageVideo'),
  new IconDefinition(MdiIcons.meteor, 'meteor'),
  new IconDefinition(MdiIcons.metronome, 'metronome'),
  new IconDefinition(MdiIcons.metronomeTick, 'metronomeTick'),
  new IconDefinition(MdiIcons.microSd, 'microSd'),
  new IconDefinition(MdiIcons.microphone, 'microphone'),
  new IconDefinition(MdiIcons.microphoneMinus, 'microphoneMinus'),
  new IconDefinition(MdiIcons.microphoneOff, 'microphoneOff'),
  new IconDefinition(MdiIcons.microphoneOutline, 'microphoneOutline'),
  new IconDefinition(MdiIcons.microphonePlus, 'microphonePlus'),
  new IconDefinition(MdiIcons.microphoneSettings, 'microphoneSettings'),
  new IconDefinition(MdiIcons.microphoneVariant, 'microphoneVariant'),
  new IconDefinition(MdiIcons.microphoneVariantOff, 'microphoneVariantOff'),
  new IconDefinition(MdiIcons.microscope, 'microscope'),
  new IconDefinition(MdiIcons.microsoft, 'microsoft'),
  new IconDefinition(MdiIcons.microsoftDynamics, 'microsoftDynamics'),
  new IconDefinition(MdiIcons.microwave, 'microwave'),
  new IconDefinition(MdiIcons.midi, 'midi'),
  new IconDefinition(MdiIcons.midiPort, 'midiPort'),
  new IconDefinition(MdiIcons.minecraft, 'minecraft'),
  new IconDefinition(MdiIcons.miniSd, 'miniSd'),
  new IconDefinition(MdiIcons.minidisc, 'minidisc'),
  new IconDefinition(MdiIcons.minus, 'minus'),
  new IconDefinition(MdiIcons.minusBox, 'minusBox'),
  new IconDefinition(MdiIcons.minusBoxOutline, 'minusBoxOutline'),
  new IconDefinition(MdiIcons.minusCircle, 'minusCircle'),
  new IconDefinition(MdiIcons.minusCircleOutline, 'minusCircleOutline'),
  new IconDefinition(MdiIcons.minusNetwork, 'minusNetwork'),
  new IconDefinition(MdiIcons.minusNetworkOutline, 'minusNetworkOutline'),
  new IconDefinition(MdiIcons.mixcloud, 'mixcloud'),
  new IconDefinition(MdiIcons.mixedReality, 'mixedReality'),
  new IconDefinition(MdiIcons.mixer, 'mixer'),
  new IconDefinition(MdiIcons.molecule, 'molecule'),
  new IconDefinition(MdiIcons.monitor, 'monitor'),
  new IconDefinition(MdiIcons.monitorCellphone, 'monitorCellphone'),
  new IconDefinition(MdiIcons.monitorCellphoneStar, 'monitorCellphoneStar'),
  new IconDefinition(MdiIcons.monitorDashboard, 'monitorDashboard'),
  new IconDefinition(MdiIcons.monitorMultiple, 'monitorMultiple'),
  new IconDefinition(MdiIcons.more, 'more'),
  new IconDefinition(MdiIcons.motorbike, 'motorbike'),
  new IconDefinition(MdiIcons.mouse, 'mouse'),
  new IconDefinition(MdiIcons.mouseBluetooth, 'mouseBluetooth'),
  new IconDefinition(MdiIcons.mouseOff, 'mouseOff'),
  new IconDefinition(MdiIcons.mouseVariant, 'mouseVariant'),
  new IconDefinition(MdiIcons.mouseVariantOff, 'mouseVariantOff'),
  new IconDefinition(MdiIcons.moveResize, 'moveResize'),
  new IconDefinition(MdiIcons.moveResizeVariant, 'moveResizeVariant'),
  new IconDefinition(MdiIcons.movie, 'movie'),
  new IconDefinition(MdiIcons.movieRoll, 'movieRoll'),
  new IconDefinition(MdiIcons.muffin, 'muffin'),
  new IconDefinition(MdiIcons.multiplication, 'multiplication'),
  new IconDefinition(MdiIcons.multiplicationBox, 'multiplicationBox'),
  new IconDefinition(MdiIcons.mushroom, 'mushroom'),
  new IconDefinition(MdiIcons.mushroomOutline, 'mushroomOutline'),
  new IconDefinition(MdiIcons.music, 'music'),
  new IconDefinition(MdiIcons.musicBox, 'musicBox'),
  new IconDefinition(MdiIcons.musicBoxOutline, 'musicBoxOutline'),
  new IconDefinition(MdiIcons.musicCircle, 'musicCircle'),
  new IconDefinition(MdiIcons.musicCircleOutline, 'musicCircleOutline'),
  new IconDefinition(MdiIcons.musicNote, 'musicNote'),
  new IconDefinition(MdiIcons.musicNoteBluetooth, 'musicNoteBluetooth'),
  new IconDefinition(MdiIcons.musicNoteBluetoothOff, 'musicNoteBluetoothOff'),
  new IconDefinition(MdiIcons.musicNoteEighth, 'musicNoteEighth'),
  new IconDefinition(MdiIcons.musicNoteHalf, 'musicNoteHalf'),
  new IconDefinition(MdiIcons.musicNoteOff, 'musicNoteOff'),
  new IconDefinition(MdiIcons.musicNoteQuarter, 'musicNoteQuarter'),
  new IconDefinition(MdiIcons.musicNoteSixteenth, 'musicNoteSixteenth'),
  new IconDefinition(MdiIcons.musicNoteWhole, 'musicNoteWhole'),
  new IconDefinition(MdiIcons.musicOff, 'musicOff'),
  new IconDefinition(MdiIcons.nas, 'nas'),
  new IconDefinition(MdiIcons.nativescript, 'nativescript'),
  new IconDefinition(MdiIcons.nature, 'nature'),
  new IconDefinition(MdiIcons.naturePeople, 'naturePeople'),
  new IconDefinition(MdiIcons.navigation, 'navigation'),
  new IconDefinition(MdiIcons.nearMe, 'nearMe'),
  new IconDefinition(MdiIcons.needle, 'needle'),
  new IconDefinition(MdiIcons.netflix, 'netflix'),
  new IconDefinition(MdiIcons.network, 'network'),
  new IconDefinition(MdiIcons.networkOff, 'networkOff'),
  new IconDefinition(MdiIcons.networkOffOutline, 'networkOffOutline'),
  new IconDefinition(MdiIcons.networkOutline, 'networkOutline'),
  new IconDefinition(MdiIcons.networkStrength1, 'networkStrength1'),
  new IconDefinition(MdiIcons.networkStrength1Alert, 'networkStrength1Alert'),
  new IconDefinition(MdiIcons.networkStrength2, 'networkStrength2'),
  new IconDefinition(MdiIcons.networkStrength2Alert, 'networkStrength2Alert'),
  new IconDefinition(MdiIcons.networkStrength3, 'networkStrength3'),
  new IconDefinition(MdiIcons.networkStrength3Alert, 'networkStrength3Alert'),
  new IconDefinition(MdiIcons.networkStrength4, 'networkStrength4'),
  new IconDefinition(MdiIcons.networkStrength4Alert, 'networkStrength4Alert'),
  new IconDefinition(MdiIcons.networkStrengthOff, 'networkStrengthOff'),
  new IconDefinition(MdiIcons.networkStrengthOffOutline, 'networkStrengthOffOutline'),
  new IconDefinition(MdiIcons.networkStrengthOutline, 'networkStrengthOutline'),
  new IconDefinition(MdiIcons.newBox, 'newBox'),
  new IconDefinition(MdiIcons.newspaper, 'newspaper'),
  new IconDefinition(MdiIcons.nfc, 'nfc'),
  new IconDefinition(MdiIcons.nfcTap, 'nfcTap'),
  new IconDefinition(MdiIcons.nfcVariant, 'nfcVariant'),
  new IconDefinition(MdiIcons.ninja, 'ninja'),
  new IconDefinition(MdiIcons.nintendoSwitch, 'nintendoSwitch'),
  new IconDefinition(MdiIcons.nodejs, 'nodejs'),
  new IconDefinition(MdiIcons.notEqual, 'notEqual'),
  new IconDefinition(MdiIcons.notEqualVariant, 'notEqualVariant'),
  new IconDefinition(MdiIcons.note, 'note'),
  new IconDefinition(MdiIcons.noteMultiple, 'noteMultiple'),
  new IconDefinition(MdiIcons.noteMultipleOutline, 'noteMultipleOutline'),
  new IconDefinition(MdiIcons.noteOutline, 'noteOutline'),
  new IconDefinition(MdiIcons.notePlus, 'notePlus'),
  new IconDefinition(MdiIcons.notePlusOutline, 'notePlusOutline'),
  new IconDefinition(MdiIcons.noteText, 'noteText'),
  new IconDefinition(MdiIcons.notebook, 'notebook'),
  new IconDefinition(MdiIcons.notificationClearAll, 'notificationClearAll'),
  new IconDefinition(MdiIcons.npm, 'npm'),
  new IconDefinition(MdiIcons.npmVariant, 'npmVariant'),
  new IconDefinition(MdiIcons.npmVariantOutline, 'npmVariantOutline'),
  new IconDefinition(MdiIcons.nuke, 'nuke'),
  new IconDefinition(MdiIcons.nullIcon, 'nullIcon'),
  new IconDefinition(MdiIcons.numeric, 'numeric'),
  new IconDefinition(MdiIcons.numeric0, 'numeric0'),
  new IconDefinition(MdiIcons.numeric0Box, 'numeric0Box'),
  new IconDefinition(MdiIcons.numeric0BoxMultipleOutline, 'numeric0BoxMultipleOutline'),
  new IconDefinition(MdiIcons.numeric0BoxOutline, 'numeric0BoxOutline'),
  new IconDefinition(MdiIcons.numeric0Circle, 'numeric0Circle'),
  new IconDefinition(MdiIcons.numeric0CircleOutline, 'numeric0CircleOutline'),
  new IconDefinition(MdiIcons.numeric1, 'numeric1'),
  new IconDefinition(MdiIcons.numeric1Box, 'numeric1Box'),
  new IconDefinition(MdiIcons.numeric1BoxMultipleOutline, 'numeric1BoxMultipleOutline'),
  new IconDefinition(MdiIcons.numeric1BoxOutline, 'numeric1BoxOutline'),
  new IconDefinition(MdiIcons.numeric1Circle, 'numeric1Circle'),
  new IconDefinition(MdiIcons.numeric1CircleOutline, 'numeric1CircleOutline'),
  new IconDefinition(MdiIcons.numeric2, 'numeric2'),
  new IconDefinition(MdiIcons.numeric2Box, 'numeric2Box'),
  new IconDefinition(MdiIcons.numeric2BoxMultipleOutline, 'numeric2BoxMultipleOutline'),
  new IconDefinition(MdiIcons.numeric2BoxOutline, 'numeric2BoxOutline'),
  new IconDefinition(MdiIcons.numeric2Circle, 'numeric2Circle'),
  new IconDefinition(MdiIcons.numeric2CircleOutline, 'numeric2CircleOutline'),
  new IconDefinition(MdiIcons.numeric3, 'numeric3'),
  new IconDefinition(MdiIcons.numeric3Box, 'numeric3Box'),
  new IconDefinition(MdiIcons.numeric3BoxMultipleOutline, 'numeric3BoxMultipleOutline'),
  new IconDefinition(MdiIcons.numeric3BoxOutline, 'numeric3BoxOutline'),
  new IconDefinition(MdiIcons.numeric3Circle, 'numeric3Circle'),
  new IconDefinition(MdiIcons.numeric3CircleOutline, 'numeric3CircleOutline'),
  new IconDefinition(MdiIcons.numeric4, 'numeric4'),
  new IconDefinition(MdiIcons.numeric4Box, 'numeric4Box'),
  new IconDefinition(MdiIcons.numeric4BoxMultipleOutline, 'numeric4BoxMultipleOutline'),
  new IconDefinition(MdiIcons.numeric4BoxOutline, 'numeric4BoxOutline'),
  new IconDefinition(MdiIcons.numeric4Circle, 'numeric4Circle'),
  new IconDefinition(MdiIcons.numeric4CircleOutline, 'numeric4CircleOutline'),
  new IconDefinition(MdiIcons.numeric5, 'numeric5'),
  new IconDefinition(MdiIcons.numeric5Box, 'numeric5Box'),
  new IconDefinition(MdiIcons.numeric5BoxMultipleOutline, 'numeric5BoxMultipleOutline'),
  new IconDefinition(MdiIcons.numeric5BoxOutline, 'numeric5BoxOutline'),
  new IconDefinition(MdiIcons.numeric5Circle, 'numeric5Circle'),
  new IconDefinition(MdiIcons.numeric5CircleOutline, 'numeric5CircleOutline'),
  new IconDefinition(MdiIcons.numeric6, 'numeric6'),
  new IconDefinition(MdiIcons.numeric6Box, 'numeric6Box'),
  new IconDefinition(MdiIcons.numeric6BoxMultipleOutline, 'numeric6BoxMultipleOutline'),
  new IconDefinition(MdiIcons.numeric6BoxOutline, 'numeric6BoxOutline'),
  new IconDefinition(MdiIcons.numeric6Circle, 'numeric6Circle'),
  new IconDefinition(MdiIcons.numeric6CircleOutline, 'numeric6CircleOutline'),
  new IconDefinition(MdiIcons.numeric7, 'numeric7'),
  new IconDefinition(MdiIcons.numeric7Box, 'numeric7Box'),
  new IconDefinition(MdiIcons.numeric7BoxMultipleOutline, 'numeric7BoxMultipleOutline'),
  new IconDefinition(MdiIcons.numeric7BoxOutline, 'numeric7BoxOutline'),
  new IconDefinition(MdiIcons.numeric7Circle, 'numeric7Circle'),
  new IconDefinition(MdiIcons.numeric7CircleOutline, 'numeric7CircleOutline'),
  new IconDefinition(MdiIcons.numeric8, 'numeric8'),
  new IconDefinition(MdiIcons.numeric8Box, 'numeric8Box'),
  new IconDefinition(MdiIcons.numeric8BoxMultipleOutline, 'numeric8BoxMultipleOutline'),
  new IconDefinition(MdiIcons.numeric8BoxOutline, 'numeric8BoxOutline'),
  new IconDefinition(MdiIcons.numeric8Circle, 'numeric8Circle'),
  new IconDefinition(MdiIcons.numeric8CircleOutline, 'numeric8CircleOutline'),
  new IconDefinition(MdiIcons.numeric9, 'numeric9'),
  new IconDefinition(MdiIcons.numeric9Box, 'numeric9Box'),
  new IconDefinition(MdiIcons.numeric9BoxMultipleOutline, 'numeric9BoxMultipleOutline'),
  new IconDefinition(MdiIcons.numeric9BoxOutline, 'numeric9BoxOutline'),
  new IconDefinition(MdiIcons.numeric9Circle, 'numeric9Circle'),
  new IconDefinition(MdiIcons.numeric9CircleOutline, 'numeric9CircleOutline'),
  new IconDefinition(MdiIcons.numeric9PlusBox, 'numeric9PlusBox'),
  new IconDefinition(MdiIcons.numeric9PlusBoxMultipleOutline, 'numeric9PlusBoxMultipleOutline'),
  new IconDefinition(MdiIcons.numeric9PlusBoxOutline, 'numeric9PlusBoxOutline'),
  new IconDefinition(MdiIcons.numeric9PlusCircle, 'numeric9PlusCircle'),
  new IconDefinition(MdiIcons.numeric9PlusCircleOutline, 'numeric9PlusCircleOutline'),
  new IconDefinition(MdiIcons.nut, 'nut'),
  new IconDefinition(MdiIcons.nutrition, 'nutrition'),
  new IconDefinition(MdiIcons.oar, 'oar'),
  new IconDefinition(MdiIcons.octagon, 'octagon'),
  new IconDefinition(MdiIcons.octagonOutline, 'octagonOutline'),
  new IconDefinition(MdiIcons.octagram, 'octagram'),
  new IconDefinition(MdiIcons.octagramOutline, 'octagramOutline'),
  new IconDefinition(MdiIcons.odnoklassniki, 'odnoklassniki'),
  new IconDefinition(MdiIcons.office, 'office'),
  new IconDefinition(MdiIcons.officeBuilding, 'officeBuilding'),
  new IconDefinition(MdiIcons.oil, 'oil'),
  new IconDefinition(MdiIcons.oilTemperature, 'oilTemperature'),
  new IconDefinition(MdiIcons.omega, 'omega'),
  new IconDefinition(MdiIcons.oneUp, 'oneUp'),
  new IconDefinition(MdiIcons.onedrive, 'onedrive'),
  new IconDefinition(MdiIcons.onenote, 'onenote'),
  new IconDefinition(MdiIcons.onepassword, 'onepassword'),
  new IconDefinition(MdiIcons.opacity, 'opacity'),
  new IconDefinition(MdiIcons.openInApp, 'openInApp'),
  new IconDefinition(MdiIcons.openInNew, 'openInNew'),
  new IconDefinition(MdiIcons.openSourceInitiative, 'openSourceInitiative'),
  new IconDefinition(MdiIcons.openid, 'openid'),
  new IconDefinition(MdiIcons.opera, 'opera'),
  new IconDefinition(MdiIcons.orbit, 'orbit'),
  new IconDefinition(MdiIcons.origin, 'origin'),
  new IconDefinition(MdiIcons.ornament, 'ornament'),
  new IconDefinition(MdiIcons.ornamentVariant, 'ornamentVariant'),
  new IconDefinition(MdiIcons.owl, 'owl'),
  new IconDefinition(MdiIcons.pacMan, 'pacMan'),
  new IconDefinition(MdiIcons.package, 'package'),
  new IconDefinition(MdiIcons.packageDown, 'packageDown'),
  new IconDefinition(MdiIcons.packageUp, 'packageUp'),
  new IconDefinition(MdiIcons.packageVariant, 'packageVariant'),
  new IconDefinition(MdiIcons.packageVariantClosed, 'packageVariantClosed'),
  new IconDefinition(MdiIcons.pageFirst, 'pageFirst'),
  new IconDefinition(MdiIcons.pageLast, 'pageLast'),
  new IconDefinition(MdiIcons.pageLayoutBody, 'pageLayoutBody'),
  new IconDefinition(MdiIcons.pageLayoutFooter, 'pageLayoutFooter'),
  new IconDefinition(MdiIcons.pageLayoutHeader, 'pageLayoutHeader'),
  new IconDefinition(MdiIcons.pageLayoutSidebarLeft, 'pageLayoutSidebarLeft'),
  new IconDefinition(MdiIcons.pageLayoutSidebarRight, 'pageLayoutSidebarRight'),
  new IconDefinition(MdiIcons.pageNext, 'pageNext'),
  new IconDefinition(MdiIcons.pageNextOutline, 'pageNextOutline'),
  new IconDefinition(MdiIcons.pagePrevious, 'pagePrevious'),
  new IconDefinition(MdiIcons.pagePreviousOutline, 'pagePreviousOutline'),
  new IconDefinition(MdiIcons.palette, 'palette'),
  new IconDefinition(MdiIcons.paletteAdvanced, 'paletteAdvanced'),
  new IconDefinition(MdiIcons.paletteSwatch, 'paletteSwatch'),
  new IconDefinition(MdiIcons.pan, 'pan'),
  new IconDefinition(MdiIcons.panBottomLeft, 'panBottomLeft'),
  new IconDefinition(MdiIcons.panBottomRight, 'panBottomRight'),
  new IconDefinition(MdiIcons.panDown, 'panDown'),
  new IconDefinition(MdiIcons.panHorizontal, 'panHorizontal'),
  new IconDefinition(MdiIcons.panLeft, 'panLeft'),
  new IconDefinition(MdiIcons.panRight, 'panRight'),
  new IconDefinition(MdiIcons.panTopLeft, 'panTopLeft'),
  new IconDefinition(MdiIcons.panTopRight, 'panTopRight'),
  new IconDefinition(MdiIcons.panUp, 'panUp'),
  new IconDefinition(MdiIcons.panVertical, 'panVertical'),
  new IconDefinition(MdiIcons.panda, 'panda'),
  new IconDefinition(MdiIcons.pandora, 'pandora'),
  new IconDefinition(MdiIcons.panorama, 'panorama'),
  new IconDefinition(MdiIcons.panoramaFisheye, 'panoramaFisheye'),
  new IconDefinition(MdiIcons.panoramaHorizontal, 'panoramaHorizontal'),
  new IconDefinition(MdiIcons.panoramaVertical, 'panoramaVertical'),
  new IconDefinition(MdiIcons.panoramaWideAngle, 'panoramaWideAngle'),
  new IconDefinition(MdiIcons.paperCutVertical, 'paperCutVertical'),
  new IconDefinition(MdiIcons.paperclip, 'paperclip'),
  new IconDefinition(MdiIcons.parachute, 'parachute'),
  new IconDefinition(MdiIcons.parachuteOutline, 'parachuteOutline'),
  new IconDefinition(MdiIcons.parking, 'parking'),
  new IconDefinition(MdiIcons.passport, 'passport'),
  new IconDefinition(MdiIcons.patreon, 'patreon'),
  new IconDefinition(MdiIcons.pause, 'pause'),
  new IconDefinition(MdiIcons.pauseCircle, 'pauseCircle'),
  new IconDefinition(MdiIcons.pauseCircleOutline, 'pauseCircleOutline'),
  new IconDefinition(MdiIcons.pauseOctagon, 'pauseOctagon'),
  new IconDefinition(MdiIcons.pauseOctagonOutline, 'pauseOctagonOutline'),
  new IconDefinition(MdiIcons.paw, 'paw'),
  new IconDefinition(MdiIcons.pawOff, 'pawOff'),
  new IconDefinition(MdiIcons.paypal, 'paypal'),
  new IconDefinition(MdiIcons.peace, 'peace'),
  new IconDefinition(MdiIcons.pen, 'pen'),
  new IconDefinition(MdiIcons.pencil, 'pencil'),
  new IconDefinition(MdiIcons.pencilBox, 'pencilBox'),
  new IconDefinition(MdiIcons.pencilBoxOutline, 'pencilBoxOutline'),
  new IconDefinition(MdiIcons.pencilCircle, 'pencilCircle'),
  new IconDefinition(MdiIcons.pencilCircleOutline, 'pencilCircleOutline'),
  new IconDefinition(MdiIcons.pencilLock, 'pencilLock'),
  new IconDefinition(MdiIcons.pencilOff, 'pencilOff'),
  new IconDefinition(MdiIcons.pencilOutline, 'pencilOutline'),
  new IconDefinition(MdiIcons.pentagon, 'pentagon'),
  new IconDefinition(MdiIcons.pentagonOutline, 'pentagonOutline'),
  new IconDefinition(MdiIcons.percent, 'percent'),
  new IconDefinition(MdiIcons.periodicTable, 'periodicTable'),
  new IconDefinition(MdiIcons.periodicTableCo2, 'periodicTableCo2'),
  new IconDefinition(MdiIcons.periscope, 'periscope'),
  new IconDefinition(MdiIcons.pharmacy, 'pharmacy'),
  new IconDefinition(MdiIcons.phone, 'phone'),
  new IconDefinition(MdiIcons.phoneBluetooth, 'phoneBluetooth'),
  new IconDefinition(MdiIcons.phoneClassic, 'phoneClassic'),
  new IconDefinition(MdiIcons.phoneForward, 'phoneForward'),
  new IconDefinition(MdiIcons.phoneHangup, 'phoneHangup'),
  new IconDefinition(MdiIcons.phoneInTalk, 'phoneInTalk'),
  new IconDefinition(MdiIcons.phoneIncoming, 'phoneIncoming'),
  new IconDefinition(MdiIcons.phoneLock, 'phoneLock'),
  new IconDefinition(MdiIcons.phoneLog, 'phoneLog'),
  new IconDefinition(MdiIcons.phoneMinus, 'phoneMinus'),
  new IconDefinition(MdiIcons.phoneMissed, 'phoneMissed'),
  new IconDefinition(MdiIcons.phoneOutgoing, 'phoneOutgoing'),
  new IconDefinition(MdiIcons.phonePaused, 'phonePaused'),
  new IconDefinition(MdiIcons.phonePlus, 'phonePlus'),
  new IconDefinition(MdiIcons.phoneReturn, 'phoneReturn'),
  new IconDefinition(MdiIcons.phoneRotateLandscape, 'phoneRotateLandscape'),
  new IconDefinition(MdiIcons.phoneRotatePortrait, 'phoneRotatePortrait'),
  new IconDefinition(MdiIcons.phoneSettings, 'phoneSettings'),
  new IconDefinition(MdiIcons.phoneVoip, 'phoneVoip'),
  new IconDefinition(MdiIcons.pi, 'pi'),
  new IconDefinition(MdiIcons.piBox, 'piBox'),
  new IconDefinition(MdiIcons.piano, 'piano'),
  new IconDefinition(MdiIcons.pickaxe, 'pickaxe'),
  new IconDefinition(MdiIcons.pier, 'pier'),
  new IconDefinition(MdiIcons.pierCrane, 'pierCrane'),
  new IconDefinition(MdiIcons.pig, 'pig'),
  new IconDefinition(MdiIcons.pill, 'pill'),
  new IconDefinition(MdiIcons.pillar, 'pillar'),
  new IconDefinition(MdiIcons.pin, 'pin'),
  new IconDefinition(MdiIcons.pinOff, 'pinOff'),
  new IconDefinition(MdiIcons.pinOffOutline, 'pinOffOutline'),
  new IconDefinition(MdiIcons.pinOutline, 'pinOutline'),
  new IconDefinition(MdiIcons.pineTree, 'pineTree'),
  new IconDefinition(MdiIcons.pineTreeBox, 'pineTreeBox'),
  new IconDefinition(MdiIcons.pinterest, 'pinterest'),
  new IconDefinition(MdiIcons.pinterestBox, 'pinterestBox'),
  new IconDefinition(MdiIcons.pinwheel, 'pinwheel'),
  new IconDefinition(MdiIcons.pinwheelOutline, 'pinwheelOutline'),
  new IconDefinition(MdiIcons.pipe, 'pipe'),
  new IconDefinition(MdiIcons.pipeDisconnected, 'pipeDisconnected'),
  new IconDefinition(MdiIcons.pipeLeak, 'pipeLeak'),
  new IconDefinition(MdiIcons.pirate, 'pirate'),
  new IconDefinition(MdiIcons.pistol, 'pistol'),
  new IconDefinition(MdiIcons.piston, 'piston'),
  new IconDefinition(MdiIcons.pizza, 'pizza'),
  new IconDefinition(MdiIcons.play, 'play'),
  new IconDefinition(MdiIcons.playBoxOutline, 'playBoxOutline'),
  new IconDefinition(MdiIcons.playCircle, 'playCircle'),
  new IconDefinition(MdiIcons.playCircleOutline, 'playCircleOutline'),
  new IconDefinition(MdiIcons.playNetwork, 'playNetwork'),
  new IconDefinition(MdiIcons.playNetworkOutline, 'playNetworkOutline'),
  new IconDefinition(MdiIcons.playPause, 'playPause'),
  new IconDefinition(MdiIcons.playProtectedContent, 'playProtectedContent'),
  new IconDefinition(MdiIcons.playSpeed, 'playSpeed'),
  new IconDefinition(MdiIcons.playlistCheck, 'playlistCheck'),
  new IconDefinition(MdiIcons.playlistEdit, 'playlistEdit'),
  new IconDefinition(MdiIcons.playlistMinus, 'playlistMinus'),
  new IconDefinition(MdiIcons.playlistMusic, 'playlistMusic'),
  new IconDefinition(MdiIcons.playlistMusicOutline, 'playlistMusicOutline'),
  new IconDefinition(MdiIcons.playlistPlay, 'playlistPlay'),
  new IconDefinition(MdiIcons.playlistPlus, 'playlistPlus'),
  new IconDefinition(MdiIcons.playlistRemove, 'playlistRemove'),
  new IconDefinition(MdiIcons.playstation, 'playstation'),
  new IconDefinition(MdiIcons.plex, 'plex'),
  new IconDefinition(MdiIcons.plus, 'plus'),
  new IconDefinition(MdiIcons.plusBox, 'plusBox'),
  new IconDefinition(MdiIcons.plusBoxOutline, 'plusBoxOutline'),
  new IconDefinition(MdiIcons.plusCircle, 'plusCircle'),
  new IconDefinition(MdiIcons.plusCircleMultipleOutline, 'plusCircleMultipleOutline'),
  new IconDefinition(MdiIcons.plusCircleOutline, 'plusCircleOutline'),
  new IconDefinition(MdiIcons.plusMinus, 'plusMinus'),
  new IconDefinition(MdiIcons.plusMinusBox, 'plusMinusBox'),
  new IconDefinition(MdiIcons.plusNetwork, 'plusNetwork'),
  new IconDefinition(MdiIcons.plusNetworkOutline, 'plusNetworkOutline'),
  new IconDefinition(MdiIcons.plusOne, 'plusOne'),
  new IconDefinition(MdiIcons.plusOutline, 'plusOutline'),
  new IconDefinition(MdiIcons.pocket, 'pocket'),
  new IconDefinition(MdiIcons.podcast, 'podcast'),
  new IconDefinition(MdiIcons.pokeball, 'pokeball'),
  new IconDefinition(MdiIcons.pokemonGo, 'pokemonGo'),
  new IconDefinition(MdiIcons.pokerChip, 'pokerChip'),
  new IconDefinition(MdiIcons.polaroid, 'polaroid'),
  new IconDefinition(MdiIcons.poll, 'poll'),
  new IconDefinition(MdiIcons.pollBox, 'pollBox'),
  new IconDefinition(MdiIcons.polymer, 'polymer'),
  new IconDefinition(MdiIcons.pool, 'pool'),
  new IconDefinition(MdiIcons.popcorn, 'popcorn'),
  new IconDefinition(MdiIcons.postageStamp, 'postageStamp'),
  new IconDefinition(MdiIcons.pot, 'pot'),
  new IconDefinition(MdiIcons.potMix, 'potMix'),
  new IconDefinition(MdiIcons.pound, 'pound'),
  new IconDefinition(MdiIcons.poundBox, 'poundBox'),
  new IconDefinition(MdiIcons.power, 'power'),
  new IconDefinition(MdiIcons.powerCycle, 'powerCycle'),
  new IconDefinition(MdiIcons.powerOff, 'powerOff'),
  new IconDefinition(MdiIcons.powerOn, 'powerOn'),
  new IconDefinition(MdiIcons.powerPlug, 'powerPlug'),
  new IconDefinition(MdiIcons.powerPlugOff, 'powerPlugOff'),
  new IconDefinition(MdiIcons.powerSettings, 'powerSettings'),
  new IconDefinition(MdiIcons.powerSleep, 'powerSleep'),
  new IconDefinition(MdiIcons.powerSocket, 'powerSocket'),
  new IconDefinition(MdiIcons.powerSocketAu, 'powerSocketAu'),
  new IconDefinition(MdiIcons.powerSocketEu, 'powerSocketEu'),
  new IconDefinition(MdiIcons.powerSocketUk, 'powerSocketUk'),
  new IconDefinition(MdiIcons.powerSocketUs, 'powerSocketUs'),
  new IconDefinition(MdiIcons.powerStandby, 'powerStandby'),
  new IconDefinition(MdiIcons.powershell, 'powershell'),
  new IconDefinition(MdiIcons.prescription, 'prescription'),
  new IconDefinition(MdiIcons.presentation, 'presentation'),
  new IconDefinition(MdiIcons.presentationPlay, 'presentationPlay'),
  new IconDefinition(MdiIcons.printer, 'printer'),
  new IconDefinition(MdiIcons.printer3d, 'printer3d'),
  new IconDefinition(MdiIcons.printerAlert, 'printerAlert'),
  new IconDefinition(MdiIcons.printerSettings, 'printerSettings'),
  new IconDefinition(MdiIcons.printerWireless, 'printerWireless'),
  new IconDefinition(MdiIcons.priorityHigh, 'priorityHigh'),
  new IconDefinition(MdiIcons.priorityLow, 'priorityLow'),
  new IconDefinition(MdiIcons.professionalHexagon, 'professionalHexagon'),
  new IconDefinition(MdiIcons.progressAlert, 'progressAlert'),
  new IconDefinition(MdiIcons.progressCheck, 'progressCheck'),
  new IconDefinition(MdiIcons.progressClock, 'progressClock'),
  new IconDefinition(MdiIcons.progressDownload, 'progressDownload'),
  new IconDefinition(MdiIcons.progressUpload, 'progressUpload'),
  new IconDefinition(MdiIcons.progressWrench, 'progressWrench'),
  new IconDefinition(MdiIcons.projector, 'projector'),
  new IconDefinition(MdiIcons.projectorScreen, 'projectorScreen'),
  new IconDefinition(MdiIcons.publish, 'publish'),
  new IconDefinition(MdiIcons.pulse, 'pulse'),
  new IconDefinition(MdiIcons.pumpkin, 'pumpkin'),
  new IconDefinition(MdiIcons.puzzle, 'puzzle'),
  new IconDefinition(MdiIcons.puzzleOutline, 'puzzleOutline'),
  new IconDefinition(MdiIcons.qi, 'qi'),
  new IconDefinition(MdiIcons.qqchat, 'qqchat'),
  new IconDefinition(MdiIcons.qrcode, 'qrcode'),
  new IconDefinition(MdiIcons.qrcodeEdit, 'qrcodeEdit'),
  new IconDefinition(MdiIcons.qrcodeScan, 'qrcodeScan'),
  new IconDefinition(MdiIcons.quadcopter, 'quadcopter'),
  new IconDefinition(MdiIcons.qualityHigh, 'qualityHigh'),
  new IconDefinition(MdiIcons.qualityLow, 'qualityLow'),
  new IconDefinition(MdiIcons.qualityMedium, 'qualityMedium'),
  new IconDefinition(MdiIcons.quicktime, 'quicktime'),
  new IconDefinition(MdiIcons.rabbit, 'rabbit'),
  new IconDefinition(MdiIcons.radar, 'radar'),
  new IconDefinition(MdiIcons.radiator, 'radiator'),
  new IconDefinition(MdiIcons.radiatorDisabled, 'radiatorDisabled'),
  new IconDefinition(MdiIcons.radiatorOff, 'radiatorOff'),
  new IconDefinition(MdiIcons.radio, 'radio'),
  new IconDefinition(MdiIcons.radioAm, 'radioAm'),
  new IconDefinition(MdiIcons.radioFm, 'radioFm'),
  new IconDefinition(MdiIcons.radioHandheld, 'radioHandheld'),
  new IconDefinition(MdiIcons.radioTower, 'radioTower'),
  new IconDefinition(MdiIcons.radioactive, 'radioactive'),
  new IconDefinition(MdiIcons.radioboxBlank, 'radioboxBlank'),
  new IconDefinition(MdiIcons.radioboxMarked, 'radioboxMarked'),
  new IconDefinition(MdiIcons.radius, 'radius'),
  new IconDefinition(MdiIcons.radiusOutline, 'radiusOutline'),
  new IconDefinition(MdiIcons.raspberrypi, 'raspberrypi'),
  new IconDefinition(MdiIcons.rayEnd, 'rayEnd'),
  new IconDefinition(MdiIcons.rayEndArrow, 'rayEndArrow'),
  new IconDefinition(MdiIcons.rayStart, 'rayStart'),
  new IconDefinition(MdiIcons.rayStartArrow, 'rayStartArrow'),
  new IconDefinition(MdiIcons.rayStartEnd, 'rayStartEnd'),
  new IconDefinition(MdiIcons.rayVertex, 'rayVertex'),
  new IconDefinition(MdiIcons.react, 'react'),
  new IconDefinition(MdiIcons.read, 'read'),
  new IconDefinition(MdiIcons.receipt, 'receipt'),
  new IconDefinition(MdiIcons.record, 'record'),
  new IconDefinition(MdiIcons.recordPlayer, 'recordPlayer'),
  new IconDefinition(MdiIcons.recordRec, 'recordRec'),
  new IconDefinition(MdiIcons.recycle, 'recycle'),
  new IconDefinition(MdiIcons.reddit, 'reddit'),
  new IconDefinition(MdiIcons.redo, 'redo'),
  new IconDefinition(MdiIcons.redoVariant, 'redoVariant'),
  new IconDefinition(MdiIcons.reflectHorizontal, 'reflectHorizontal'),
  new IconDefinition(MdiIcons.reflectVertical, 'reflectVertical'),
  new IconDefinition(MdiIcons.refresh, 'refresh'),
  new IconDefinition(MdiIcons.regex, 'regex'),
  new IconDefinition(MdiIcons.registeredTrademark, 'registeredTrademark'),
  new IconDefinition(MdiIcons.relativeScale, 'relativeScale'),
  new IconDefinition(MdiIcons.reload, 'reload'),
  new IconDefinition(MdiIcons.reminder, 'reminder'),
  new IconDefinition(MdiIcons.remote, 'remote'),
  new IconDefinition(MdiIcons.remoteDesktop, 'remoteDesktop'),
  new IconDefinition(MdiIcons.renameBox, 'renameBox'),
  new IconDefinition(MdiIcons.reorderHorizontal, 'reorderHorizontal'),
  new IconDefinition(MdiIcons.reorderVertical, 'reorderVertical'),
  new IconDefinition(MdiIcons.repeat, 'repeat'),
  new IconDefinition(MdiIcons.repeatOff, 'repeatOff'),
  new IconDefinition(MdiIcons.repeatOnce, 'repeatOnce'),
  new IconDefinition(MdiIcons.replay, 'replay'),
  new IconDefinition(MdiIcons.reply, 'reply'),
  new IconDefinition(MdiIcons.replyAll, 'replyAll'),
  new IconDefinition(MdiIcons.reproduction, 'reproduction'),
  new IconDefinition(MdiIcons.resistor, 'resistor'),
  new IconDefinition(MdiIcons.resistorNodes, 'resistorNodes'),
  new IconDefinition(MdiIcons.resize, 'resize'),
  new IconDefinition(MdiIcons.resizeBottomRight, 'resizeBottomRight'),
  new IconDefinition(MdiIcons.responsive, 'responsive'),
  new IconDefinition(MdiIcons.restart, 'restart'),
  new IconDefinition(MdiIcons.restore, 'restore'),
  new IconDefinition(MdiIcons.restoreClock, 'restoreClock'),
  new IconDefinition(MdiIcons.rewind, 'rewind'),
  new IconDefinition(MdiIcons.rewindOutline, 'rewindOutline'),
  new IconDefinition(MdiIcons.rhombus, 'rhombus'),
  new IconDefinition(MdiIcons.rhombusMedium, 'rhombusMedium'),
  new IconDefinition(MdiIcons.rhombusOutline, 'rhombusOutline'),
  new IconDefinition(MdiIcons.rhombusSplit, 'rhombusSplit'),
  new IconDefinition(MdiIcons.ribbon, 'ribbon'),
  new IconDefinition(MdiIcons.rice, 'rice'),
  new IconDefinition(MdiIcons.ring, 'ring'),
  new IconDefinition(MdiIcons.road, 'road'),
  new IconDefinition(MdiIcons.roadVariant, 'roadVariant'),
  new IconDefinition(MdiIcons.robot, 'robot'),
  new IconDefinition(MdiIcons.robotIndustrial, 'robotIndustrial'),
  new IconDefinition(MdiIcons.robotVacuum, 'robotVacuum'),
  new IconDefinition(MdiIcons.robotVacuumVariant, 'robotVacuumVariant'),
  new IconDefinition(MdiIcons.rocket, 'rocket'),
  new IconDefinition(MdiIcons.rollupjs, 'rollupjs'),
  new IconDefinition(MdiIcons.roomService, 'roomService'),
  new IconDefinition(MdiIcons.rotate3d, 'rotate3d'),
  new IconDefinition(MdiIcons.rotateLeft, 'rotateLeft'),
  new IconDefinition(MdiIcons.rotateLeftVariant, 'rotateLeftVariant'),
  new IconDefinition(MdiIcons.rotateRight, 'rotateRight'),
  new IconDefinition(MdiIcons.rotateRightVariant, 'rotateRightVariant'),
  new IconDefinition(MdiIcons.roundedCorner, 'roundedCorner'),
  new IconDefinition(MdiIcons.routerWireless, 'routerWireless'),
  new IconDefinition(MdiIcons.routerWirelessSettings, 'routerWirelessSettings'),
  new IconDefinition(MdiIcons.routes, 'routes'),
  new IconDefinition(MdiIcons.rowing, 'rowing'),
  new IconDefinition(MdiIcons.rss, 'rss'),
  new IconDefinition(MdiIcons.rssBox, 'rssBox'),
  new IconDefinition(MdiIcons.ruler, 'ruler'),
  new IconDefinition(MdiIcons.rulerSquare, 'rulerSquare'),
  new IconDefinition(MdiIcons.run, 'run'),
  new IconDefinition(MdiIcons.runFast, 'runFast'),
  new IconDefinition(MdiIcons.safe, 'safe'),
  new IconDefinition(MdiIcons.sale, 'sale'),
  new IconDefinition(MdiIcons.salesforce, 'salesforce'),
  new IconDefinition(MdiIcons.sass, 'sass'),
  new IconDefinition(MdiIcons.satellite, 'satellite'),
  new IconDefinition(MdiIcons.satelliteUplink, 'satelliteUplink'),
  new IconDefinition(MdiIcons.satelliteVariant, 'satelliteVariant'),
  new IconDefinition(MdiIcons.sausage, 'sausage'),
  new IconDefinition(MdiIcons.saxophone, 'saxophone'),
  new IconDefinition(MdiIcons.scale, 'scale'),
  new IconDefinition(MdiIcons.scaleBalance, 'scaleBalance'),
  new IconDefinition(MdiIcons.scaleBathroom, 'scaleBathroom'),
  new IconDefinition(MdiIcons.scanner, 'scanner'),
  new IconDefinition(MdiIcons.scannerOff, 'scannerOff'),
  new IconDefinition(MdiIcons.school, 'school'),
  new IconDefinition(MdiIcons.scissorsCutting, 'scissorsCutting'),
  new IconDefinition(MdiIcons.screenRotation, 'screenRotation'),
  new IconDefinition(MdiIcons.screenRotationLock, 'screenRotationLock'),
  new IconDefinition(MdiIcons.screwdriver, 'screwdriver'),
  new IconDefinition(MdiIcons.script, 'script'),
  new IconDefinition(MdiIcons.scriptOutline, 'scriptOutline'),
  new IconDefinition(MdiIcons.scriptText, 'scriptText'),
  new IconDefinition(MdiIcons.scriptTextOutline, 'scriptTextOutline'),
  new IconDefinition(MdiIcons.sd, 'sd'),
  new IconDefinition(MdiIcons.seal, 'seal'),
  new IconDefinition(MdiIcons.searchWeb, 'searchWeb'),
  new IconDefinition(MdiIcons.seat, 'seat'),
  new IconDefinition(MdiIcons.seatFlat, 'seatFlat'),
  new IconDefinition(MdiIcons.seatFlatAngled, 'seatFlatAngled'),
  new IconDefinition(MdiIcons.seatIndividualSuite, 'seatIndividualSuite'),
  new IconDefinition(MdiIcons.seatLegroomExtra, 'seatLegroomExtra'),
  new IconDefinition(MdiIcons.seatLegroomNormal, 'seatLegroomNormal'),
  new IconDefinition(MdiIcons.seatLegroomReduced, 'seatLegroomReduced'),
  new IconDefinition(MdiIcons.seatOutline, 'seatOutline'),
  new IconDefinition(MdiIcons.seatReclineExtra, 'seatReclineExtra'),
  new IconDefinition(MdiIcons.seatReclineNormal, 'seatReclineNormal'),
  new IconDefinition(MdiIcons.seatbelt, 'seatbelt'),
  new IconDefinition(MdiIcons.security, 'security'),
  new IconDefinition(MdiIcons.securityNetwork, 'securityNetwork'),
  new IconDefinition(MdiIcons.select, 'select'),
  new IconDefinition(MdiIcons.selectAll, 'selectAll'),
  new IconDefinition(MdiIcons.selectCompare, 'selectCompare'),
  new IconDefinition(MdiIcons.selectDrag, 'selectDrag'),
  new IconDefinition(MdiIcons.selectInverse, 'selectInverse'),
  new IconDefinition(MdiIcons.selectOff, 'selectOff'),
  new IconDefinition(MdiIcons.selection, 'selection'),
  new IconDefinition(MdiIcons.selectionDrag, 'selectionDrag'),
  new IconDefinition(MdiIcons.selectionOff, 'selectionOff'),
  new IconDefinition(MdiIcons.send, 'send'),
  new IconDefinition(MdiIcons.sendLock, 'sendLock'),
  new IconDefinition(MdiIcons.serialPort, 'serialPort'),
  new IconDefinition(MdiIcons.server, 'server'),
  new IconDefinition(MdiIcons.serverMinus, 'serverMinus'),
  new IconDefinition(MdiIcons.serverNetwork, 'serverNetwork'),
  new IconDefinition(MdiIcons.serverNetworkOff, 'serverNetworkOff'),
  new IconDefinition(MdiIcons.serverOff, 'serverOff'),
  new IconDefinition(MdiIcons.serverPlus, 'serverPlus'),
  new IconDefinition(MdiIcons.serverRemove, 'serverRemove'),
  new IconDefinition(MdiIcons.serverSecurity, 'serverSecurity'),
  new IconDefinition(MdiIcons.setAll, 'setAll'),
  new IconDefinition(MdiIcons.setCenter, 'setCenter'),
  new IconDefinition(MdiIcons.setCenterRight, 'setCenterRight'),
  new IconDefinition(MdiIcons.setLeft, 'setLeft'),
  new IconDefinition(MdiIcons.setLeftCenter, 'setLeftCenter'),
  new IconDefinition(MdiIcons.setLeftRight, 'setLeftRight'),
  new IconDefinition(MdiIcons.setNone, 'setNone'),
  new IconDefinition(MdiIcons.setRight, 'setRight'),
  new IconDefinition(MdiIcons.setTopBox, 'setTopBox'),
  new IconDefinition(MdiIcons.settings, 'settings'),
  new IconDefinition(MdiIcons.settingsBox, 'settingsBox'),
  new IconDefinition(MdiIcons.settingsHelper, 'settingsHelper'),
  new IconDefinition(MdiIcons.settingsOutline, 'settingsOutline'),
  new IconDefinition(MdiIcons.shape, 'shape'),
  new IconDefinition(MdiIcons.shapeCirclePlus, 'shapeCirclePlus'),
  new IconDefinition(MdiIcons.shapeOutline, 'shapeOutline'),
  new IconDefinition(MdiIcons.shapePlus, 'shapePlus'),
  new IconDefinition(MdiIcons.shapePolygonPlus, 'shapePolygonPlus'),
  new IconDefinition(MdiIcons.shapeRectanglePlus, 'shapeRectanglePlus'),
  new IconDefinition(MdiIcons.shapeSquarePlus, 'shapeSquarePlus'),
  new IconDefinition(MdiIcons.share, 'share'),
  new IconDefinition(MdiIcons.shareOutline, 'shareOutline'),
  new IconDefinition(MdiIcons.shareVariant, 'shareVariant'),
  new IconDefinition(MdiIcons.sheep, 'sheep'),
  new IconDefinition(MdiIcons.shield, 'shield'),
  new IconDefinition(MdiIcons.shieldAccount, 'shieldAccount'),
  new IconDefinition(MdiIcons.shieldAccountOutline, 'shieldAccountOutline'),
  new IconDefinition(MdiIcons.shieldAirplane, 'shieldAirplane'),
  new IconDefinition(MdiIcons.shieldAirplaneOutline, 'shieldAirplaneOutline'),
  new IconDefinition(MdiIcons.shieldCheck, 'shieldCheck'),
  new IconDefinition(MdiIcons.shieldCheckOutline, 'shieldCheckOutline'),
  new IconDefinition(MdiIcons.shieldCross, 'shieldCross'),
  new IconDefinition(MdiIcons.shieldCrossOutline, 'shieldCrossOutline'),
  new IconDefinition(MdiIcons.shieldHalfFull, 'shieldHalfFull'),
  new IconDefinition(MdiIcons.shieldHome, 'shieldHome'),
  new IconDefinition(MdiIcons.shieldHomeOutline, 'shieldHomeOutline'),
  new IconDefinition(MdiIcons.shieldKey, 'shieldKey'),
  new IconDefinition(MdiIcons.shieldKeyOutline, 'shieldKeyOutline'),
  new IconDefinition(MdiIcons.shieldLock, 'shieldLock'),
  new IconDefinition(MdiIcons.shieldLockOutline, 'shieldLockOutline'),
  new IconDefinition(MdiIcons.shieldOff, 'shieldOff'),
  new IconDefinition(MdiIcons.shieldOffOutline, 'shieldOffOutline'),
  new IconDefinition(MdiIcons.shieldOutline, 'shieldOutline'),
  new IconDefinition(MdiIcons.shieldPlus, 'shieldPlus'),
  new IconDefinition(MdiIcons.shieldPlusOutline, 'shieldPlusOutline'),
  new IconDefinition(MdiIcons.shieldRemove, 'shieldRemove'),
  new IconDefinition(MdiIcons.shieldRemoveOutline, 'shieldRemoveOutline'),
  new IconDefinition(MdiIcons.shipWheel, 'shipWheel'),
  new IconDefinition(MdiIcons.shoeFormal, 'shoeFormal'),
  new IconDefinition(MdiIcons.shoeHeel, 'shoeHeel'),
  new IconDefinition(MdiIcons.shopify, 'shopify'),
  new IconDefinition(MdiIcons.shopping, 'shopping'),
  new IconDefinition(MdiIcons.shoppingMusic, 'shoppingMusic'),
  new IconDefinition(MdiIcons.shovel, 'shovel'),
  new IconDefinition(MdiIcons.shovelOff, 'shovelOff'),
  new IconDefinition(MdiIcons.shower, 'shower'),
  new IconDefinition(MdiIcons.showerHead, 'showerHead'),
  new IconDefinition(MdiIcons.shredder, 'shredder'),
  new IconDefinition(MdiIcons.shuffle, 'shuffle'),
  new IconDefinition(MdiIcons.shuffleDisabled, 'shuffleDisabled'),
  new IconDefinition(MdiIcons.shuffleVariant, 'shuffleVariant'),
  new IconDefinition(MdiIcons.sigma, 'sigma'),
  new IconDefinition(MdiIcons.sigmaLower, 'sigmaLower'),
  new IconDefinition(MdiIcons.signCaution, 'signCaution'),
  new IconDefinition(MdiIcons.signDirection, 'signDirection'),
  new IconDefinition(MdiIcons.signText, 'signText'),
  new IconDefinition(MdiIcons.signal, 'signal'),
  new IconDefinition(MdiIcons.signal2g, 'signal2g'),
  new IconDefinition(MdiIcons.signal3g, 'signal3g'),
  new IconDefinition(MdiIcons.signal4g, 'signal4g'),
  new IconDefinition(MdiIcons.signal5g, 'signal5g'),
  new IconDefinition(MdiIcons.signalCellular1, 'signalCellular1'),
  new IconDefinition(MdiIcons.signalCellular2, 'signalCellular2'),
  new IconDefinition(MdiIcons.signalCellular3, 'signalCellular3'),
  new IconDefinition(MdiIcons.signalCellularOutline, 'signalCellularOutline'),
  new IconDefinition(MdiIcons.signalHspa, 'signalHspa'),
  new IconDefinition(MdiIcons.signalHspaPlus, 'signalHspaPlus'),
  new IconDefinition(MdiIcons.signalOff, 'signalOff'),
  new IconDefinition(MdiIcons.signalVariant, 'signalVariant'),
  new IconDefinition(MdiIcons.silo, 'silo'),
  new IconDefinition(MdiIcons.silverware, 'silverware'),
  new IconDefinition(MdiIcons.silverwareFork, 'silverwareFork'),
  new IconDefinition(MdiIcons.silverwareForkKnife, 'silverwareForkKnife'),
  new IconDefinition(MdiIcons.silverwareSpoon, 'silverwareSpoon'),
  new IconDefinition(MdiIcons.silverwareVariant, 'silverwareVariant'),
  new IconDefinition(MdiIcons.sim, 'sim'),
  new IconDefinition(MdiIcons.simAlert, 'simAlert'),
  new IconDefinition(MdiIcons.simOff, 'simOff'),
  new IconDefinition(MdiIcons.sinaWeibo, 'sinaWeibo'),
  new IconDefinition(MdiIcons.sitemap, 'sitemap'),
  new IconDefinition(MdiIcons.skipBackward, 'skipBackward'),
  new IconDefinition(MdiIcons.skipForward, 'skipForward'),
  new IconDefinition(MdiIcons.skipNext, 'skipNext'),
  new IconDefinition(MdiIcons.skipNextCircle, 'skipNextCircle'),
  new IconDefinition(MdiIcons.skipNextCircleOutline, 'skipNextCircleOutline'),
  new IconDefinition(MdiIcons.skipPrevious, 'skipPrevious'),
  new IconDefinition(MdiIcons.skipPreviousCircle, 'skipPreviousCircle'),
  new IconDefinition(MdiIcons.skipPreviousCircleOutline, 'skipPreviousCircleOutline'),
  new IconDefinition(MdiIcons.skull, 'skull'),
  new IconDefinition(MdiIcons.skullCrossbones, 'skullCrossbones'),
  new IconDefinition(MdiIcons.skullCrossbonesOutline, 'skullCrossbonesOutline'),
  new IconDefinition(MdiIcons.skullOutline, 'skullOutline'),
  new IconDefinition(MdiIcons.skype, 'skype'),
  new IconDefinition(MdiIcons.skypeBusiness, 'skypeBusiness'),
  new IconDefinition(MdiIcons.slack, 'slack'),
  new IconDefinition(MdiIcons.slackware, 'slackware'),
  new IconDefinition(MdiIcons.sleep, 'sleep'),
  new IconDefinition(MdiIcons.sleepOff, 'sleepOff'),
  new IconDefinition(MdiIcons.smog, 'smog'),
  new IconDefinition(MdiIcons.smokeDetector, 'smokeDetector'),
  new IconDefinition(MdiIcons.smoking, 'smoking'),
  new IconDefinition(MdiIcons.smokingOff, 'smokingOff'),
  new IconDefinition(MdiIcons.snapchat, 'snapchat'),
  new IconDefinition(MdiIcons.snowflake, 'snowflake'),
  new IconDefinition(MdiIcons.snowman, 'snowman'),
  new IconDefinition(MdiIcons.soccer, 'soccer'),
  new IconDefinition(MdiIcons.soccerField, 'soccerField'),
  new IconDefinition(MdiIcons.sofa, 'sofa'),
  new IconDefinition(MdiIcons.solarPower, 'solarPower'),
  new IconDefinition(MdiIcons.solid, 'solid'),
  new IconDefinition(MdiIcons.sort, 'sort'),
  new IconDefinition(MdiIcons.sortAlphabetical, 'sortAlphabetical'),
  new IconDefinition(MdiIcons.sortAscending, 'sortAscending'),
  new IconDefinition(MdiIcons.sortDescending, 'sortDescending'),
  new IconDefinition(MdiIcons.sortNumeric, 'sortNumeric'),
  new IconDefinition(MdiIcons.sortVariant, 'sortVariant'),
  new IconDefinition(MdiIcons.sortVariantLock, 'sortVariantLock'),
  new IconDefinition(MdiIcons.sortVariantLockOpen, 'sortVariantLockOpen'),
  new IconDefinition(MdiIcons.soundcloud, 'soundcloud'),
  new IconDefinition(MdiIcons.sourceBranch, 'sourceBranch'),
  new IconDefinition(MdiIcons.sourceCommit, 'sourceCommit'),
  new IconDefinition(MdiIcons.sourceCommitEnd, 'sourceCommitEnd'),
  new IconDefinition(MdiIcons.sourceCommitEndLocal, 'sourceCommitEndLocal'),
  new IconDefinition(MdiIcons.sourceCommitLocal, 'sourceCommitLocal'),
  new IconDefinition(MdiIcons.sourceCommitNextLocal, 'sourceCommitNextLocal'),
  new IconDefinition(MdiIcons.sourceCommitStart, 'sourceCommitStart'),
  new IconDefinition(MdiIcons.sourceCommitStartNextLocal, 'sourceCommitStartNextLocal'),
  new IconDefinition(MdiIcons.sourceFork, 'sourceFork'),
  new IconDefinition(MdiIcons.sourceMerge, 'sourceMerge'),
  new IconDefinition(MdiIcons.sourcePull, 'sourcePull'),
  new IconDefinition(MdiIcons.sourceRepository, 'sourceRepository'),
  new IconDefinition(MdiIcons.sourceRepositoryMultiple, 'sourceRepositoryMultiple'),
  new IconDefinition(MdiIcons.soySauce, 'soySauce'),
  new IconDefinition(MdiIcons.spa, 'spa'),
  new IconDefinition(MdiIcons.spaOutline, 'spaOutline'),
  new IconDefinition(MdiIcons.spaceInvaders, 'spaceInvaders'),
  new IconDefinition(MdiIcons.speaker, 'speaker'),
  new IconDefinition(MdiIcons.speakerBluetooth, 'speakerBluetooth'),
  new IconDefinition(MdiIcons.speakerOff, 'speakerOff'),
  new IconDefinition(MdiIcons.speakerWireless, 'speakerWireless'),
  new IconDefinition(MdiIcons.speedometer, 'speedometer'),
  new IconDefinition(MdiIcons.spellcheck, 'spellcheck'),
  new IconDefinition(MdiIcons.spiderWeb, 'spiderWeb'),
  new IconDefinition(MdiIcons.spotify, 'spotify'),
  new IconDefinition(MdiIcons.spotlight, 'spotlight'),
  new IconDefinition(MdiIcons.spotlightBeam, 'spotlightBeam'),
  new IconDefinition(MdiIcons.spray, 'spray'),
  new IconDefinition(MdiIcons.sprayBottle, 'sprayBottle'),
  new IconDefinition(MdiIcons.square, 'square'),
  new IconDefinition(MdiIcons.squareEditOutline, 'squareEditOutline'),
  new IconDefinition(MdiIcons.squareInc, 'squareInc'),
  new IconDefinition(MdiIcons.squareIncCash, 'squareIncCash'),
  new IconDefinition(MdiIcons.squareMedium, 'squareMedium'),
  new IconDefinition(MdiIcons.squareMediumOutline, 'squareMediumOutline'),
  new IconDefinition(MdiIcons.squareOutline, 'squareOutline'),
  new IconDefinition(MdiIcons.squareRoot, 'squareRoot'),
  new IconDefinition(MdiIcons.squareRootBox, 'squareRootBox'),
  new IconDefinition(MdiIcons.squareSmall, 'squareSmall'),
  new IconDefinition(MdiIcons.squeegee, 'squeegee'),
  new IconDefinition(MdiIcons.ssh, 'ssh'),
  new IconDefinition(MdiIcons.stackExchange, 'stackExchange'),
  new IconDefinition(MdiIcons.stackOverflow, 'stackOverflow'),
  new IconDefinition(MdiIcons.stadium, 'stadium'),
  new IconDefinition(MdiIcons.stairs, 'stairs'),
  new IconDefinition(MdiIcons.standardDefinition, 'standardDefinition'),
  new IconDefinition(MdiIcons.star, 'star'),
  new IconDefinition(MdiIcons.starBox, 'starBox'),
  new IconDefinition(MdiIcons.starBoxOutline, 'starBoxOutline'),
  new IconDefinition(MdiIcons.starCircle, 'starCircle'),
  new IconDefinition(MdiIcons.starCircleOutline, 'starCircleOutline'),
  new IconDefinition(MdiIcons.starFace, 'starFace'),
  new IconDefinition(MdiIcons.starFourPoints, 'starFourPoints'),
  new IconDefinition(MdiIcons.starFourPointsOutline, 'starFourPointsOutline'),
  new IconDefinition(MdiIcons.starHalf, 'starHalf'),
  new IconDefinition(MdiIcons.starOff, 'starOff'),
  new IconDefinition(MdiIcons.starOutline, 'starOutline'),
  new IconDefinition(MdiIcons.starThreePoints, 'starThreePoints'),
  new IconDefinition(MdiIcons.starThreePointsOutline, 'starThreePointsOutline'),
  new IconDefinition(MdiIcons.steam, 'steam'),
  new IconDefinition(MdiIcons.steamBox, 'steamBox'),
  new IconDefinition(MdiIcons.steering, 'steering'),
  new IconDefinition(MdiIcons.steeringOff, 'steeringOff'),
  new IconDefinition(MdiIcons.stepBackward, 'stepBackward'),
  new IconDefinition(MdiIcons.stepBackward2, 'stepBackward2'),
  new IconDefinition(MdiIcons.stepForward, 'stepForward'),
  new IconDefinition(MdiIcons.stepForward2, 'stepForward2'),
  new IconDefinition(MdiIcons.stethoscope, 'stethoscope'),
  new IconDefinition(MdiIcons.sticker, 'sticker'),
  new IconDefinition(MdiIcons.stickerEmoji, 'stickerEmoji'),
  new IconDefinition(MdiIcons.stocking, 'stocking'),
  new IconDefinition(MdiIcons.stop, 'stop'),
  new IconDefinition(MdiIcons.stopCircle, 'stopCircle'),
  new IconDefinition(MdiIcons.stopCircleOutline, 'stopCircleOutline'),
  new IconDefinition(MdiIcons.store, 'store'),
  new IconDefinition(MdiIcons.store24Hour, 'store24Hour'),
  new IconDefinition(MdiIcons.stove, 'stove'),
  new IconDefinition(MdiIcons.strava, 'strava'),
  new IconDefinition(MdiIcons.subdirectoryArrowLeft, 'subdirectoryArrowLeft'),
  new IconDefinition(MdiIcons.subdirectoryArrowRight, 'subdirectoryArrowRight'),
  new IconDefinition(MdiIcons.subtitles, 'subtitles'),
  new IconDefinition(MdiIcons.subtitlesOutline, 'subtitlesOutline'),
  new IconDefinition(MdiIcons.subway, 'subway'),
  new IconDefinition(MdiIcons.subwayVariant, 'subwayVariant'),
  new IconDefinition(MdiIcons.summit, 'summit'),
  new IconDefinition(MdiIcons.sunglasses, 'sunglasses'),
  new IconDefinition(MdiIcons.surroundSound, 'surroundSound'),
  new IconDefinition(MdiIcons.surroundSound20, 'surroundSound20'),
  new IconDefinition(MdiIcons.surroundSound31, 'surroundSound31'),
  new IconDefinition(MdiIcons.surroundSound51, 'surroundSound51'),
  new IconDefinition(MdiIcons.surroundSound71, 'surroundSound71'),
  new IconDefinition(MdiIcons.svg, 'svg'),
  new IconDefinition(MdiIcons.swapHorizontal, 'swapHorizontal'),
  new IconDefinition(MdiIcons.swapHorizontalBold, 'swapHorizontalBold'),
  new IconDefinition(MdiIcons.swapHorizontalVariant, 'swapHorizontalVariant'),
  new IconDefinition(MdiIcons.swapVertical, 'swapVertical'),
  new IconDefinition(MdiIcons.swapVerticalBold, 'swapVerticalBold'),
  new IconDefinition(MdiIcons.swapVerticalVariant, 'swapVerticalVariant'),
  new IconDefinition(MdiIcons.swim, 'swim'),
  new IconDefinition(MdiIcons.switchIcon, 'switchIcon'),
  new IconDefinition(MdiIcons.sword, 'sword'),
  new IconDefinition(MdiIcons.swordCross, 'swordCross'),
  new IconDefinition(MdiIcons.symfony, 'symfony'),
  new IconDefinition(MdiIcons.syncIcon, 'syncIcon'),
  new IconDefinition(MdiIcons.syncAlert, 'syncAlert'),
  new IconDefinition(MdiIcons.syncOff, 'syncOff'),
  new IconDefinition(MdiIcons.tab, 'tab'),
  new IconDefinition(MdiIcons.tabMinus, 'tabMinus'),
  new IconDefinition(MdiIcons.tabPlus, 'tabPlus'),
  new IconDefinition(MdiIcons.tabRemove, 'tabRemove'),
  new IconDefinition(MdiIcons.tabUnselected, 'tabUnselected'),
  new IconDefinition(MdiIcons.table, 'table'),
  new IconDefinition(MdiIcons.tableBorder, 'tableBorder'),
  new IconDefinition(MdiIcons.tableColumn, 'tableColumn'),
  new IconDefinition(MdiIcons.tableColumnPlusAfter, 'tableColumnPlusAfter'),
  new IconDefinition(MdiIcons.tableColumnPlusBefore, 'tableColumnPlusBefore'),
  new IconDefinition(MdiIcons.tableColumnRemove, 'tableColumnRemove'),
  new IconDefinition(MdiIcons.tableColumnWidth, 'tableColumnWidth'),
  new IconDefinition(MdiIcons.tableEdit, 'tableEdit'),
  new IconDefinition(MdiIcons.tableLarge, 'tableLarge'),
  new IconDefinition(MdiIcons.tableMergeCells, 'tableMergeCells'),
  new IconDefinition(MdiIcons.tableOfContents, 'tableOfContents'),
  new IconDefinition(MdiIcons.tablePlus, 'tablePlus'),
  new IconDefinition(MdiIcons.tableRemove, 'tableRemove'),
  new IconDefinition(MdiIcons.tableRow, 'tableRow'),
  new IconDefinition(MdiIcons.tableRowHeight, 'tableRowHeight'),
  new IconDefinition(MdiIcons.tableRowPlusAfter, 'tableRowPlusAfter'),
  new IconDefinition(MdiIcons.tableRowPlusBefore, 'tableRowPlusBefore'),
  new IconDefinition(MdiIcons.tableRowRemove, 'tableRowRemove'),
  new IconDefinition(MdiIcons.tableSearch, 'tableSearch'),
  new IconDefinition(MdiIcons.tableSettings, 'tableSettings'),
  new IconDefinition(MdiIcons.tablet, 'tablet'),
  new IconDefinition(MdiIcons.tabletAndroid, 'tabletAndroid'),
  new IconDefinition(MdiIcons.tabletCellphone, 'tabletCellphone'),
  new IconDefinition(MdiIcons.tabletIpad, 'tabletIpad'),
  new IconDefinition(MdiIcons.taco, 'taco'),
  new IconDefinition(MdiIcons.tag, 'tag'),
  new IconDefinition(MdiIcons.tagFaces, 'tagFaces'),
  new IconDefinition(MdiIcons.tagHeart, 'tagHeart'),
  new IconDefinition(MdiIcons.tagHeartOutline, 'tagHeartOutline'),
  new IconDefinition(MdiIcons.tagMinus, 'tagMinus'),
  new IconDefinition(MdiIcons.tagMultiple, 'tagMultiple'),
  new IconDefinition(MdiIcons.tagOutline, 'tagOutline'),
  new IconDefinition(MdiIcons.tagPlus, 'tagPlus'),
  new IconDefinition(MdiIcons.tagRemove, 'tagRemove'),
  new IconDefinition(MdiIcons.tagTextOutline, 'tagTextOutline'),
  new IconDefinition(MdiIcons.tapeMeasure, 'tapeMeasure'),
  new IconDefinition(MdiIcons.target, 'target'),
  new IconDefinition(MdiIcons.targetAccount, 'targetAccount'),
  new IconDefinition(MdiIcons.targetVariant, 'targetVariant'),
  new IconDefinition(MdiIcons.taxi, 'taxi'),
  new IconDefinition(MdiIcons.teach, 'teach'),
  new IconDefinition(MdiIcons.teamviewer, 'teamviewer'),
  new IconDefinition(MdiIcons.telegram, 'telegram'),
  new IconDefinition(MdiIcons.telescope, 'telescope'),
  new IconDefinition(MdiIcons.television, 'television'),
  new IconDefinition(MdiIcons.televisionBox, 'televisionBox'),
  new IconDefinition(MdiIcons.televisionClassic, 'televisionClassic'),
  new IconDefinition(MdiIcons.televisionClassicOff, 'televisionClassicOff'),
  new IconDefinition(MdiIcons.televisionGuide, 'televisionGuide'),
  new IconDefinition(MdiIcons.televisionOff, 'televisionOff'),
  new IconDefinition(MdiIcons.temperatureCelsius, 'temperatureCelsius'),
  new IconDefinition(MdiIcons.temperatureFahrenheit, 'temperatureFahrenheit'),
  new IconDefinition(MdiIcons.temperatureKelvin, 'temperatureKelvin'),
  new IconDefinition(MdiIcons.tennis, 'tennis'),
  new IconDefinition(MdiIcons.tent, 'tent'),
  new IconDefinition(MdiIcons.terrain, 'terrain'),
  new IconDefinition(MdiIcons.testTube, 'testTube'),
  new IconDefinition(MdiIcons.testTubeEmpty, 'testTubeEmpty'),
  new IconDefinition(MdiIcons.testTubeOff, 'testTubeOff'),
  new IconDefinition(MdiIcons.text, 'text'),
  new IconDefinition(MdiIcons.textShadow, 'textShadow'),
  new IconDefinition(MdiIcons.textShort, 'textShort'),
  new IconDefinition(MdiIcons.textSubject, 'textSubject'),
  new IconDefinition(MdiIcons.textToSpeech, 'textToSpeech'),
  new IconDefinition(MdiIcons.textToSpeechOff, 'textToSpeechOff'),
  new IconDefinition(MdiIcons.textbox, 'textbox'),
  new IconDefinition(MdiIcons.textboxPassword, 'textboxPassword'),
  new IconDefinition(MdiIcons.texture, 'texture'),
  new IconDefinition(MdiIcons.theater, 'theater'),
  new IconDefinition(MdiIcons.themeLightDark, 'themeLightDark'),
  new IconDefinition(MdiIcons.thermometer, 'thermometer'),
  new IconDefinition(MdiIcons.thermometerLines, 'thermometerLines'),
  new IconDefinition(MdiIcons.thermostat, 'thermostat'),
  new IconDefinition(MdiIcons.thermostatBox, 'thermostatBox'),
  new IconDefinition(MdiIcons.thoughtBubble, 'thoughtBubble'),
  new IconDefinition(MdiIcons.thoughtBubbleOutline, 'thoughtBubbleOutline'),
  new IconDefinition(MdiIcons.thumbDown, 'thumbDown'),
  new IconDefinition(MdiIcons.thumbDownOutline, 'thumbDownOutline'),
  new IconDefinition(MdiIcons.thumbUp, 'thumbUp'),
  new IconDefinition(MdiIcons.thumbUpOutline, 'thumbUpOutline'),
  new IconDefinition(MdiIcons.thumbsUpDown, 'thumbsUpDown'),
  new IconDefinition(MdiIcons.ticket, 'ticket'),
  new IconDefinition(MdiIcons.ticketAccount, 'ticketAccount'),
  new IconDefinition(MdiIcons.ticketConfirmation, 'ticketConfirmation'),
  new IconDefinition(MdiIcons.ticketOutline, 'ticketOutline'),
  new IconDefinition(MdiIcons.ticketPercent, 'ticketPercent'),
  new IconDefinition(MdiIcons.tie, 'tie'),
  new IconDefinition(MdiIcons.tilde, 'tilde'),
  new IconDefinition(MdiIcons.timelapse, 'timelapse'),
  new IconDefinition(MdiIcons.timeline, 'timeline'),
  new IconDefinition(MdiIcons.timelineOutline, 'timelineOutline'),
  new IconDefinition(MdiIcons.timelineText, 'timelineText'),
  new IconDefinition(MdiIcons.timelineTextOutline, 'timelineTextOutline'),
  new IconDefinition(MdiIcons.timer, 'timer'),
  new IconDefinition(MdiIcons.timer10, 'timer10'),
  new IconDefinition(MdiIcons.timer3, 'timer3'),
  new IconDefinition(MdiIcons.timerOff, 'timerOff'),
  new IconDefinition(MdiIcons.timerSand, 'timerSand'),
  new IconDefinition(MdiIcons.timerSandEmpty, 'timerSandEmpty'),
  new IconDefinition(MdiIcons.timerSandFull, 'timerSandFull'),
  new IconDefinition(MdiIcons.timetable, 'timetable'),
  new IconDefinition(MdiIcons.toasterOven, 'toasterOven'),
  new IconDefinition(MdiIcons.toggleSwitch, 'toggleSwitch'),
  new IconDefinition(MdiIcons.toggleSwitchOff, 'toggleSwitchOff'),
  new IconDefinition(MdiIcons.toggleSwitchOffOutline, 'toggleSwitchOffOutline'),
  new IconDefinition(MdiIcons.toggleSwitchOutline, 'toggleSwitchOutline'),
  new IconDefinition(MdiIcons.toilet, 'toilet'),
  new IconDefinition(MdiIcons.toolbox, 'toolbox'),
  new IconDefinition(MdiIcons.toolboxOutline, 'toolboxOutline'),
  new IconDefinition(MdiIcons.tooltip, 'tooltip'),
  new IconDefinition(MdiIcons.tooltipAccount, 'tooltipAccount'),
  new IconDefinition(MdiIcons.tooltipEdit, 'tooltipEdit'),
  new IconDefinition(MdiIcons.tooltipImage, 'tooltipImage'),
  new IconDefinition(MdiIcons.tooltipImageOutline, 'tooltipImageOutline'),
  new IconDefinition(MdiIcons.tooltipOutline, 'tooltipOutline'),
  new IconDefinition(MdiIcons.tooltipPlus, 'tooltipPlus'),
  new IconDefinition(MdiIcons.tooltipPlusOutline, 'tooltipPlusOutline'),
  new IconDefinition(MdiIcons.tooltipText, 'tooltipText'),
  new IconDefinition(MdiIcons.tooltipTextOutline, 'tooltipTextOutline'),
  new IconDefinition(MdiIcons.tooth, 'tooth'),
  new IconDefinition(MdiIcons.toothOutline, 'toothOutline'),
  new IconDefinition(MdiIcons.tor, 'tor'),
  new IconDefinition(MdiIcons.tournament, 'tournament'),
  new IconDefinition(MdiIcons.towerBeach, 'towerBeach'),
  new IconDefinition(MdiIcons.towerFire, 'towerFire'),
  new IconDefinition(MdiIcons.towing, 'towing'),
  new IconDefinition(MdiIcons.trackLight, 'trackLight'),
  new IconDefinition(MdiIcons.trackpad, 'trackpad'),
  new IconDefinition(MdiIcons.trackpadLock, 'trackpadLock'),
  new IconDefinition(MdiIcons.tractor, 'tractor'),
  new IconDefinition(MdiIcons.trademark, 'trademark'),
  new IconDefinition(MdiIcons.trafficLight, 'trafficLight'),
  new IconDefinition(MdiIcons.train, 'train'),
  new IconDefinition(MdiIcons.trainCar, 'trainCar'),
  new IconDefinition(MdiIcons.trainVariant, 'trainVariant'),
  new IconDefinition(MdiIcons.tram, 'tram'),
  new IconDefinition(MdiIcons.transcribe, 'transcribe'),
  new IconDefinition(MdiIcons.transcribeClose, 'transcribeClose'),
  new IconDefinition(MdiIcons.transfer, 'transfer'),
  new IconDefinition(MdiIcons.transitTransfer, 'transitTransfer'),
  new IconDefinition(MdiIcons.transition, 'transition'),
  new IconDefinition(MdiIcons.transitionMasked, 'transitionMasked'),
  new IconDefinition(MdiIcons.translate, 'translate'),
  new IconDefinition(MdiIcons.trashCan, 'trashCan'),
  new IconDefinition(MdiIcons.trashCanOutline, 'trashCanOutline'),
  new IconDefinition(MdiIcons.treasureChest, 'treasureChest'),
  new IconDefinition(MdiIcons.tree, 'tree'),
  new IconDefinition(MdiIcons.trello, 'trello'),
  new IconDefinition(MdiIcons.trendingDown, 'trendingDown'),
  new IconDefinition(MdiIcons.trendingNeutral, 'trendingNeutral'),
  new IconDefinition(MdiIcons.trendingUp, 'trendingUp'),
  new IconDefinition(MdiIcons.triangle, 'triangle'),
  new IconDefinition(MdiIcons.triangleOutline, 'triangleOutline'),
  new IconDefinition(MdiIcons.triforce, 'triforce'),
  new IconDefinition(MdiIcons.trophy, 'trophy'),
  new IconDefinition(MdiIcons.trophyAward, 'trophyAward'),
  new IconDefinition(MdiIcons.trophyOutline, 'trophyOutline'),
  new IconDefinition(MdiIcons.trophyVariant, 'trophyVariant'),
  new IconDefinition(MdiIcons.trophyVariantOutline, 'trophyVariantOutline'),
  new IconDefinition(MdiIcons.truck, 'truck'),
  new IconDefinition(MdiIcons.truckCheck, 'truckCheck'),
  new IconDefinition(MdiIcons.truckDelivery, 'truckDelivery'),
  new IconDefinition(MdiIcons.truckFast, 'truckFast'),
  new IconDefinition(MdiIcons.truckTrailer, 'truckTrailer'),
  new IconDefinition(MdiIcons.tshirtCrew, 'tshirtCrew'),
  new IconDefinition(MdiIcons.tshirtCrewOutline, 'tshirtCrewOutline'),
  new IconDefinition(MdiIcons.tshirtV, 'tshirtV'),
  new IconDefinition(MdiIcons.tshirtVOutline, 'tshirtVOutline'),
  new IconDefinition(MdiIcons.tumbleDryer, 'tumbleDryer'),
  new IconDefinition(MdiIcons.tumblr, 'tumblr'),
  new IconDefinition(MdiIcons.tumblrBox, 'tumblrBox'),
  new IconDefinition(MdiIcons.tumblrReblog, 'tumblrReblog'),
  new IconDefinition(MdiIcons.tune, 'tune'),
  new IconDefinition(MdiIcons.tuneVertical, 'tuneVertical'),
  new IconDefinition(MdiIcons.turnstile, 'turnstile'),
  new IconDefinition(MdiIcons.turnstileOutline, 'turnstileOutline'),
  new IconDefinition(MdiIcons.turtle, 'turtle'),
  new IconDefinition(MdiIcons.twitch, 'twitch'),
  new IconDefinition(MdiIcons.twitter, 'twitter'),
  new IconDefinition(MdiIcons.twitterBox, 'twitterBox'),
  new IconDefinition(MdiIcons.twitterCircle, 'twitterCircle'),
  new IconDefinition(MdiIcons.twitterRetweet, 'twitterRetweet'),
  new IconDefinition(MdiIcons.twoFactorAuthentication, 'twoFactorAuthentication'),
  new IconDefinition(MdiIcons.uber, 'uber'),
  new IconDefinition(MdiIcons.ubisoft, 'ubisoft'),
  new IconDefinition(MdiIcons.ubuntu, 'ubuntu'),
  new IconDefinition(MdiIcons.ultraHighDefinition, 'ultraHighDefinition'),
  new IconDefinition(MdiIcons.umbraco, 'umbraco'),
  new IconDefinition(MdiIcons.umbrella, 'umbrella'),
  new IconDefinition(MdiIcons.umbrellaClosed, 'umbrellaClosed'),
  new IconDefinition(MdiIcons.umbrellaOutline, 'umbrellaOutline'),
  new IconDefinition(MdiIcons.undo, 'undo'),
  new IconDefinition(MdiIcons.undoVariant, 'undoVariant'),
  new IconDefinition(MdiIcons.unfoldLessHorizontal, 'unfoldLessHorizontal'),
  new IconDefinition(MdiIcons.unfoldLessVertical, 'unfoldLessVertical'),
  new IconDefinition(MdiIcons.unfoldMoreHorizontal, 'unfoldMoreHorizontal'),
  new IconDefinition(MdiIcons.unfoldMoreVertical, 'unfoldMoreVertical'),
  new IconDefinition(MdiIcons.ungroup, 'ungroup'),
  new IconDefinition(MdiIcons.unity, 'unity'),
  new IconDefinition(MdiIcons.unreal, 'unreal'),
  new IconDefinition(MdiIcons.untappd, 'untappd'),
  new IconDefinition(MdiIcons.update, 'update'),
  new IconDefinition(MdiIcons.upload, 'upload'),
  new IconDefinition(MdiIcons.uploadMultiple, 'uploadMultiple'),
  new IconDefinition(MdiIcons.uploadNetwork, 'uploadNetwork'),
  new IconDefinition(MdiIcons.uploadNetworkOutline, 'uploadNetworkOutline'),
  new IconDefinition(MdiIcons.usb, 'usb'),
  new IconDefinition(MdiIcons.vanPassenger, 'vanPassenger'),
  new IconDefinition(MdiIcons.vanUtility, 'vanUtility'),
  new IconDefinition(MdiIcons.vanish, 'vanish'),
  new IconDefinition(MdiIcons.variable, 'variable'),
  new IconDefinition(MdiIcons.vectorArrangeAbove, 'vectorArrangeAbove'),
  new IconDefinition(MdiIcons.vectorArrangeBelow, 'vectorArrangeBelow'),
  new IconDefinition(MdiIcons.vectorBezier, 'vectorBezier'),
  new IconDefinition(MdiIcons.vectorCircle, 'vectorCircle'),
  new IconDefinition(MdiIcons.vectorCircleVariant, 'vectorCircleVariant'),
  new IconDefinition(MdiIcons.vectorCombine, 'vectorCombine'),
  new IconDefinition(MdiIcons.vectorCurve, 'vectorCurve'),
  new IconDefinition(MdiIcons.vectorDifference, 'vectorDifference'),
  new IconDefinition(MdiIcons.vectorDifferenceAb, 'vectorDifferenceAb'),
  new IconDefinition(MdiIcons.vectorDifferenceBa, 'vectorDifferenceBa'),
  new IconDefinition(MdiIcons.vectorEllipse, 'vectorEllipse'),
  new IconDefinition(MdiIcons.vectorIntersection, 'vectorIntersection'),
  new IconDefinition(MdiIcons.vectorLine, 'vectorLine'),
  new IconDefinition(MdiIcons.vectorPoint, 'vectorPoint'),
  new IconDefinition(MdiIcons.vectorPolygon, 'vectorPolygon'),
  new IconDefinition(MdiIcons.vectorPolyline, 'vectorPolyline'),
  new IconDefinition(MdiIcons.vectorRadius, 'vectorRadius'),
  new IconDefinition(MdiIcons.vectorRectangle, 'vectorRectangle'),
  new IconDefinition(MdiIcons.vectorSelection, 'vectorSelection'),
  new IconDefinition(MdiIcons.vectorSquare, 'vectorSquare'),
  new IconDefinition(MdiIcons.vectorTriangle, 'vectorTriangle'),
  new IconDefinition(MdiIcons.vectorUnion, 'vectorUnion'),
  new IconDefinition(MdiIcons.venmo, 'venmo'),
  new IconDefinition(MdiIcons.vhs, 'vhs'),
  new IconDefinition(MdiIcons.vibrate, 'vibrate'),
  new IconDefinition(MdiIcons.vibrateOff, 'vibrateOff'),
  new IconDefinition(MdiIcons.video, 'video'),
  new IconDefinition(MdiIcons.video3d, 'video3d'),
  new IconDefinition(MdiIcons.video4kBox, 'video4kBox'),
  new IconDefinition(MdiIcons.videoAccount, 'videoAccount'),
  new IconDefinition(MdiIcons.videoImage, 'videoImage'),
  new IconDefinition(MdiIcons.videoInputAntenna, 'videoInputAntenna'),
  new IconDefinition(MdiIcons.videoInputComponent, 'videoInputComponent'),
  new IconDefinition(MdiIcons.videoInputHdmi, 'videoInputHdmi'),
  new IconDefinition(MdiIcons.videoInputSvideo, 'videoInputSvideo'),
  new IconDefinition(MdiIcons.videoMinus, 'videoMinus'),
  new IconDefinition(MdiIcons.videoOff, 'videoOff'),
  new IconDefinition(MdiIcons.videoOffOutline, 'videoOffOutline'),
  new IconDefinition(MdiIcons.videoOutline, 'videoOutline'),
  new IconDefinition(MdiIcons.videoPlus, 'videoPlus'),
  new IconDefinition(MdiIcons.videoStabilization, 'videoStabilization'),
  new IconDefinition(MdiIcons.videoSwitch, 'videoSwitch'),
  new IconDefinition(MdiIcons.videoVintage, 'videoVintage'),
  new IconDefinition(MdiIcons.viewAgenda, 'viewAgenda'),
  new IconDefinition(MdiIcons.viewArray, 'viewArray'),
  new IconDefinition(MdiIcons.viewCarousel, 'viewCarousel'),
  new IconDefinition(MdiIcons.viewColumn, 'viewColumn'),
  new IconDefinition(MdiIcons.viewDashboard, 'viewDashboard'),
  new IconDefinition(MdiIcons.viewDashboardOutline, 'viewDashboardOutline'),
  new IconDefinition(MdiIcons.viewDashboardVariant, 'viewDashboardVariant'),
  new IconDefinition(MdiIcons.viewDay, 'viewDay'),
  new IconDefinition(MdiIcons.viewGrid, 'viewGrid'),
  new IconDefinition(MdiIcons.viewHeadline, 'viewHeadline'),
  new IconDefinition(MdiIcons.viewList, 'viewList'),
  new IconDefinition(MdiIcons.viewModule, 'viewModule'),
  new IconDefinition(MdiIcons.viewParallel, 'viewParallel'),
  new IconDefinition(MdiIcons.viewQuilt, 'viewQuilt'),
  new IconDefinition(MdiIcons.viewSequential, 'viewSequential'),
  new IconDefinition(MdiIcons.viewSplitHorizontal, 'viewSplitHorizontal'),
  new IconDefinition(MdiIcons.viewSplitVertical, 'viewSplitVertical'),
  new IconDefinition(MdiIcons.viewStream, 'viewStream'),
  new IconDefinition(MdiIcons.viewWeek, 'viewWeek'),
  new IconDefinition(MdiIcons.vimeo, 'vimeo'),
  new IconDefinition(MdiIcons.violin, 'violin'),
  new IconDefinition(MdiIcons.virtualReality, 'virtualReality'),
  new IconDefinition(MdiIcons.visualStudio, 'visualStudio'),
  new IconDefinition(MdiIcons.visualStudioCode, 'visualStudioCode'),
  new IconDefinition(MdiIcons.vk, 'vk'),
  new IconDefinition(MdiIcons.vkBox, 'vkBox'),
  new IconDefinition(MdiIcons.vkCircle, 'vkCircle'),
  new IconDefinition(MdiIcons.vlc, 'vlc'),
  new IconDefinition(MdiIcons.voice, 'voice'),
  new IconDefinition(MdiIcons.voicemail, 'voicemail'),
  new IconDefinition(MdiIcons.volleyball, 'volleyball'),
  new IconDefinition(MdiIcons.volumeHigh, 'volumeHigh'),
  new IconDefinition(MdiIcons.volumeLow, 'volumeLow'),
  new IconDefinition(MdiIcons.volumeMedium, 'volumeMedium'),
  new IconDefinition(MdiIcons.volumeMinus, 'volumeMinus'),
  new IconDefinition(MdiIcons.volumeMute, 'volumeMute'),
  new IconDefinition(MdiIcons.volumeOff, 'volumeOff'),
  new IconDefinition(MdiIcons.volumePlus, 'volumePlus'),
  new IconDefinition(MdiIcons.vote, 'vote'),
  new IconDefinition(MdiIcons.voteOutline, 'voteOutline'),
  new IconDefinition(MdiIcons.vpn, 'vpn'),
  new IconDefinition(MdiIcons.vuejs, 'vuejs'),
  new IconDefinition(MdiIcons.walk, 'walk'),
  new IconDefinition(MdiIcons.wall, 'wall'),
  new IconDefinition(MdiIcons.wallSconce, 'wallSconce'),
  new IconDefinition(MdiIcons.wallSconceFlat, 'wallSconceFlat'),
  new IconDefinition(MdiIcons.wallSconceVariant, 'wallSconceVariant'),
  new IconDefinition(MdiIcons.wallet, 'wallet'),
  new IconDefinition(MdiIcons.walletGiftcard, 'walletGiftcard'),
  new IconDefinition(MdiIcons.walletMembership, 'walletMembership'),
  new IconDefinition(MdiIcons.walletOutline, 'walletOutline'),
  new IconDefinition(MdiIcons.walletTravel, 'walletTravel'),
  new IconDefinition(MdiIcons.wan, 'wan'),
  new IconDefinition(MdiIcons.washingMachine, 'washingMachine'),
  new IconDefinition(MdiIcons.watch, 'watch'),
  new IconDefinition(MdiIcons.watchExport, 'watchExport'),
  new IconDefinition(MdiIcons.watchExportVariant, 'watchExportVariant'),
  new IconDefinition(MdiIcons.watchImport, 'watchImport'),
  new IconDefinition(MdiIcons.watchImportVariant, 'watchImportVariant'),
  new IconDefinition(MdiIcons.watchVariant, 'watchVariant'),
  new IconDefinition(MdiIcons.watchVibrate, 'watchVibrate'),
  new IconDefinition(MdiIcons.watchVibrateOff, 'watchVibrateOff'),
  new IconDefinition(MdiIcons.water, 'water'),
  new IconDefinition(MdiIcons.waterOff, 'waterOff'),
  new IconDefinition(MdiIcons.waterPercent, 'waterPercent'),
  new IconDefinition(MdiIcons.waterPump, 'waterPump'),
  new IconDefinition(MdiIcons.watermark, 'watermark'),
  new IconDefinition(MdiIcons.waves, 'waves'),
  new IconDefinition(MdiIcons.waze, 'waze'),
  new IconDefinition(MdiIcons.weatherCloudy, 'weatherCloudy'),
  new IconDefinition(MdiIcons.weatherFog, 'weatherFog'),
  new IconDefinition(MdiIcons.weatherHail, 'weatherHail'),
  new IconDefinition(MdiIcons.weatherHurricane, 'weatherHurricane'),
  new IconDefinition(MdiIcons.weatherLightning, 'weatherLightning'),
  new IconDefinition(MdiIcons.weatherLightningRainy, 'weatherLightningRainy'),
  new IconDefinition(MdiIcons.weatherNight, 'weatherNight'),
  new IconDefinition(MdiIcons.weatherPartlycloudy, 'weatherPartlycloudy'),
  new IconDefinition(MdiIcons.weatherPouring, 'weatherPouring'),
  new IconDefinition(MdiIcons.weatherRainy, 'weatherRainy'),
  new IconDefinition(MdiIcons.weatherSnowy, 'weatherSnowy'),
  new IconDefinition(MdiIcons.weatherSnowyRainy, 'weatherSnowyRainy'),
  new IconDefinition(MdiIcons.weatherSunny, 'weatherSunny'),
  new IconDefinition(MdiIcons.weatherSunset, 'weatherSunset'),
  new IconDefinition(MdiIcons.weatherSunsetDown, 'weatherSunsetDown'),
  new IconDefinition(MdiIcons.weatherSunsetUp, 'weatherSunsetUp'),
  new IconDefinition(MdiIcons.weatherWindy, 'weatherWindy'),
  new IconDefinition(MdiIcons.weatherWindyVariant, 'weatherWindyVariant'),
  new IconDefinition(MdiIcons.web, 'web'),
  new IconDefinition(MdiIcons.webcam, 'webcam'),
  new IconDefinition(MdiIcons.webhook, 'webhook'),
  new IconDefinition(MdiIcons.webpack, 'webpack'),
  new IconDefinition(MdiIcons.wechat, 'wechat'),
  new IconDefinition(MdiIcons.weight, 'weight'),
  new IconDefinition(MdiIcons.weightKilogram, 'weightKilogram'),
  new IconDefinition(MdiIcons.weightPound, 'weightPound'),
  new IconDefinition(MdiIcons.whatsapp, 'whatsapp'),
  new IconDefinition(MdiIcons.wheelchairAccessibility, 'wheelchairAccessibility'),
  new IconDefinition(MdiIcons.whistle, 'whistle'),
  new IconDefinition(MdiIcons.whiteBalanceAuto, 'whiteBalanceAuto'),
  new IconDefinition(MdiIcons.whiteBalanceIncandescent, 'whiteBalanceIncandescent'),
  new IconDefinition(MdiIcons.whiteBalanceIridescent, 'whiteBalanceIridescent'),
  new IconDefinition(MdiIcons.whiteBalanceSunny, 'whiteBalanceSunny'),
  new IconDefinition(MdiIcons.widgets, 'widgets'),
  new IconDefinition(MdiIcons.wifi, 'wifi'),
  new IconDefinition(MdiIcons.wifiOff, 'wifiOff'),
  new IconDefinition(MdiIcons.wifiStrength1, 'wifiStrength1'),
  new IconDefinition(MdiIcons.wifiStrength1Alert, 'wifiStrength1Alert'),
  new IconDefinition(MdiIcons.wifiStrength1Lock, 'wifiStrength1Lock'),
  new IconDefinition(MdiIcons.wifiStrength2, 'wifiStrength2'),
  new IconDefinition(MdiIcons.wifiStrength2Alert, 'wifiStrength2Alert'),
  new IconDefinition(MdiIcons.wifiStrength2Lock, 'wifiStrength2Lock'),
  new IconDefinition(MdiIcons.wifiStrength3, 'wifiStrength3'),
  new IconDefinition(MdiIcons.wifiStrength3Alert, 'wifiStrength3Alert'),
  new IconDefinition(MdiIcons.wifiStrength3Lock, 'wifiStrength3Lock'),
  new IconDefinition(MdiIcons.wifiStrength4, 'wifiStrength4'),
  new IconDefinition(MdiIcons.wifiStrength4Alert, 'wifiStrength4Alert'),
  new IconDefinition(MdiIcons.wifiStrength4Lock, 'wifiStrength4Lock'),
  new IconDefinition(MdiIcons.wifiStrengthAlertOutline, 'wifiStrengthAlertOutline'),
  new IconDefinition(MdiIcons.wifiStrengthLockOutline, 'wifiStrengthLockOutline'),
  new IconDefinition(MdiIcons.wifiStrengthOff, 'wifiStrengthOff'),
  new IconDefinition(MdiIcons.wifiStrengthOffOutline, 'wifiStrengthOffOutline'),
  new IconDefinition(MdiIcons.wifiStrengthOutline, 'wifiStrengthOutline'),
  new IconDefinition(MdiIcons.wii, 'wii'),
  new IconDefinition(MdiIcons.wiiu, 'wiiu'),
  new IconDefinition(MdiIcons.wikipedia, 'wikipedia'),
  new IconDefinition(MdiIcons.windowClose, 'windowClose'),
  new IconDefinition(MdiIcons.windowClosed, 'windowClosed'),
  new IconDefinition(MdiIcons.windowMaximize, 'windowMaximize'),
  new IconDefinition(MdiIcons.windowMinimize, 'windowMinimize'),
  new IconDefinition(MdiIcons.windowOpen, 'windowOpen'),
  new IconDefinition(MdiIcons.windowRestore, 'windowRestore'),
  new IconDefinition(MdiIcons.windows, 'windows'),
  new IconDefinition(MdiIcons.windowsClassic, 'windowsClassic'),
  new IconDefinition(MdiIcons.wiper, 'wiper'),
  new IconDefinition(MdiIcons.wordpress, 'wordpress'),
  new IconDefinition(MdiIcons.worker, 'worker'),
  new IconDefinition(MdiIcons.wrap, 'wrap'),
  new IconDefinition(MdiIcons.wrapDisabled, 'wrapDisabled'),
  new IconDefinition(MdiIcons.wrench, 'wrench'),
  new IconDefinition(MdiIcons.wrenchOutline, 'wrenchOutline'),
  new IconDefinition(MdiIcons.wunderlist, 'wunderlist'),
  new IconDefinition(MdiIcons.xamarin, 'xamarin'),
  new IconDefinition(MdiIcons.xamarinOutline, 'xamarinOutline'),
  new IconDefinition(MdiIcons.xaml, 'xaml'),
  new IconDefinition(MdiIcons.xbox, 'xbox'),
  new IconDefinition(MdiIcons.xboxController, 'xboxController'),
  new IconDefinition(MdiIcons.xboxControllerBatteryAlert, 'xboxControllerBatteryAlert'),
  new IconDefinition(MdiIcons.xboxControllerBatteryCharging, 'xboxControllerBatteryCharging'),
  new IconDefinition(MdiIcons.xboxControllerBatteryEmpty, 'xboxControllerBatteryEmpty'),
  new IconDefinition(MdiIcons.xboxControllerBatteryFull, 'xboxControllerBatteryFull'),
  new IconDefinition(MdiIcons.xboxControllerBatteryLow, 'xboxControllerBatteryLow'),
  new IconDefinition(MdiIcons.xboxControllerBatteryMedium, 'xboxControllerBatteryMedium'),
  new IconDefinition(MdiIcons.xboxControllerBatteryUnknown, 'xboxControllerBatteryUnknown'),
  new IconDefinition(MdiIcons.xboxControllerOff, 'xboxControllerOff'),
  new IconDefinition(MdiIcons.xda, 'xda'),
  new IconDefinition(MdiIcons.xing, 'xing'),
  new IconDefinition(MdiIcons.xingBox, 'xingBox'),
  new IconDefinition(MdiIcons.xingCircle, 'xingCircle'),
  new IconDefinition(MdiIcons.xml, 'xml'),
  new IconDefinition(MdiIcons.xmpp, 'xmpp'),
  new IconDefinition(MdiIcons.yahoo, 'yahoo'),
  new IconDefinition(MdiIcons.yammer, 'yammer'),
  new IconDefinition(MdiIcons.yeast, 'yeast'),
  new IconDefinition(MdiIcons.yelp, 'yelp'),
  new IconDefinition(MdiIcons.yinYang, 'yinYang'),
  new IconDefinition(MdiIcons.youtube, 'youtube'),
  new IconDefinition(MdiIcons.youtubeCreatorStudio, 'youtubeCreatorStudio'),
  new IconDefinition(MdiIcons.youtubeGaming, 'youtubeGaming'),
  new IconDefinition(MdiIcons.youtubeTv, 'youtubeTv'),
  new IconDefinition(MdiIcons.zWave, 'zWave'),
  new IconDefinition(MdiIcons.zend, 'zend'),
  new IconDefinition(MdiIcons.zipBox, 'zipBox'),
  new IconDefinition(MdiIcons.zipDisk, 'zipDisk'),
  new IconDefinition(MdiIcons.zodiacAquarius, 'zodiacAquarius'),
  new IconDefinition(MdiIcons.zodiacAries, 'zodiacAries'),
  new IconDefinition(MdiIcons.zodiacCancer, 'zodiacCancer'),
  new IconDefinition(MdiIcons.zodiacCapricorn, 'zodiacCapricorn'),
  new IconDefinition(MdiIcons.zodiacGemini, 'zodiacGemini'),
  new IconDefinition(MdiIcons.zodiacLeo, 'zodiacLeo'),
  new IconDefinition(MdiIcons.zodiacLibra, 'zodiacLibra'),
  new IconDefinition(MdiIcons.zodiacPisces, 'zodiacPisces'),
  new IconDefinition(MdiIcons.zodiacSagittarius, 'zodiacSagittarius'),
  new IconDefinition(MdiIcons.zodiacScorpio, 'zodiacScorpio'),
  new IconDefinition(MdiIcons.zodiacTaurus, 'zodiacTaurus'),
  new IconDefinition(MdiIcons.zodiacVirgo, 'zodiacVirgo'),
];
